/* 
 * h235_container0.cxx
 *
 * Source for registering and starting the decode of the H.245 protocol
 *
 * H.323 for Ethereal
 *
 * Copyright (c) 2002 Koninklijke Philips NV
 *
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific language governing rights and limitations
 * under the License.
 *
 * The Original Code is H.323 for Ethereal.
 *
 * The Initial Developer of the Original Code is Koninklijke Philips NV.
 *
 * All Rights Reserved.
 *
 * Contributor(s): ______________________________________.
 *
 *
 */


extern "C" {
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "plugins/plugin_api.h"

#include "moduleinfo.h"

#ifdef HAVE_SYS_TYPES_H
#include <sys/types.h>
#endif

#include <string.h>
#include <ctype.h>
#include <time.h>

#include <gmodule.h>
#ifdef HAVE_NETINET_IN_H
# include <netinet/in.h>
#endif
#include <epan/packet.h>
#include "packet-h225.h"

}


extern "C++"{
#  include <stdio.h>
#  include <string.h>
#  include "h245_container.h"
#  include "mini_ptlib/include/mini_ptlib.h"
#  include "h245.h"
}

//static address fake_addr;
static int heur_init = FALSE;

static H245_Integer_Container h245Cont;

static gboolean h245_desegment = TRUE;
static dissector_handle_t h245_tpkt_pdu_handle;

extern "C" {
/*
void h245_add_address( const unsigned char* ip_addr, int prt )
{
	address src_addr;
	conversation_t* pconv = ( conversation_t* ) NULL;

	src_addr.type = AT_IPv4;
	src_addr.len = 4;
	src_addr.data = ip_addr;

	/*
	 * The first time the function is called let the tcp dissector
	 * know that we're interested in traffic
	 */
/*	if ( ! heur_init ) {
		heur_dissector_add( "tcp", dissect_h245, h245Cont.h245_0.hf_proto_H245 );
		heur_init = TRUE;
	}

	/*
	 * Check if the ip address and port combination is not 
	 * already registered
	 */
/*	pconv = find_conversation( &src_addr, &fake_addr, PT_TCP, prt, 0, 0);

	/*
	 * If not, add
	 */
/*	if ( ! pconv ) {
		conversation_new( &src_addr, &fake_addr, PT_TCP, prt, 0, NULL, 0 );
	}

}

static void h245_init( void ) 
{
	// Create a fake adddress...
	fake_addr.type = AT_IPv4;
	fake_addr.len = 4;

	unsigned char* tmp_data = new unsigned char[ fake_addr.len ];
	for ( int i = 0; i < fake_addr.len; i++) {
		tmp_data[i] = 0;
	}
	fake_addr.data = tmp_data;
}
*/

static void
dissect_h245_tpkt_pdu( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
{
  PBYTEArray bytes;
  int nr_bytes_in_data = 0;
  int offset = 0;
  bool tpkt_len_found = false;
  
	while ( tvb_length_remaining( tvb, offset + ( unsigned ) nr_bytes_in_data ) > 0 ) {
		bytes[ nr_bytes_in_data ] = tvb_get_guint8( tvb, offset + nr_bytes_in_data );
		nr_bytes_in_data++;
	}
  
  PPER_Stream strm( bytes );
  H245_MultimediaSystemControlMessage seq;
  
  if ( seq.Decode( strm ) ) {
  /*
  * After a succesful decode do preShowEthereal() first
  * This might result in more protocols to be dissected 
  * ( compare H.225.0 -> H.245)
    */
    seq.preShowEthereal();
    if ( check_col( pinfo->cinfo, COL_PROTOCOL ) )   {
      col_add_str( pinfo->cinfo, COL_PROTOCOL, "H.245" );
    }
    if ( check_col( pinfo->cinfo, COL_INFO ) )   
    {
      col_append_fstr( pinfo->cinfo, COL_INFO, "%s ", (const unsigned char*) seq.getSummary() );
    }
    
    if ( tree ) 
    {
    /* 
    * Start displaying
      */
      proto_tree	*h245_tree = (proto_tree*) NULL;
      proto_item	*h245_ti = (proto_item*) NULL;
      h245_ti = proto_tree_add_item( tree, h245Cont.h245_0.hf_proto_H245, tvb, offset, seq.GetByteLength(), FALSE );
      h245_tree = proto_item_add_subtree( h245_ti, h245Cont.h245_0.ett_proto_H245 );
      seq.showEthereal( h245_tree, tvb, offset );
    }
  }
  else
  {
    col_append_str( pinfo->cinfo, COL_INFO, "Failure during decode" );
  }
}

void 
dissect_h245( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
{
  // This dissector is only called for conversations which have been
  // registered by the H.225 CS dissector, so no need to check anything 
  // right now
  dissect_tpkt_encap(tvb, pinfo, tree, h245_desegment, h245_tpkt_pdu_handle);
}

void
proto_reg_handoff_h245(void)
{
	dissector_handle_t h245_handle;
	h245_handle = create_dissector_handle( dissect_h245, h245Cont.h245_0.hf_proto_H245 );
}


void
proto_register_h245(void)
{

static hf_register_info hfh245[] = 
{
  {
  &h245Cont.h245_0.hf_h245_NonStandardIdentifier_object,
    {
      "object",
      "h245.NonStandardIdentifier.object",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NonStandardIdentifier object",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_MasterSlaveDetermination_terminalType,
    {
      "terminalType",
      "h245.MasterSlaveDetermination.terminalType",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MasterSlaveDetermination terminalType",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_MasterSlaveDetermination_statusDeterminationNumber,
    {
      "statusDeterminationNumber",
      "h245.MasterSlaveDetermination.statusDeterminationNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MasterSlaveDetermination statusDeterminationNumber",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AlternativeCapabilitySet_array,
    {
      "array",
      "h245.AlternativeCapabilitySet.array",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "AlternativeCapabilitySet array",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_TerminalCapabilitySetAck_sequenceNumber,
    {
      "sequenceNumber",
      "h245.TerminalCapabilitySetAck.sequenceNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "TerminalCapabilitySetAck sequenceNumber",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_Capability_h233EncryptionTransmitCapability,
    {
      "h233EncryptionTransmitCapability",
      "h245.Capability.h233EncryptionTransmitCapability",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "Capability h233EncryptionTransmitCapability",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_Capability_maxPendingReplacementFor,
    {
      "maxPendingReplacementFor",
      "h245.Capability.maxPendingReplacementFor",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "Capability maxPendingReplacementFor",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H223AnnexCCapability_videoWithAL1M,
    {
      "videoWithAL1M",
      "h245.H223AnnexCCapability.videoWithAL1M",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AnnexCCapability videoWithAL1M",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H223AnnexCCapability_videoWithAL2M,
    {
      "videoWithAL2M",
      "h245.H223AnnexCCapability.videoWithAL2M",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AnnexCCapability videoWithAL2M",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H223AnnexCCapability_videoWithAL3M,
    {
      "videoWithAL3M",
      "h245.H223AnnexCCapability.videoWithAL3M",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AnnexCCapability videoWithAL3M",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H223AnnexCCapability_audioWithAL1M,
    {
      "audioWithAL1M",
      "h245.H223AnnexCCapability.audioWithAL1M",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AnnexCCapability audioWithAL1M",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H223AnnexCCapability_audioWithAL2M,
    {
      "audioWithAL2M",
      "h245.H223AnnexCCapability.audioWithAL2M",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AnnexCCapability audioWithAL2M",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H223AnnexCCapability_audioWithAL3M,
    {
      "audioWithAL3M",
      "h245.H223AnnexCCapability.audioWithAL3M",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AnnexCCapability audioWithAL3M",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H223AnnexCCapability_dataWithAL1M,
    {
      "dataWithAL1M",
      "h245.H223AnnexCCapability.dataWithAL1M",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AnnexCCapability dataWithAL1M",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H223AnnexCCapability_dataWithAL2M,
    {
      "dataWithAL2M",
      "h245.H223AnnexCCapability.dataWithAL2M",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AnnexCCapability dataWithAL2M",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H223AnnexCCapability_dataWithAL3M,
    {
      "dataWithAL3M",
      "h245.H223AnnexCCapability.dataWithAL3M",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AnnexCCapability dataWithAL3M",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H223AnnexCCapability_alpduInterleaving,
    {
      "alpduInterleaving",
      "h245.H223AnnexCCapability.alpduInterleaving",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AnnexCCapability alpduInterleaving",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H223AnnexCCapability_maximumAL1MPDUSize,
    {
      "maximumAL1MPDUSize",
      "h245.H223AnnexCCapability.maximumAL1MPDUSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H223AnnexCCapability maximumAL1MPDUSize",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H223AnnexCCapability_maximumAL2MSDUSize,
    {
      "maximumAL2MSDUSize",
      "h245.H223AnnexCCapability.maximumAL2MSDUSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H223AnnexCCapability maximumAL2MSDUSize",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H223AnnexCCapability_maximumAL3MSDUSize,
    {
      "maximumAL3MSDUSize",
      "h245.H223AnnexCCapability.maximumAL3MSDUSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H223AnnexCCapability maximumAL3MSDUSize",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_V75Capability_audioHeader,
    {
      "audioHeader",
      "h245.V75Capability.audioHeader",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "V75Capability audioHeader",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_QOSMode_guaranteedQOS,
    {
      "guaranteedQOS",
      "h245.QOSMode.guaranteedQOS",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "QOSMode guaranteedQOS",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_QOSMode_controlledLoad,
    {
      "controlledLoad",
      "h245.QOSMode.controlledLoad",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "QOSMode controlledLoad",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ATMParameters_maxNTUSize,
    {
      "maxNTUSize",
      "h245.ATMParameters.maxNTUSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "ATMParameters maxNTUSize",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ATMParameters_atmUBR,
    {
      "atmUBR",
      "h245.ATMParameters.atmUBR",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "ATMParameters atmUBR",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ATMParameters_atmrtVBR,
    {
      "atmrtVBR",
      "h245.ATMParameters.atmrtVBR",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "ATMParameters atmrtVBR",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ATMParameters_atmnrtVBR,
    {
      "atmnrtVBR",
      "h245.ATMParameters.atmnrtVBR",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "ATMParameters atmnrtVBR",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ATMParameters_atmABR,
    {
      "atmABR",
      "h245.ATMParameters.atmABR",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "ATMParameters atmABR",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ATMParameters_atmCBR,
    {
      "atmCBR",
      "h245.ATMParameters.atmCBR",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "ATMParameters atmCBR",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_MediaTransportType_ip_UDP,
    {
      "ip_UDP",
      "h245.MediaTransportType.ip_UDP",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MediaTransportType ip_UDP",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_MediaTransportType_ip_TCP,
    {
      "ip_TCP",
      "h245.MediaTransportType.ip_TCP",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MediaTransportType ip_TCP",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_MediaTransportType_atm_AAL5_UNIDIR,
    {
      "atm_AAL5_UNIDIR",
      "h245.MediaTransportType.atm_AAL5_UNIDIR",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MediaTransportType atm_AAL5_UNIDIR",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_MediaTransportType_atm_AAL5_BIDIR,
    {
      "atm_AAL5_BIDIR",
      "h245.MediaTransportType.atm_AAL5_BIDIR",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MediaTransportType atm_AAL5_BIDIR",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_RedundancyEncodingMethod_rtpAudioRedundancyEncoding,
    {
      "rtpAudioRedundancyEncoding",
      "h245.RedundancyEncodingMethod.rtpAudioRedundancyEncoding",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RedundancyEncodingMethod rtpAudioRedundancyEncoding",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H261VideoCapability_qcifMPI,
    {
      "qcifMPI",
      "h245.H261VideoCapability.qcifMPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H261VideoCapability qcifMPI",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H261VideoCapability_cifMPI,
    {
      "cifMPI",
      "h245.H261VideoCapability.cifMPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H261VideoCapability cifMPI",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H261VideoCapability_temporalSpatialTradeOffCapability,
    {
      "temporalSpatialTradeOffCapability",
      "h245.H261VideoCapability.temporalSpatialTradeOffCapability",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H261VideoCapability temporalSpatialTradeOffCapability",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H261VideoCapability_maxBitRate,
    {
      "maxBitRate",
      "h245.H261VideoCapability.maxBitRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H261VideoCapability maxBitRate",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H261VideoCapability_stillImageTransmission,
    {
      "stillImageTransmission",
      "h245.H261VideoCapability.stillImageTransmission",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H261VideoCapability stillImageTransmission",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H262VideoCapability_profileAndLevel_SPatML,
    {
      "profileAndLevel_SPatML",
      "h245.H262VideoCapability.profileAndLevel_SPatML",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H262VideoCapability profileAndLevel_SPatML",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H262VideoCapability_profileAndLevel_MPatLL,
    {
      "profileAndLevel_MPatLL",
      "h245.H262VideoCapability.profileAndLevel_MPatLL",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H262VideoCapability profileAndLevel_MPatLL",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H262VideoCapability_profileAndLevel_MPatML,
    {
      "profileAndLevel_MPatML",
      "h245.H262VideoCapability.profileAndLevel_MPatML",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H262VideoCapability profileAndLevel_MPatML",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H262VideoCapability_profileAndLevel_MPatH_14,
    {
      "profileAndLevel_MPatH_14",
      "h245.H262VideoCapability.profileAndLevel_MPatH_14",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H262VideoCapability profileAndLevel_MPatH_14",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H262VideoCapability_profileAndLevel_MPatHL,
    {
      "profileAndLevel_MPatHL",
      "h245.H262VideoCapability.profileAndLevel_MPatHL",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H262VideoCapability profileAndLevel_MPatHL",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H262VideoCapability_profileAndLevel_SNRatLL,
    {
      "profileAndLevel_SNRatLL",
      "h245.H262VideoCapability.profileAndLevel_SNRatLL",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H262VideoCapability profileAndLevel_SNRatLL",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H262VideoCapability_profileAndLevel_SNRatML,
    {
      "profileAndLevel_SNRatML",
      "h245.H262VideoCapability.profileAndLevel_SNRatML",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H262VideoCapability profileAndLevel_SNRatML",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H262VideoCapability_profileAndLevel_SpatialatH_14,
    {
      "profileAndLevel_SpatialatH_14",
      "h245.H262VideoCapability.profileAndLevel_SpatialatH_14",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H262VideoCapability profileAndLevel_SpatialatH_14",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H262VideoCapability_profileAndLevel_HPatML,
    {
      "profileAndLevel_HPatML",
      "h245.H262VideoCapability.profileAndLevel_HPatML",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H262VideoCapability profileAndLevel_HPatML",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H262VideoCapability_profileAndLevel_HPatH_14,
    {
      "profileAndLevel_HPatH_14",
      "h245.H262VideoCapability.profileAndLevel_HPatH_14",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H262VideoCapability profileAndLevel_HPatH_14",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H262VideoCapability_profileAndLevel_HPatHL,
    {
      "profileAndLevel_HPatHL",
      "h245.H262VideoCapability.profileAndLevel_HPatHL",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H262VideoCapability profileAndLevel_HPatHL",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H262VideoCapability_videoBitRate,
    {
      "videoBitRate",
      "h245.H262VideoCapability.videoBitRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H262VideoCapability videoBitRate",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H262VideoCapability_vbvBufferSize,
    {
      "vbvBufferSize",
      "h245.H262VideoCapability.vbvBufferSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H262VideoCapability vbvBufferSize",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H262VideoCapability_samplesPerLine,
    {
      "samplesPerLine",
      "h245.H262VideoCapability.samplesPerLine",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H262VideoCapability samplesPerLine",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H262VideoCapability_linesPerFrame,
    {
      "linesPerFrame",
      "h245.H262VideoCapability.linesPerFrame",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H262VideoCapability linesPerFrame",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H262VideoCapability_framesPerSecond,
    {
      "framesPerSecond",
      "h245.H262VideoCapability.framesPerSecond",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H262VideoCapability framesPerSecond",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H262VideoCapability_luminanceSampleRate,
    {
      "luminanceSampleRate",
      "h245.H262VideoCapability.luminanceSampleRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H262VideoCapability luminanceSampleRate",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_TransparencyParameters_presentationOrder,
    {
      "presentationOrder",
      "h245.TransparencyParameters.presentationOrder",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "TransparencyParameters presentationOrder",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_TransparencyParameters_offset_x,
    {
      "offset_x",
      "h245.TransparencyParameters.offset_x",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "TransparencyParameters offset_x",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_TransparencyParameters_offset_y,
    {
      "offset_y",
      "h245.TransparencyParameters.offset_y",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "TransparencyParameters offset_y",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_TransparencyParameters_scale_x,
    {
      "scale_x",
      "h245.TransparencyParameters.scale_x",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "TransparencyParameters scale_x",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_TransparencyParameters_scale_y,
    {
      "scale_y",
      "h245.TransparencyParameters.scale_y",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "TransparencyParameters scale_y",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_CustomPictureClockFrequency_clockConversionCode,
    {
      "clockConversionCode",
      "h245.CustomPictureClockFrequency.clockConversionCode",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CustomPictureClockFrequency clockConversionCode",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_CustomPictureClockFrequency_clockDivisor,
    {
      "clockDivisor",
      "h245.CustomPictureClockFrequency.clockDivisor",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CustomPictureClockFrequency clockDivisor",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_CustomPictureClockFrequency_sqcifMPI,
    {
      "sqcifMPI",
      "h245.CustomPictureClockFrequency.sqcifMPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CustomPictureClockFrequency sqcifMPI",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_CustomPictureClockFrequency_qcifMPI,
    {
      "qcifMPI",
      "h245.CustomPictureClockFrequency.qcifMPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CustomPictureClockFrequency qcifMPI",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_CustomPictureClockFrequency_cifMPI,
    {
      "cifMPI",
      "h245.CustomPictureClockFrequency.cifMPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CustomPictureClockFrequency cifMPI",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_CustomPictureClockFrequency_cif4MPI,
    {
      "cif4MPI",
      "h245.CustomPictureClockFrequency.cif4MPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CustomPictureClockFrequency cif4MPI",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_CustomPictureClockFrequency_cif16MPI,
    {
      "cif16MPI",
      "h245.CustomPictureClockFrequency.cif16MPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CustomPictureClockFrequency cif16MPI",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H263ModeComboFlags_unrestrictedVector,
    {
      "unrestrictedVector",
      "h245.H263ModeComboFlags.unrestrictedVector",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263ModeComboFlags unrestrictedVector",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H263ModeComboFlags_arithmeticCoding,
    {
      "arithmeticCoding",
      "h245.H263ModeComboFlags.arithmeticCoding",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263ModeComboFlags arithmeticCoding",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H263ModeComboFlags_advancedPrediction,
    {
      "advancedPrediction",
      "h245.H263ModeComboFlags.advancedPrediction",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263ModeComboFlags advancedPrediction",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H263ModeComboFlags_pbFrames,
    {
      "pbFrames",
      "h245.H263ModeComboFlags.pbFrames",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263ModeComboFlags pbFrames",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H263ModeComboFlags_advancedIntraCodingMode,
    {
      "advancedIntraCodingMode",
      "h245.H263ModeComboFlags.advancedIntraCodingMode",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263ModeComboFlags advancedIntraCodingMode",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H263ModeComboFlags_deblockingFilterMode,
    {
      "deblockingFilterMode",
      "h245.H263ModeComboFlags.deblockingFilterMode",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263ModeComboFlags deblockingFilterMode",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H263ModeComboFlags_unlimitedMotionVectors,
    {
      "unlimitedMotionVectors",
      "h245.H263ModeComboFlags.unlimitedMotionVectors",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263ModeComboFlags unlimitedMotionVectors",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H263ModeComboFlags_slicesInOrder_NonRect,
    {
      "slicesInOrder_NonRect",
      "h245.H263ModeComboFlags.slicesInOrder_NonRect",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263ModeComboFlags slicesInOrder_NonRect",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H263ModeComboFlags_slicesInOrder_Rect,
    {
      "slicesInOrder_Rect",
      "h245.H263ModeComboFlags.slicesInOrder_Rect",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263ModeComboFlags slicesInOrder_Rect",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H263ModeComboFlags_slicesNoOrder_NonRect,
    {
      "slicesNoOrder_NonRect",
      "h245.H263ModeComboFlags.slicesNoOrder_NonRect",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263ModeComboFlags slicesNoOrder_NonRect",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H263ModeComboFlags_slicesNoOrder_Rect,
    {
      "slicesNoOrder_Rect",
      "h245.H263ModeComboFlags.slicesNoOrder_Rect",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263ModeComboFlags slicesNoOrder_Rect",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H263ModeComboFlags_improvedPBFramesMode,
    {
      "improvedPBFramesMode",
      "h245.H263ModeComboFlags.improvedPBFramesMode",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263ModeComboFlags improvedPBFramesMode",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H263ModeComboFlags_referencePicSelect,
    {
      "referencePicSelect",
      "h245.H263ModeComboFlags.referencePicSelect",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263ModeComboFlags referencePicSelect",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H263ModeComboFlags_dynamicPictureResizingByFour,
    {
      "dynamicPictureResizingByFour",
      "h245.H263ModeComboFlags.dynamicPictureResizingByFour",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263ModeComboFlags dynamicPictureResizingByFour",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H263ModeComboFlags_dynamicPictureResizingSixteenthPel,
    {
      "dynamicPictureResizingSixteenthPel",
      "h245.H263ModeComboFlags.dynamicPictureResizingSixteenthPel",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263ModeComboFlags dynamicPictureResizingSixteenthPel",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H263ModeComboFlags_dynamicWarpingHalfPel,
    {
      "dynamicWarpingHalfPel",
      "h245.H263ModeComboFlags.dynamicWarpingHalfPel",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263ModeComboFlags dynamicWarpingHalfPel",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H263ModeComboFlags_dynamicWarpingSixteenthPel,
    {
      "dynamicWarpingSixteenthPel",
      "h245.H263ModeComboFlags.dynamicWarpingSixteenthPel",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263ModeComboFlags dynamicWarpingSixteenthPel",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H263ModeComboFlags_reducedResolutionUpdate,
    {
      "reducedResolutionUpdate",
      "h245.H263ModeComboFlags.reducedResolutionUpdate",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263ModeComboFlags reducedResolutionUpdate",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H263ModeComboFlags_independentSegmentDecoding,
    {
      "independentSegmentDecoding",
      "h245.H263ModeComboFlags.independentSegmentDecoding",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263ModeComboFlags independentSegmentDecoding",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H263ModeComboFlags_alternateInterVLCMode,
    {
      "alternateInterVLCMode",
      "h245.H263ModeComboFlags.alternateInterVLCMode",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263ModeComboFlags alternateInterVLCMode",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H263ModeComboFlags_modifiedQuantizationMode,
    {
      "modifiedQuantizationMode",
      "h245.H263ModeComboFlags.modifiedQuantizationMode",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263ModeComboFlags modifiedQuantizationMode",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS11172VideoCapability_constrainedBitstream,
    {
      "constrainedBitstream",
      "h245.IS11172VideoCapability.constrainedBitstream",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS11172VideoCapability constrainedBitstream",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS11172VideoCapability_videoBitRate,
    {
      "videoBitRate",
      "h245.IS11172VideoCapability.videoBitRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "IS11172VideoCapability videoBitRate",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS11172VideoCapability_vbvBufferSize,
    {
      "vbvBufferSize",
      "h245.IS11172VideoCapability.vbvBufferSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "IS11172VideoCapability vbvBufferSize",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS11172VideoCapability_samplesPerLine,
    {
      "samplesPerLine",
      "h245.IS11172VideoCapability.samplesPerLine",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "IS11172VideoCapability samplesPerLine",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS11172VideoCapability_linesPerFrame,
    {
      "linesPerFrame",
      "h245.IS11172VideoCapability.linesPerFrame",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "IS11172VideoCapability linesPerFrame",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS11172VideoCapability_pictureRate,
    {
      "pictureRate",
      "h245.IS11172VideoCapability.pictureRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "IS11172VideoCapability pictureRate",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS11172VideoCapability_luminanceSampleRate,
    {
      "luminanceSampleRate",
      "h245.IS11172VideoCapability.luminanceSampleRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "IS11172VideoCapability luminanceSampleRate",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioCapability_g711Alaw64k,
    {
      "g711Alaw64k",
      "h245.AudioCapability.g711Alaw64k",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "AudioCapability g711Alaw64k",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioCapability_g711Alaw56k,
    {
      "g711Alaw56k",
      "h245.AudioCapability.g711Alaw56k",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "AudioCapability g711Alaw56k",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioCapability_g711Ulaw64k,
    {
      "g711Ulaw64k",
      "h245.AudioCapability.g711Ulaw64k",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "AudioCapability g711Ulaw64k",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioCapability_g711Ulaw56k,
    {
      "g711Ulaw56k",
      "h245.AudioCapability.g711Ulaw56k",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "AudioCapability g711Ulaw56k",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioCapability_g722_64k,
    {
      "g722_64k",
      "h245.AudioCapability.g722_64k",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "AudioCapability g722_64k",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioCapability_g722_56k,
    {
      "g722_56k",
      "h245.AudioCapability.g722_56k",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "AudioCapability g722_56k",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioCapability_g722_48k,
    {
      "g722_48k",
      "h245.AudioCapability.g722_48k",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "AudioCapability g722_48k",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioCapability_g728,
    {
      "g728",
      "h245.AudioCapability.g728",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "AudioCapability g728",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioCapability_g729,
    {
      "g729",
      "h245.AudioCapability.g729",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "AudioCapability g729",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioCapability_g729AnnexA,
    {
      "g729AnnexA",
      "h245.AudioCapability.g729AnnexA",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "AudioCapability g729AnnexA",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioCapability_g729wAnnexB,
    {
      "g729wAnnexB",
      "h245.AudioCapability.g729wAnnexB",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "AudioCapability g729wAnnexB",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioCapability_g729AnnexAwAnnexB,
    {
      "g729AnnexAwAnnexB",
      "h245.AudioCapability.g729AnnexAwAnnexB",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "AudioCapability g729AnnexAwAnnexB",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS11172AudioCapability_audioLayer1,
    {
      "audioLayer1",
      "h245.IS11172AudioCapability.audioLayer1",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS11172AudioCapability audioLayer1",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS11172AudioCapability_audioLayer2,
    {
      "audioLayer2",
      "h245.IS11172AudioCapability.audioLayer2",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS11172AudioCapability audioLayer2",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS11172AudioCapability_audioLayer3,
    {
      "audioLayer3",
      "h245.IS11172AudioCapability.audioLayer3",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS11172AudioCapability audioLayer3",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS11172AudioCapability_audioSampling32k,
    {
      "audioSampling32k",
      "h245.IS11172AudioCapability.audioSampling32k",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS11172AudioCapability audioSampling32k",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS11172AudioCapability_audioSampling44k1,
    {
      "audioSampling44k1",
      "h245.IS11172AudioCapability.audioSampling44k1",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS11172AudioCapability audioSampling44k1",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS11172AudioCapability_audioSampling48k,
    {
      "audioSampling48k",
      "h245.IS11172AudioCapability.audioSampling48k",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS11172AudioCapability audioSampling48k",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS11172AudioCapability_singleChannel,
    {
      "singleChannel",
      "h245.IS11172AudioCapability.singleChannel",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS11172AudioCapability singleChannel",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS11172AudioCapability_twoChannels,
    {
      "twoChannels",
      "h245.IS11172AudioCapability.twoChannels",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS11172AudioCapability twoChannels",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS11172AudioCapability_bitRate,
    {
      "bitRate",
      "h245.IS11172AudioCapability.bitRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "IS11172AudioCapability bitRate",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS13818AudioCapability_audioLayer1,
    {
      "audioLayer1",
      "h245.IS13818AudioCapability.audioLayer1",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioCapability audioLayer1",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS13818AudioCapability_audioLayer2,
    {
      "audioLayer2",
      "h245.IS13818AudioCapability.audioLayer2",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioCapability audioLayer2",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS13818AudioCapability_audioLayer3,
    {
      "audioLayer3",
      "h245.IS13818AudioCapability.audioLayer3",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioCapability audioLayer3",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS13818AudioCapability_audioSampling16k,
    {
      "audioSampling16k",
      "h245.IS13818AudioCapability.audioSampling16k",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioCapability audioSampling16k",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS13818AudioCapability_audioSampling22k05,
    {
      "audioSampling22k05",
      "h245.IS13818AudioCapability.audioSampling22k05",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioCapability audioSampling22k05",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS13818AudioCapability_audioSampling24k,
    {
      "audioSampling24k",
      "h245.IS13818AudioCapability.audioSampling24k",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioCapability audioSampling24k",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS13818AudioCapability_audioSampling32k,
    {
      "audioSampling32k",
      "h245.IS13818AudioCapability.audioSampling32k",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioCapability audioSampling32k",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS13818AudioCapability_audioSampling44k1,
    {
      "audioSampling44k1",
      "h245.IS13818AudioCapability.audioSampling44k1",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioCapability audioSampling44k1",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS13818AudioCapability_audioSampling48k,
    {
      "audioSampling48k",
      "h245.IS13818AudioCapability.audioSampling48k",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioCapability audioSampling48k",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS13818AudioCapability_singleChannel,
    {
      "singleChannel",
      "h245.IS13818AudioCapability.singleChannel",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioCapability singleChannel",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS13818AudioCapability_twoChannels,
    {
      "twoChannels",
      "h245.IS13818AudioCapability.twoChannels",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioCapability twoChannels",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS13818AudioCapability_threeChannels2_1,
    {
      "threeChannels2_1",
      "h245.IS13818AudioCapability.threeChannels2_1",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioCapability threeChannels2_1",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS13818AudioCapability_threeChannels3_0,
    {
      "threeChannels3_0",
      "h245.IS13818AudioCapability.threeChannels3_0",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioCapability threeChannels3_0",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS13818AudioCapability_fourChannels2_0_2_0,
    {
      "fourChannels2_0_2_0",
      "h245.IS13818AudioCapability.fourChannels2_0_2_0",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioCapability fourChannels2_0_2_0",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS13818AudioCapability_fourChannels2_2,
    {
      "fourChannels2_2",
      "h245.IS13818AudioCapability.fourChannels2_2",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioCapability fourChannels2_2",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS13818AudioCapability_fourChannels3_1,
    {
      "fourChannels3_1",
      "h245.IS13818AudioCapability.fourChannels3_1",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioCapability fourChannels3_1",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS13818AudioCapability_fiveChannels3_0_2_0,
    {
      "fiveChannels3_0_2_0",
      "h245.IS13818AudioCapability.fiveChannels3_0_2_0",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioCapability fiveChannels3_0_2_0",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS13818AudioCapability_fiveChannels3_2,
    {
      "fiveChannels3_2",
      "h245.IS13818AudioCapability.fiveChannels3_2",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioCapability fiveChannels3_2",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS13818AudioCapability_lowFrequencyEnhancement,
    {
      "lowFrequencyEnhancement",
      "h245.IS13818AudioCapability.lowFrequencyEnhancement",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioCapability lowFrequencyEnhancement",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS13818AudioCapability_multilingual,
    {
      "multilingual",
      "h245.IS13818AudioCapability.multilingual",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioCapability multilingual",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS13818AudioCapability_bitRate,
    {
      "bitRate",
      "h245.IS13818AudioCapability.bitRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "IS13818AudioCapability bitRate",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_GSMAudioCapability_audioUnitSize,
    {
      "audioUnitSize",
      "h245.GSMAudioCapability.audioUnitSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "GSMAudioCapability audioUnitSize",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_GSMAudioCapability_comfortNoise,
    {
      "comfortNoise",
      "h245.GSMAudioCapability.comfortNoise",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "GSMAudioCapability comfortNoise",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_GSMAudioCapability_scrambled,
    {
      "scrambled",
      "h245.GSMAudioCapability.scrambled",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "GSMAudioCapability scrambled",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_DataProtocolCapability_v14buffered,
    {
      "v14buffered",
      "h245.DataProtocolCapability.v14buffered",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "DataProtocolCapability v14buffered",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_DataProtocolCapability_v42lapm,
    {
      "v42lapm",
      "h245.DataProtocolCapability.v42lapm",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "DataProtocolCapability v42lapm",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_DataProtocolCapability_hdlcFrameTunnelling,
    {
      "hdlcFrameTunnelling",
      "h245.DataProtocolCapability.hdlcFrameTunnelling",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "DataProtocolCapability hdlcFrameTunnelling",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_DataProtocolCapability_h310SeparateVCStack,
    {
      "h310SeparateVCStack",
      "h245.DataProtocolCapability.h310SeparateVCStack",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "DataProtocolCapability h310SeparateVCStack",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_DataProtocolCapability_h310SingleVCStack,
    {
      "h310SingleVCStack",
      "h245.DataProtocolCapability.h310SingleVCStack",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "DataProtocolCapability h310SingleVCStack",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_DataProtocolCapability_transparent,
    {
      "transparent",
      "h245.DataProtocolCapability.transparent",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "DataProtocolCapability transparent",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_DataProtocolCapability_segmentationAndReassembly,
    {
      "segmentationAndReassembly",
      "h245.DataProtocolCapability.segmentationAndReassembly",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "DataProtocolCapability segmentationAndReassembly",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_DataProtocolCapability_hdlcFrameTunnelingwSAR,
    {
      "hdlcFrameTunnelingwSAR",
      "h245.DataProtocolCapability.hdlcFrameTunnelingwSAR",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "DataProtocolCapability hdlcFrameTunnelingwSAR",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_DataProtocolCapability_v120,
    {
      "v120",
      "h245.DataProtocolCapability.v120",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "DataProtocolCapability v120",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_DataProtocolCapability_separateLANStack,
    {
      "separateLANStack",
      "h245.DataProtocolCapability.separateLANStack",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "DataProtocolCapability separateLANStack",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_DataProtocolCapability_tcp,
    {
      "tcp",
      "h245.DataProtocolCapability.tcp",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "DataProtocolCapability tcp",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_DataProtocolCapability_udp,
    {
      "udp",
      "h245.DataProtocolCapability.udp",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "DataProtocolCapability udp",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_V42bis_numberOfCodewords,
    {
      "numberOfCodewords",
      "h245.V42bis.numberOfCodewords",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "V42bis numberOfCodewords",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_V42bis_maximumStringLength,
    {
      "maximumStringLength",
      "h245.V42bis.maximumStringLength",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "V42bis maximumStringLength",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_T84Profile_t84Unrestricted,
    {
      "t84Unrestricted",
      "h245.T84Profile.t84Unrestricted",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "T84Profile t84Unrestricted",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_T38FaxProfile_fillBitRemoval,
    {
      "fillBitRemoval",
      "h245.T38FaxProfile.fillBitRemoval",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "T38FaxProfile fillBitRemoval",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_T38FaxProfile_transcodingJBIG,
    {
      "transcodingJBIG",
      "h245.T38FaxProfile.transcodingJBIG",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "T38FaxProfile transcodingJBIG",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_T38FaxProfile_transcodingMMR,
    {
      "transcodingMMR",
      "h245.T38FaxProfile.transcodingMMR",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "T38FaxProfile transcodingMMR",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_MediaEncryptionAlgorithm_algorithm,
    {
      "algorithm",
      "h245.MediaEncryptionAlgorithm.algorithm",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MediaEncryptionAlgorithm algorithm",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_UserInputCapability_basicString,
    {
      "basicString",
      "h245.UserInputCapability.basicString",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "UserInputCapability basicString",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_UserInputCapability_iA5String,
    {
      "iA5String",
      "h245.UserInputCapability.iA5String",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "UserInputCapability iA5String",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_UserInputCapability_generalString,
    {
      "generalString",
      "h245.UserInputCapability.generalString",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "UserInputCapability generalString",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_UserInputCapability_dtmf,
    {
      "dtmf",
      "h245.UserInputCapability.dtmf",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "UserInputCapability dtmf",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_UserInputCapability_hookflash,
    {
      "hookflash",
      "h245.UserInputCapability.hookflash",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "UserInputCapability hookflash",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_V75Parameters_audioHeaderPresent,
    {
      "audioHeaderPresent",
      "h245.V75Parameters.audioHeaderPresent",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "V75Parameters audioHeaderPresent",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_DataType_nullData,
    {
      "nullData",
      "h245.DataType.nullData",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "DataType nullData",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H222LogicalChannelParameters_resourceID,
    {
      "resourceID",
      "h245.H222LogicalChannelParameters.resourceID",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H222LogicalChannelParameters resourceID",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H222LogicalChannelParameters_subChannelID,
    {
      "subChannelID",
      "h245.H222LogicalChannelParameters.subChannelID",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H222LogicalChannelParameters subChannelID",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H222LogicalChannelParameters_pcr_pid,
    {
      "pcr_pid",
      "h245.H222LogicalChannelParameters.pcr_pid",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H222LogicalChannelParameters pcr_pid",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H222LogicalChannelParameters_programDescriptors,
    {
      "programDescriptors",
      "h245.H222LogicalChannelParameters.programDescriptors",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H222LogicalChannelParameters programDescriptors",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H222LogicalChannelParameters_streamDescriptors,
    {
      "streamDescriptors",
      "h245.H222LogicalChannelParameters.streamDescriptors",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H222LogicalChannelParameters streamDescriptors",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_CRCLength_crc8bit,
    {
      "crc8bit",
      "h245.CRCLength.crc8bit",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "CRCLength crc8bit",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_CRCLength_crc16bit,
    {
      "crc16bit",
      "h245.CRCLength.crc16bit",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "CRCLength crc16bit",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_CRCLength_crc32bit,
    {
      "crc32bit",
      "h245.CRCLength.crc32bit",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "CRCLength crc32bit",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_UnicastAddress_netBios,
    {
      "netBios",
      "h245.UnicastAddress.netBios",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "UnicastAddress netBios",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_UnicastAddress_nsap,
    {
      "nsap",
      "h245.UnicastAddress.nsap",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "UnicastAddress nsap",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_MulticastAddress_nsap,
    {
      "nsap",
      "h245.MulticastAddress.nsap",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MulticastAddress nsap",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_EscrowData_escrowID,
    {
      "escrowID",
      "h245.EscrowData.escrowID",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "EscrowData escrowID",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_EscrowData_escrowValue,
    {
      "escrowValue",
      "h245.EscrowData.escrowValue",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "EscrowData escrowValue",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_OpenLogicalChannelConfirm_forwardLogicalChannelNumber,
    {
      "forwardLogicalChannelNumber",
      "h245.OpenLogicalChannelConfirm.forwardLogicalChannelNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "OpenLogicalChannelConfirm forwardLogicalChannelNumber",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_CloseLogicalChannelAck_forwardLogicalChannelNumber,
    {
      "forwardLogicalChannelNumber",
      "h245.CloseLogicalChannelAck.forwardLogicalChannelNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CloseLogicalChannelAck forwardLogicalChannelNumber",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_RequestChannelCloseAck_forwardLogicalChannelNumber,
    {
      "forwardLogicalChannelNumber",
      "h245.RequestChannelCloseAck.forwardLogicalChannelNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RequestChannelCloseAck forwardLogicalChannelNumber",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_RequestChannelCloseRelease_forwardLogicalChannelNumber,
    {
      "forwardLogicalChannelNumber",
      "h245.RequestChannelCloseRelease.forwardLogicalChannelNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RequestChannelCloseRelease forwardLogicalChannelNumber",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_V76ModeParameters_suspendResumewAddress,
    {
      "suspendResumewAddress",
      "h245.V76ModeParameters.suspendResumewAddress",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "V76ModeParameters suspendResumewAddress",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_V76ModeParameters_suspendResumewoAddress,
    {
      "suspendResumewoAddress",
      "h245.V76ModeParameters.suspendResumewoAddress",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "V76ModeParameters suspendResumewoAddress",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS11172VideoMode_constrainedBitstream,
    {
      "constrainedBitstream",
      "h245.IS11172VideoMode.constrainedBitstream",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS11172VideoMode constrainedBitstream",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS11172VideoMode_videoBitRate,
    {
      "videoBitRate",
      "h245.IS11172VideoMode.videoBitRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "IS11172VideoMode videoBitRate",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS11172VideoMode_vbvBufferSize,
    {
      "vbvBufferSize",
      "h245.IS11172VideoMode.vbvBufferSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "IS11172VideoMode vbvBufferSize",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS11172VideoMode_samplesPerLine,
    {
      "samplesPerLine",
      "h245.IS11172VideoMode.samplesPerLine",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "IS11172VideoMode samplesPerLine",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS11172VideoMode_linesPerFrame,
    {
      "linesPerFrame",
      "h245.IS11172VideoMode.linesPerFrame",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "IS11172VideoMode linesPerFrame",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS11172VideoMode_pictureRate,
    {
      "pictureRate",
      "h245.IS11172VideoMode.pictureRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "IS11172VideoMode pictureRate",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_IS11172VideoMode_luminanceSampleRate,
    {
      "luminanceSampleRate",
      "h245.IS11172VideoMode.luminanceSampleRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "IS11172VideoMode luminanceSampleRate",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioMode_g711Alaw64k,
    {
      "g711Alaw64k",
      "h245.AudioMode.g711Alaw64k",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "AudioMode g711Alaw64k",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioMode_g711Alaw56k,
    {
      "g711Alaw56k",
      "h245.AudioMode.g711Alaw56k",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "AudioMode g711Alaw56k",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioMode_g711Ulaw64k,
    {
      "g711Ulaw64k",
      "h245.AudioMode.g711Ulaw64k",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "AudioMode g711Ulaw64k",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioMode_g711Ulaw56k,
    {
      "g711Ulaw56k",
      "h245.AudioMode.g711Ulaw56k",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "AudioMode g711Ulaw56k",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioMode_g722_64k,
    {
      "g722_64k",
      "h245.AudioMode.g722_64k",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "AudioMode g722_64k",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioMode_g722_56k,
    {
      "g722_56k",
      "h245.AudioMode.g722_56k",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "AudioMode g722_56k",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioMode_g722_48k,
    {
      "g722_48k",
      "h245.AudioMode.g722_48k",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "AudioMode g722_48k",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioMode_g728,
    {
      "g728",
      "h245.AudioMode.g728",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "AudioMode g728",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioMode_g729,
    {
      "g729",
      "h245.AudioMode.g729",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "AudioMode g729",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioMode_g729AnnexA,
    {
      "g729AnnexA",
      "h245.AudioMode.g729AnnexA",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "AudioMode g729AnnexA",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioMode_g729wAnnexB,
    {
      "g729wAnnexB",
      "h245.AudioMode.g729wAnnexB",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "AudioMode g729wAnnexB",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioMode_g729AnnexAwAnnexB,
    {
      "g729AnnexAwAnnexB",
      "h245.AudioMode.g729AnnexAwAnnexB",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "AudioMode g729AnnexAwAnnexB",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_EncryptionMode_h233Encryption,
    {
      "h233Encryption",
      "h245.EncryptionMode.h233Encryption",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "EncryptionMode h233Encryption",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_RoundTripDelayRequest_sequenceNumber,
    {
      "sequenceNumber",
      "h245.RoundTripDelayRequest.sequenceNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RoundTripDelayRequest sequenceNumber",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_RoundTripDelayResponse_sequenceNumber,
    {
      "sequenceNumber",
      "h245.RoundTripDelayResponse.sequenceNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RoundTripDelayResponse sequenceNumber",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceRequest_terminalListRequest,
    {
      "terminalListRequest",
      "h245.ConferenceRequest.terminalListRequest",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceRequest terminalListRequest",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceRequest_makeMeChair,
    {
      "makeMeChair",
      "h245.ConferenceRequest.makeMeChair",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceRequest makeMeChair",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceRequest_cancelMakeMeChair,
    {
      "cancelMakeMeChair",
      "h245.ConferenceRequest.cancelMakeMeChair",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceRequest cancelMakeMeChair",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceRequest_enterH243Password,
    {
      "enterH243Password",
      "h245.ConferenceRequest.enterH243Password",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceRequest enterH243Password",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceRequest_enterH243TerminalID,
    {
      "enterH243TerminalID",
      "h245.ConferenceRequest.enterH243TerminalID",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceRequest enterH243TerminalID",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceRequest_enterH243ConferenceID,
    {
      "enterH243ConferenceID",
      "h245.ConferenceRequest.enterH243ConferenceID",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceRequest enterH243ConferenceID",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceRequest_enterExtensionAddress,
    {
      "enterExtensionAddress",
      "h245.ConferenceRequest.enterExtensionAddress",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceRequest enterExtensionAddress",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceRequest_requestChairTokenOwner,
    {
      "requestChairTokenOwner",
      "h245.ConferenceRequest.requestChairTokenOwner",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceRequest requestChairTokenOwner",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceRequest_broadcastMyLogicalChannel,
    {
      "broadcastMyLogicalChannel",
      "h245.ConferenceRequest.broadcastMyLogicalChannel",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "ConferenceRequest broadcastMyLogicalChannel",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceRequest_requestAllTerminalIDs,
    {
      "requestAllTerminalIDs",
      "h245.ConferenceRequest.requestAllTerminalIDs",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceRequest requestAllTerminalIDs",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_Criteria_field,
    {
      "field",
      "h245.Criteria.field",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "Criteria field",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_Criteria_value,
    {
      "value",
      "h245.Criteria.value",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "Criteria value",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceResponse_videoCommandReject,
    {
      "videoCommandReject",
      "h245.ConferenceResponse.videoCommandReject",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceResponse videoCommandReject",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceResponse_terminalDropReject,
    {
      "terminalDropReject",
      "h245.ConferenceResponse.terminalDropReject",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceResponse terminalDropReject",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_RemoteMCRequest_masterActivate,
    {
      "masterActivate",
      "h245.RemoteMCRequest.masterActivate",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RemoteMCRequest masterActivate",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_RemoteMCRequest_slaveActivate,
    {
      "slaveActivate",
      "h245.RemoteMCRequest.slaveActivate",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RemoteMCRequest slaveActivate",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_RemoteMCRequest_deActivate,
    {
      "deActivate",
      "h245.RemoteMCRequest.deActivate",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RemoteMCRequest deActivate",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_RemoteMCResponse_accept,
    {
      "accept",
      "h245.RemoteMCResponse.accept",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RemoteMCResponse accept",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_DiallingInformation_infoNotAvailable,
    {
      "infoNotAvailable",
      "h245.DiallingInformation.infoNotAvailable",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "DiallingInformation infoNotAvailable",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_DiallingInformationNetworkType_n_isdn,
    {
      "n_isdn",
      "h245.DiallingInformationNetworkType.n_isdn",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "DiallingInformationNetworkType n_isdn",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_DiallingInformationNetworkType_gstn,
    {
      "gstn",
      "h245.DiallingInformationNetworkType.gstn",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "DiallingInformationNetworkType gstn",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConnectionIdentifier_channelTag,
    {
      "channelTag",
      "h245.ConnectionIdentifier.channelTag",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "ConnectionIdentifier channelTag",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConnectionIdentifier_sequenceNumber,
    {
      "sequenceNumber",
      "h245.ConnectionIdentifier.sequenceNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "ConnectionIdentifier sequenceNumber",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_SendTerminalCapabilitySet_genericRequest,
    {
      "genericRequest",
      "h245.SendTerminalCapabilitySet.genericRequest",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "SendTerminalCapabilitySet genericRequest",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_EncryptionCommand_encryptionSE,
    {
      "encryptionSE",
      "h245.EncryptionCommand.encryptionSE",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "EncryptionCommand encryptionSE",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_EncryptionCommand_encryptionIVRequest,
    {
      "encryptionIVRequest",
      "h245.EncryptionCommand.encryptionIVRequest",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "EncryptionCommand encryptionIVRequest",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_EndSessionCommand_disconnect,
    {
      "disconnect",
      "h245.EndSessionCommand.disconnect",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "EndSessionCommand disconnect",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceCommand_broadcastMyLogicalChannel,
    {
      "broadcastMyLogicalChannel",
      "h245.ConferenceCommand.broadcastMyLogicalChannel",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "ConferenceCommand broadcastMyLogicalChannel",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceCommand_cancelBroadcastMyLogicalChannel,
    {
      "cancelBroadcastMyLogicalChannel",
      "h245.ConferenceCommand.cancelBroadcastMyLogicalChannel",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "ConferenceCommand cancelBroadcastMyLogicalChannel",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceCommand_cancelMakeTerminalBroadcaster,
    {
      "cancelMakeTerminalBroadcaster",
      "h245.ConferenceCommand.cancelMakeTerminalBroadcaster",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceCommand cancelMakeTerminalBroadcaster",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceCommand_cancelSendThisSource,
    {
      "cancelSendThisSource",
      "h245.ConferenceCommand.cancelSendThisSource",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceCommand cancelSendThisSource",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceCommand_dropConference,
    {
      "dropConference",
      "h245.ConferenceCommand.dropConference",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceCommand dropConference",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_SubstituteConferenceIDCommand_conferenceIdentifier,
    {
      "conferenceIdentifier",
      "h245.SubstituteConferenceIDCommand.conferenceIdentifier",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "SubstituteConferenceIDCommand conferenceIdentifier",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_KeyProtectionMethod_secureChannel,
    {
      "secureChannel",
      "h245.KeyProtectionMethod.secureChannel",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "KeyProtectionMethod secureChannel",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_KeyProtectionMethod_sharedSecret,
    {
      "sharedSecret",
      "h245.KeyProtectionMethod.sharedSecret",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "KeyProtectionMethod sharedSecret",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_KeyProtectionMethod_certProtectedKey,
    {
      "certProtectedKey",
      "h245.KeyProtectionMethod.certProtectedKey",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "KeyProtectionMethod certProtectedKey",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceIndication_sbeNumber,
    {
      "sbeNumber",
      "h245.ConferenceIndication.sbeNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "ConferenceIndication sbeNumber",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceIndication_seenByAtLeastOneOther,
    {
      "seenByAtLeastOneOther",
      "h245.ConferenceIndication.seenByAtLeastOneOther",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceIndication seenByAtLeastOneOther",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceIndication_cancelSeenByAtLeastOneOther,
    {
      "cancelSeenByAtLeastOneOther",
      "h245.ConferenceIndication.cancelSeenByAtLeastOneOther",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceIndication cancelSeenByAtLeastOneOther",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceIndication_seenByAll,
    {
      "seenByAll",
      "h245.ConferenceIndication.seenByAll",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceIndication seenByAll",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceIndication_cancelSeenByAll,
    {
      "cancelSeenByAll",
      "h245.ConferenceIndication.cancelSeenByAll",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceIndication cancelSeenByAll",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceIndication_requestForFloor,
    {
      "requestForFloor",
      "h245.ConferenceIndication.requestForFloor",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceIndication requestForFloor",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ConferenceIndication_withdrawChairToken,
    {
      "withdrawChairToken",
      "h245.ConferenceIndication.withdrawChairToken",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceIndication withdrawChairToken",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H223SkewIndication_logicalChannelNumber1,
    {
      "logicalChannelNumber1",
      "h245.H223SkewIndication.logicalChannelNumber1",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H223SkewIndication logicalChannelNumber1",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H223SkewIndication_logicalChannelNumber2,
    {
      "logicalChannelNumber2",
      "h245.H223SkewIndication.logicalChannelNumber2",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H223SkewIndication logicalChannelNumber2",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H223SkewIndication_skew,
    {
      "skew",
      "h245.H223SkewIndication.skew",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H223SkewIndication skew",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H2250MaximumSkewIndication_logicalChannelNumber1,
    {
      "logicalChannelNumber1",
      "h245.H2250MaximumSkewIndication.logicalChannelNumber1",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H2250MaximumSkewIndication logicalChannelNumber1",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H2250MaximumSkewIndication_logicalChannelNumber2,
    {
      "logicalChannelNumber2",
      "h245.H2250MaximumSkewIndication.logicalChannelNumber2",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H2250MaximumSkewIndication logicalChannelNumber2",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H2250MaximumSkewIndication_maximumSkew,
    {
      "maximumSkew",
      "h245.H2250MaximumSkewIndication.maximumSkew",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H2250MaximumSkewIndication maximumSkew",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_VendorIdentification_productNumber,
    {
      "productNumber",
      "h245.VendorIdentification.productNumber",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "VendorIdentification productNumber",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_VendorIdentification_versionNumber,
    {
      "versionNumber",
      "h245.VendorIdentification.versionNumber",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "VendorIdentification versionNumber",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_UserInputIndication_alphanumeric,
    {
      "alphanumeric",
      "h245.UserInputIndication.alphanumeric",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "UserInputIndication alphanumeric",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_NonStandardIdentifier_h221NonStandard_t35CountryCode,
    {
      "t35CountryCode",
      "h245.NonStandardIdentifier_h221NonStandard.t35CountryCode",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "NonStandardIdentifier_h221NonStandard t35CountryCode",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_NonStandardIdentifier_h221NonStandard_t35Extension,
    {
      "t35Extension",
      "h245.NonStandardIdentifier_h221NonStandard.t35Extension",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "NonStandardIdentifier_h221NonStandard t35Extension",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_NonStandardIdentifier_h221NonStandard_manufacturerCode,
    {
      "manufacturerCode",
      "h245.NonStandardIdentifier_h221NonStandard.manufacturerCode",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "NonStandardIdentifier_h221NonStandard manufacturerCode",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_MasterSlaveDeterminationAck_decision_master,
    {
      "master",
      "h245.MasterSlaveDeterminationAck_decision.master",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MasterSlaveDeterminationAck_decision master",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_MasterSlaveDeterminationAck_decision_slave,
    {
      "slave",
      "h245.MasterSlaveDeterminationAck_decision.slave",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MasterSlaveDeterminationAck_decision slave",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_MasterSlaveDeterminationReject_cause_identicalNumbers,
    {
      "identicalNumbers",
      "h245.MasterSlaveDeterminationReject_cause.identicalNumbers",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MasterSlaveDeterminationReject_cause identicalNumbers",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_TerminalCapabilitySetReject_cause_unspecified,
    {
      "unspecified",
      "h245.TerminalCapabilitySetReject_cause.unspecified",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "TerminalCapabilitySetReject_cause unspecified",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_TerminalCapabilitySetReject_cause_undefinedTableEntryUsed,
    {
      "undefinedTableEntryUsed",
      "h245.TerminalCapabilitySetReject_cause.undefinedTableEntryUsed",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "TerminalCapabilitySetReject_cause undefinedTableEntryUsed",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_TerminalCapabilitySetReject_cause_descriptorCapacityExceeded,
    {
      "descriptorCapacityExceeded",
      "h245.TerminalCapabilitySetReject_cause.descriptorCapacityExceeded",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "TerminalCapabilitySetReject_cause descriptorCapacityExceeded",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_Capability_h233EncryptionReceiveCapability_h233IVResponseTime,
    {
      "h233IVResponseTime",
      "h245.Capability_h233EncryptionReceiveCapability.h233IVResponseTime",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "Capability_h233EncryptionReceiveCapability h233IVResponseTime",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_VCCapability_aal1_nullClockRecovery,
    {
      "nullClockRecovery",
      "h245.VCCapability_aal1.nullClockRecovery",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "VCCapability_aal1 nullClockRecovery",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_VCCapability_aal1_srtsClockRecovery,
    {
      "srtsClockRecovery",
      "h245.VCCapability_aal1.srtsClockRecovery",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "VCCapability_aal1 srtsClockRecovery",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_VCCapability_aal1_adaptiveClockRecovery,
    {
      "adaptiveClockRecovery",
      "h245.VCCapability_aal1.adaptiveClockRecovery",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "VCCapability_aal1 adaptiveClockRecovery",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_VCCapability_aal1_nullErrorCorrection,
    {
      "nullErrorCorrection",
      "h245.VCCapability_aal1.nullErrorCorrection",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "VCCapability_aal1 nullErrorCorrection",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_VCCapability_aal1_longInterleaver,
    {
      "longInterleaver",
      "h245.VCCapability_aal1.longInterleaver",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "VCCapability_aal1 longInterleaver",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_VCCapability_aal1_shortInterleaver,
    {
      "shortInterleaver",
      "h245.VCCapability_aal1.shortInterleaver",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "VCCapability_aal1 shortInterleaver",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_VCCapability_aal1_errorCorrectionOnly,
    {
      "errorCorrectionOnly",
      "h245.VCCapability_aal1.errorCorrectionOnly",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "VCCapability_aal1 errorCorrectionOnly",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_VCCapability_aal1_structuredDataTransfer,
    {
      "structuredDataTransfer",
      "h245.VCCapability_aal1.structuredDataTransfer",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "VCCapability_aal1 structuredDataTransfer",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_VCCapability_aal1_partiallyFilledCells,
    {
      "partiallyFilledCells",
      "h245.VCCapability_aal1.partiallyFilledCells",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "VCCapability_aal1 partiallyFilledCells",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_VCCapability_aal5_forwardMaximumSDUSize,
    {
      "forwardMaximumSDUSize",
      "h245.VCCapability_aal5.forwardMaximumSDUSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "VCCapability_aal5 forwardMaximumSDUSize",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_VCCapability_aal5_backwardMaximumSDUSize,
    {
      "backwardMaximumSDUSize",
      "h245.VCCapability_aal5.backwardMaximumSDUSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "VCCapability_aal5 backwardMaximumSDUSize",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H223Capability_h223MultiplexTableCapability_basic,
    {
      "basic",
      "h245.H223Capability_h223MultiplexTableCapability.basic",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223Capability_h223MultiplexTableCapability basic",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H223Capability_mobileOperationTransmitCapability_modeChangeCapability,
    {
      "modeChangeCapability",
      "h245.H223Capability_mobileOperationTransmitCapability.modeChangeCapability",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223Capability_mobileOperationTransmitCapability modeChangeCapability",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H223Capability_mobileOperationTransmitCapability_h223AnnexA,
    {
      "h223AnnexA",
      "h245.H223Capability_mobileOperationTransmitCapability.h223AnnexA",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223Capability_mobileOperationTransmitCapability h223AnnexA",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H223Capability_mobileOperationTransmitCapability_h223AnnexADoubleFlag,
    {
      "h223AnnexADoubleFlag",
      "h245.H223Capability_mobileOperationTransmitCapability.h223AnnexADoubleFlag",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223Capability_mobileOperationTransmitCapability h223AnnexADoubleFlag",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H223Capability_mobileOperationTransmitCapability_h223AnnexB,
    {
      "h223AnnexB",
      "h245.H223Capability_mobileOperationTransmitCapability.h223AnnexB",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223Capability_mobileOperationTransmitCapability h223AnnexB",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H223Capability_mobileOperationTransmitCapability_h223AnnexBwithHeader,
    {
      "h223AnnexBwithHeader",
      "h245.H223Capability_mobileOperationTransmitCapability.h223AnnexBwithHeader",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223Capability_mobileOperationTransmitCapability h223AnnexBwithHeader",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H2250Capability_mcCapability_centralizedConferenceMC,
    {
      "centralizedConferenceMC",
      "h245.H2250Capability_mcCapability.centralizedConferenceMC",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H2250Capability_mcCapability centralizedConferenceMC",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_H2250Capability_mcCapability_decentralizedConferenceMC,
    {
      "decentralizedConferenceMC",
      "h245.H2250Capability_mcCapability.decentralizedConferenceMC",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H2250Capability_mcCapability decentralizedConferenceMC",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_ArrayOf_CapabilityTableEntryNumber_array,
    {
      "array",
      "h245.ArrayOf_CapabilityTableEntryNumber.array",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "ArrayOf_CapabilityTableEntryNumber array",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_RTPH263VideoRedundancyEncoding_frameToThreadMapping_roundrobin,
    {
      "roundrobin",
      "h245.RTPH263VideoRedundancyEncoding_frameToThreadMapping.roundrobin",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RTPH263VideoRedundancyEncoding_frameToThreadMapping roundrobin",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_RTPH263VideoRedundancyEncoding_containedThreads_array,
    {
      "array",
      "h245.RTPH263VideoRedundancyEncoding_containedThreads.array",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RTPH263VideoRedundancyEncoding_containedThreads array",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_RTPH263VideoRedundancyFrameMapping_frameSequence_array,
    {
      "array",
      "h245.RTPH263VideoRedundancyFrameMapping_frameSequence.array",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RTPH263VideoRedundancyFrameMapping_frameSequence array",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_RefPictureSelection_additionalPictureMemory_sqcifAdditionalPictureMemory,
    {
      "sqcifAdditionalPictureMemory",
      "h245.RefPictureSelection_additionalPictureMemory.sqcifAdditionalPictureMemory",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RefPictureSelection_additionalPictureMemory sqcifAdditionalPictureMemory",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_RefPictureSelection_additionalPictureMemory_qcifAdditionalPictureMemory,
    {
      "qcifAdditionalPictureMemory",
      "h245.RefPictureSelection_additionalPictureMemory.qcifAdditionalPictureMemory",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RefPictureSelection_additionalPictureMemory qcifAdditionalPictureMemory",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_RefPictureSelection_additionalPictureMemory_cifAdditionalPictureMemory,
    {
      "cifAdditionalPictureMemory",
      "h245.RefPictureSelection_additionalPictureMemory.cifAdditionalPictureMemory",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RefPictureSelection_additionalPictureMemory cifAdditionalPictureMemory",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_RefPictureSelection_additionalPictureMemory_cif4AdditionalPictureMemory,
    {
      "cif4AdditionalPictureMemory",
      "h245.RefPictureSelection_additionalPictureMemory.cif4AdditionalPictureMemory",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RefPictureSelection_additionalPictureMemory cif4AdditionalPictureMemory",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_RefPictureSelection_additionalPictureMemory_cif16AdditionalPictureMemory,
    {
      "cif16AdditionalPictureMemory",
      "h245.RefPictureSelection_additionalPictureMemory.cif16AdditionalPictureMemory",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RefPictureSelection_additionalPictureMemory cif16AdditionalPictureMemory",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_RefPictureSelection_additionalPictureMemory_bigCpfAdditionalPictureMemory,
    {
      "bigCpfAdditionalPictureMemory",
      "h245.RefPictureSelection_additionalPictureMemory.bigCpfAdditionalPictureMemory",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RefPictureSelection_additionalPictureMemory bigCpfAdditionalPictureMemory",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_RefPictureSelection_videoBackChannelSend_none,
    {
      "none",
      "h245.RefPictureSelection_videoBackChannelSend.none",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RefPictureSelection_videoBackChannelSend none",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_RefPictureSelection_videoBackChannelSend_ackMessageOnly,
    {
      "ackMessageOnly",
      "h245.RefPictureSelection_videoBackChannelSend.ackMessageOnly",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RefPictureSelection_videoBackChannelSend ackMessageOnly",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_RefPictureSelection_videoBackChannelSend_nackMessageOnly,
    {
      "nackMessageOnly",
      "h245.RefPictureSelection_videoBackChannelSend.nackMessageOnly",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RefPictureSelection_videoBackChannelSend nackMessageOnly",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_RefPictureSelection_videoBackChannelSend_ackOrNackMessageOnly,
    {
      "ackOrNackMessageOnly",
      "h245.RefPictureSelection_videoBackChannelSend.ackOrNackMessageOnly",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RefPictureSelection_videoBackChannelSend ackOrNackMessageOnly",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_RefPictureSelection_videoBackChannelSend_ackAndNackMessage,
    {
      "ackAndNackMessage",
      "h245.RefPictureSelection_videoBackChannelSend.ackAndNackMessage",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RefPictureSelection_videoBackChannelSend ackAndNackMessage",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_CustomPictureFormat_pixelAspectInformation_anyPixelAspectRatio,
    {
      "anyPixelAspectRatio",
      "h245.CustomPictureFormat_pixelAspectInformation.anyPixelAspectRatio",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "CustomPictureFormat_pixelAspectInformation anyPixelAspectRatio",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioCapability_g7231_maxAl_sduAudioFrames,
    {
      "maxAl_sduAudioFrames",
      "h245.AudioCapability_g7231.maxAl_sduAudioFrames",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "AudioCapability_g7231 maxAl_sduAudioFrames",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_AudioCapability_g7231_silenceSuppression,
    {
      "silenceSuppression",
      "h245.AudioCapability_g7231.silenceSuppression",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "AudioCapability_g7231 silenceSuppression",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_G7231AnnexCCapability_g723AnnexCAudioMode_highRateMode0,
    {
      "highRateMode0",
      "h245.G7231AnnexCCapability_g723AnnexCAudioMode.highRateMode0",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "G7231AnnexCCapability_g723AnnexCAudioMode highRateMode0",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_G7231AnnexCCapability_g723AnnexCAudioMode_highRateMode1,
    {
      "highRateMode1",
      "h245.G7231AnnexCCapability_g723AnnexCAudioMode.highRateMode1",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "G7231AnnexCCapability_g723AnnexCAudioMode highRateMode1",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_G7231AnnexCCapability_g723AnnexCAudioMode_lowRateMode0,
    {
      "lowRateMode0",
      "h245.G7231AnnexCCapability_g723AnnexCAudioMode.lowRateMode0",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "G7231AnnexCCapability_g723AnnexCAudioMode lowRateMode0",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_G7231AnnexCCapability_g723AnnexCAudioMode_lowRateMode1,
    {
      "lowRateMode1",
      "h245.G7231AnnexCCapability_g723AnnexCAudioMode.lowRateMode1",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "G7231AnnexCCapability_g723AnnexCAudioMode lowRateMode1",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_G7231AnnexCCapability_g723AnnexCAudioMode_sidMode0,
    {
      "sidMode0",
      "h245.G7231AnnexCCapability_g723AnnexCAudioMode.sidMode0",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "G7231AnnexCCapability_g723AnnexCAudioMode sidMode0",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_G7231AnnexCCapability_g723AnnexCAudioMode_sidMode1,
    {
      "sidMode1",
      "h245.G7231AnnexCCapability_g723AnnexCAudioMode.sidMode1",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "G7231AnnexCCapability_g723AnnexCAudioMode sidMode1",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_DataApplicationCapability_application_dsvdControl,
    {
      "dsvdControl",
      "h245.DataApplicationCapability_application.dsvdControl",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "DataApplicationCapability_application dsvdControl",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_T84Profile_t84Restricted_qcif,
    {
      "qcif",
      "h245.T84Profile_t84Restricted.qcif",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "T84Profile_t84Restricted qcif",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_T84Profile_t84Restricted_cif,
    {
      "cif",
      "h245.T84Profile_t84Restricted.cif",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "T84Profile_t84Restricted cif",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_T84Profile_t84Restricted_ccir601Seq,
    {
      "ccir601Seq",
      "h245.T84Profile_t84Restricted.ccir601Seq",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "T84Profile_t84Restricted ccir601Seq",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_T84Profile_t84Restricted_ccir601Prog,
    {
      "ccir601Prog",
      "h245.T84Profile_t84Restricted.ccir601Prog",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "T84Profile_t84Restricted ccir601Prog",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_T84Profile_t84Restricted_hdtvSeq,
    {
      "hdtvSeq",
      "h245.T84Profile_t84Restricted.hdtvSeq",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "T84Profile_t84Restricted hdtvSeq",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_T84Profile_t84Restricted_hdtvProg,
    {
      "hdtvProg",
      "h245.T84Profile_t84Restricted.hdtvProg",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "T84Profile_t84Restricted hdtvProg",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_T84Profile_t84Restricted_g3FacsMH200x100,
    {
      "g3FacsMH200x100",
      "h245.T84Profile_t84Restricted.g3FacsMH200x100",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "T84Profile_t84Restricted g3FacsMH200x100",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_T84Profile_t84Restricted_g3FacsMH200x200,
    {
      "g3FacsMH200x200",
      "h245.T84Profile_t84Restricted.g3FacsMH200x200",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "T84Profile_t84Restricted g3FacsMH200x200",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_T84Profile_t84Restricted_g4FacsMMR200x100,
    {
      "g4FacsMMR200x100",
      "h245.T84Profile_t84Restricted.g4FacsMMR200x100",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "T84Profile_t84Restricted g4FacsMMR200x100",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_T84Profile_t84Restricted_g4FacsMMR200x200,
    {
      "g4FacsMMR200x200",
      "h245.T84Profile_t84Restricted.g4FacsMMR200x200",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "T84Profile_t84Restricted g4FacsMMR200x200",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_T84Profile_t84Restricted_jbig200x200Seq,
    {
      "jbig200x200Seq",
      "h245.T84Profile_t84Restricted.jbig200x200Seq",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "T84Profile_t84Restricted jbig200x200Seq",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_T84Profile_t84Restricted_jbig200x200Prog,
    {
      "jbig200x200Prog",
      "h245.T84Profile_t84Restricted.jbig200x200Prog",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "T84Profile_t84Restricted jbig200x200Prog",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_T84Profile_t84Restricted_jbig300x300Seq,
    {
      "jbig300x300Seq",
      "h245.T84Profile_t84Restricted.jbig300x300Seq",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "T84Profile_t84Restricted jbig300x300Seq",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_T84Profile_t84Restricted_jbig300x300Prog,
    {
      "jbig300x300Prog",
      "h245.T84Profile_t84Restricted.jbig300x300Prog",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "T84Profile_t84Restricted jbig300x300Prog",
    }
  },
  {
  &h245Cont.h245_0.hf_h245_T84Profile_t84Restricted_digPhotoLow,
    {
      "digPhotoLow",
      "h245.T84Profile_t84Restricted.digPhotoLow",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "T84Profile_t84Restricted digPhotoLow",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_T84Profile_t84Restricted_digPhotoMedSeq,
    {
      "digPhotoMedSeq",
      "h245.T84Profile_t84Restricted.digPhotoMedSeq",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "T84Profile_t84Restricted digPhotoMedSeq",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_T84Profile_t84Restricted_digPhotoMedProg,
    {
      "digPhotoMedProg",
      "h245.T84Profile_t84Restricted.digPhotoMedProg",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "T84Profile_t84Restricted digPhotoMedProg",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_T84Profile_t84Restricted_digPhotoHighSeq,
    {
      "digPhotoHighSeq",
      "h245.T84Profile_t84Restricted.digPhotoHighSeq",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "T84Profile_t84Restricted digPhotoHighSeq",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_T84Profile_t84Restricted_digPhotoHighProg,
    {
      "digPhotoHighProg",
      "h245.T84Profile_t84Restricted.digPhotoHighProg",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "T84Profile_t84Restricted digPhotoHighProg",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NetworkAccessParameters_distribution_unicast,
    {
      "unicast",
      "h245.NetworkAccessParameters_distribution.unicast",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NetworkAccessParameters_distribution unicast",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NetworkAccessParameters_distribution_multicast,
    {
      "multicast",
      "h245.NetworkAccessParameters_distribution.multicast",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NetworkAccessParameters_distribution multicast",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NetworkAccessParameters_networkAddress_e164Address,
    {
      "e164Address",
      "h245.NetworkAccessParameters_networkAddress.e164Address",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NetworkAccessParameters_networkAddress e164Address",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NetworkAccessParameters_t120SetupProcedure_originateCall,
    {
      "originateCall",
      "h245.NetworkAccessParameters_t120SetupProcedure.originateCall",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NetworkAccessParameters_t120SetupProcedure originateCall",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NetworkAccessParameters_t120SetupProcedure_waitForCall,
    {
      "waitForCall",
      "h245.NetworkAccessParameters_t120SetupProcedure.waitForCall",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NetworkAccessParameters_t120SetupProcedure waitForCall",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NetworkAccessParameters_t120SetupProcedure_issueQuery,
    {
      "issueQuery",
      "h245.NetworkAccessParameters_t120SetupProcedure.issueQuery",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NetworkAccessParameters_t120SetupProcedure issueQuery",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_Q2931Address_address_internationalNumber,
    {
      "internationalNumber",
      "h245.Q2931Address_address.internationalNumber",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "Q2931Address_address internationalNumber",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_Q2931Address_address_nsapAddress,
    {
      "nsapAddress",
      "h245.Q2931Address_address.nsapAddress",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "Q2931Address_address nsapAddress",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223LogicalChannelParameters_adaptationLayerType_al1Framed,
    {
      "al1Framed",
      "h245.H223LogicalChannelParameters_adaptationLayerType.al1Framed",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223LogicalChannelParameters_adaptationLayerType al1Framed",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223LogicalChannelParameters_adaptationLayerType_al1NotFramed,
    {
      "al1NotFramed",
      "h245.H223LogicalChannelParameters_adaptationLayerType.al1NotFramed",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223LogicalChannelParameters_adaptationLayerType al1NotFramed",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223LogicalChannelParameters_adaptationLayerType_al2WithoutSequenceNumbers,
    {
      "al2WithoutSequenceNumbers",
      "h245.H223LogicalChannelParameters_adaptationLayerType.al2WithoutSequenceNumbers",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223LogicalChannelParameters_adaptationLayerType al2WithoutSequenceNumbers",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223LogicalChannelParameters_adaptationLayerType_al2WithSequenceNumbers,
    {
      "al2WithSequenceNumbers",
      "h245.H223LogicalChannelParameters_adaptationLayerType.al2WithSequenceNumbers",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223LogicalChannelParameters_adaptationLayerType al2WithSequenceNumbers",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223AL1MParameters_transferMode_framed,
    {
      "framed",
      "h245.H223AL1MParameters_transferMode.framed",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AL1MParameters_transferMode framed",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223AL1MParameters_transferMode_unframed,
    {
      "unframed",
      "h245.H223AL1MParameters_transferMode.unframed",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AL1MParameters_transferMode unframed",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223AL1MParameters_headerFEC_sebch16_7,
    {
      "sebch16_7",
      "h245.H223AL1MParameters_headerFEC.sebch16_7",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AL1MParameters_headerFEC sebch16_7",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223AL1MParameters_headerFEC_golay24_12,
    {
      "golay24_12",
      "h245.H223AL1MParameters_headerFEC.golay24_12",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AL1MParameters_headerFEC golay24_12",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223AL1MParameters_crcLength_crc4bit,
    {
      "crc4bit",
      "h245.H223AL1MParameters_crcLength.crc4bit",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AL1MParameters_crcLength crc4bit",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223AL1MParameters_crcLength_crc12bit,
    {
      "crc12bit",
      "h245.H223AL1MParameters_crcLength.crc12bit",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AL1MParameters_crcLength crc12bit",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223AL1MParameters_crcLength_crc20bit,
    {
      "crc20bit",
      "h245.H223AL1MParameters_crcLength.crc20bit",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AL1MParameters_crcLength crc20bit",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223AL1MParameters_crcLength_crc28bit,
    {
      "crc28bit",
      "h245.H223AL1MParameters_crcLength.crc28bit",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AL1MParameters_crcLength crc28bit",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223AL1MParameters_arqType_noArq,
    {
      "noArq",
      "h245.H223AL1MParameters_arqType.noArq",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AL1MParameters_arqType noArq",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223AL2MParameters_headerFEC_sebch16_5,
    {
      "sebch16_5",
      "h245.H223AL2MParameters_headerFEC.sebch16_5",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AL2MParameters_headerFEC sebch16_5",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223AL2MParameters_headerFEC_golay24_12,
    {
      "golay24_12",
      "h245.H223AL2MParameters_headerFEC.golay24_12",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AL2MParameters_headerFEC golay24_12",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223AL3MParameters_headerFormat_sebch16_7,
    {
      "sebch16_7",
      "h245.H223AL3MParameters_headerFormat.sebch16_7",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AL3MParameters_headerFormat sebch16_7",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223AL3MParameters_headerFormat_golay24_12,
    {
      "golay24_12",
      "h245.H223AL3MParameters_headerFormat.golay24_12",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AL3MParameters_headerFormat golay24_12",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223AL3MParameters_crcLength_crc4bit,
    {
      "crc4bit",
      "h245.H223AL3MParameters_crcLength.crc4bit",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AL3MParameters_crcLength crc4bit",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223AL3MParameters_crcLength_crc12bit,
    {
      "crc12bit",
      "h245.H223AL3MParameters_crcLength.crc12bit",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AL3MParameters_crcLength crc12bit",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223AL3MParameters_crcLength_crc20bit,
    {
      "crc20bit",
      "h245.H223AL3MParameters_crcLength.crc20bit",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AL3MParameters_crcLength crc20bit",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223AL3MParameters_crcLength_crc28bit,
    {
      "crc28bit",
      "h245.H223AL3MParameters_crcLength.crc28bit",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AL3MParameters_crcLength crc28bit",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223AL3MParameters_arqType_noArq,
    {
      "noArq",
      "h245.H223AL3MParameters_arqType.noArq",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AL3MParameters_arqType noArq",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223AnnexCArqParameters_numberOfRetransmissions_finite,
    {
      "finite",
      "h245.H223AnnexCArqParameters_numberOfRetransmissions.finite",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H223AnnexCArqParameters_numberOfRetransmissions finite",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223AnnexCArqParameters_numberOfRetransmissions_infinite,
    {
      "infinite",
      "h245.H223AnnexCArqParameters_numberOfRetransmissions.infinite",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AnnexCArqParameters_numberOfRetransmissions infinite",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_V76LogicalChannelParameters_suspendResume_noSuspendResume,
    {
      "noSuspendResume",
      "h245.V76LogicalChannelParameters_suspendResume.noSuspendResume",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "V76LogicalChannelParameters_suspendResume noSuspendResume",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_V76LogicalChannelParameters_suspendResume_suspendResumewAddress,
    {
      "suspendResumewAddress",
      "h245.V76LogicalChannelParameters_suspendResume.suspendResumewAddress",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "V76LogicalChannelParameters_suspendResume suspendResumewAddress",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_V76LogicalChannelParameters_suspendResume_suspendResumewoAddress,
    {
      "suspendResumewoAddress",
      "h245.V76LogicalChannelParameters_suspendResume.suspendResumewoAddress",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "V76LogicalChannelParameters_suspendResume suspendResumewoAddress",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_V76LogicalChannelParameters_mode_uNERM,
    {
      "uNERM",
      "h245.V76LogicalChannelParameters_mode.uNERM",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "V76LogicalChannelParameters_mode uNERM",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H2250LogicalChannelParameters_mediaPacketization_h261aVideoPacketization,
    {
      "h261aVideoPacketization",
      "h245.H2250LogicalChannelParameters_mediaPacketization.h261aVideoPacketization",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H2250LogicalChannelParameters_mediaPacketization h261aVideoPacketization",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_RTPPayloadType_payloadDescriptor_rfc_number,
    {
      "rfc_number",
      "h245.RTPPayloadType_payloadDescriptor.rfc_number",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RTPPayloadType_payloadDescriptor rfc_number",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_RTPPayloadType_payloadDescriptor_oid,
    {
      "oid",
      "h245.RTPPayloadType_payloadDescriptor.oid",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RTPPayloadType_payloadDescriptor oid",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_UnicastAddress_iPAddress_network,
    {
      "network",
      "h245.UnicastAddress_iPAddress.network",
      FT_IPv4, 
      BASE_NONE, 
      NULL,
      0x0,
      "UnicastAddress_iPAddress network",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_UnicastAddress_iPAddress_tsapIdentifier,
    {
      "tsapIdentifier",
      "h245.UnicastAddress_iPAddress.tsapIdentifier",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "UnicastAddress_iPAddress tsapIdentifier",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_UnicastAddress_iPXAddress_node,
    {
      "node",
      "h245.UnicastAddress_iPXAddress.node",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "UnicastAddress_iPXAddress node",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_UnicastAddress_iPXAddress_netnum,
    {
      "netnum",
      "h245.UnicastAddress_iPXAddress.netnum",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "UnicastAddress_iPXAddress netnum",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_UnicastAddress_iPXAddress_tsapIdentifier,
    {
      "tsapIdentifier",
      "h245.UnicastAddress_iPXAddress.tsapIdentifier",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "UnicastAddress_iPXAddress tsapIdentifier",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_UnicastAddress_iP6Address_network,
    {
      "network",
      "h245.UnicastAddress_iP6Address.network",
      FT_IPv6, 
      BASE_NONE, 
      NULL,
      0x0,
      "UnicastAddress_iP6Address network",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_UnicastAddress_iP6Address_tsapIdentifier,
    {
      "tsapIdentifier",
      "h245.UnicastAddress_iP6Address.tsapIdentifier",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "UnicastAddress_iP6Address tsapIdentifier",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MulticastAddress_iPAddress_network,
    {
      "network",
      "h245.MulticastAddress_iPAddress.network",
      FT_IPv4, 
      BASE_NONE, 
      NULL,
      0x0,
      "MulticastAddress_iPAddress network",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MulticastAddress_iPAddress_tsapIdentifier,
    {
      "tsapIdentifier",
      "h245.MulticastAddress_iPAddress.tsapIdentifier",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MulticastAddress_iPAddress tsapIdentifier",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MulticastAddress_iP6Address_network,
    {
      "network",
      "h245.MulticastAddress_iP6Address.network",
      FT_IPv6, 
      BASE_NONE, 
      NULL,
      0x0,
      "MulticastAddress_iP6Address network",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MulticastAddress_iP6Address_tsapIdentifier,
    {
      "tsapIdentifier",
      "h245.MulticastAddress_iP6Address.tsapIdentifier",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MulticastAddress_iP6Address tsapIdentifier",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_OpenLogicalChannelReject_cause_unspecified,
    {
      "unspecified",
      "h245.OpenLogicalChannelReject_cause.unspecified",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "OpenLogicalChannelReject_cause unspecified",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_OpenLogicalChannelReject_cause_unsuitableReverseParameters,
    {
      "unsuitableReverseParameters",
      "h245.OpenLogicalChannelReject_cause.unsuitableReverseParameters",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "OpenLogicalChannelReject_cause unsuitableReverseParameters",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_OpenLogicalChannelReject_cause_dataTypeNotSupported,
    {
      "dataTypeNotSupported",
      "h245.OpenLogicalChannelReject_cause.dataTypeNotSupported",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "OpenLogicalChannelReject_cause dataTypeNotSupported",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_OpenLogicalChannelReject_cause_dataTypeNotAvailable,
    {
      "dataTypeNotAvailable",
      "h245.OpenLogicalChannelReject_cause.dataTypeNotAvailable",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "OpenLogicalChannelReject_cause dataTypeNotAvailable",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_OpenLogicalChannelReject_cause_unknownDataType,
    {
      "unknownDataType",
      "h245.OpenLogicalChannelReject_cause.unknownDataType",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "OpenLogicalChannelReject_cause unknownDataType",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_OpenLogicalChannelReject_cause_dataTypeALCombinationNotSupported,
    {
      "dataTypeALCombinationNotSupported",
      "h245.OpenLogicalChannelReject_cause.dataTypeALCombinationNotSupported",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "OpenLogicalChannelReject_cause dataTypeALCombinationNotSupported",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_OpenLogicalChannelReject_cause_multicastChannelNotAllowed,
    {
      "multicastChannelNotAllowed",
      "h245.OpenLogicalChannelReject_cause.multicastChannelNotAllowed",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "OpenLogicalChannelReject_cause multicastChannelNotAllowed",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_OpenLogicalChannelReject_cause_insufficientBandwidth,
    {
      "insufficientBandwidth",
      "h245.OpenLogicalChannelReject_cause.insufficientBandwidth",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "OpenLogicalChannelReject_cause insufficientBandwidth",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_OpenLogicalChannelReject_cause_separateStackEstablishmentFailed,
    {
      "separateStackEstablishmentFailed",
      "h245.OpenLogicalChannelReject_cause.separateStackEstablishmentFailed",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "OpenLogicalChannelReject_cause separateStackEstablishmentFailed",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_OpenLogicalChannelReject_cause_invalidSessionID,
    {
      "invalidSessionID",
      "h245.OpenLogicalChannelReject_cause.invalidSessionID",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "OpenLogicalChannelReject_cause invalidSessionID",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_OpenLogicalChannelReject_cause_masterSlaveConflict,
    {
      "masterSlaveConflict",
      "h245.OpenLogicalChannelReject_cause.masterSlaveConflict",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "OpenLogicalChannelReject_cause masterSlaveConflict",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_OpenLogicalChannelReject_cause_waitForCommunicationMode,
    {
      "waitForCommunicationMode",
      "h245.OpenLogicalChannelReject_cause.waitForCommunicationMode",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "OpenLogicalChannelReject_cause waitForCommunicationMode",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_OpenLogicalChannelReject_cause_invalidDependentChannel,
    {
      "invalidDependentChannel",
      "h245.OpenLogicalChannelReject_cause.invalidDependentChannel",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "OpenLogicalChannelReject_cause invalidDependentChannel",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_OpenLogicalChannelReject_cause_replacementForRejected,
    {
      "replacementForRejected",
      "h245.OpenLogicalChannelReject_cause.replacementForRejected",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "OpenLogicalChannelReject_cause replacementForRejected",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_CloseLogicalChannel_source_user,
    {
      "user",
      "h245.CloseLogicalChannel_source.user",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "CloseLogicalChannel_source user",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_CloseLogicalChannel_source_lcse,
    {
      "lcse",
      "h245.CloseLogicalChannel_source.lcse",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "CloseLogicalChannel_source lcse",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_CloseLogicalChannel_reason_unknown,
    {
      "unknown",
      "h245.CloseLogicalChannel_reason.unknown",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "CloseLogicalChannel_reason unknown",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_CloseLogicalChannel_reason_reopen,
    {
      "reopen",
      "h245.CloseLogicalChannel_reason.reopen",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "CloseLogicalChannel_reason reopen",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_CloseLogicalChannel_reason_reservationFailure,
    {
      "reservationFailure",
      "h245.CloseLogicalChannel_reason.reservationFailure",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "CloseLogicalChannel_reason reservationFailure",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_RequestChannelClose_reason_unknown,
    {
      "unknown",
      "h245.RequestChannelClose_reason.unknown",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RequestChannelClose_reason unknown",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_RequestChannelClose_reason_normal,
    {
      "normal",
      "h245.RequestChannelClose_reason.normal",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RequestChannelClose_reason normal",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_RequestChannelClose_reason_reopen,
    {
      "reopen",
      "h245.RequestChannelClose_reason.reopen",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RequestChannelClose_reason reopen",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_RequestChannelClose_reason_reservationFailure,
    {
      "reservationFailure",
      "h245.RequestChannelClose_reason.reservationFailure",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RequestChannelClose_reason reservationFailure",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_RequestChannelCloseReject_cause_unspecified,
    {
      "unspecified",
      "h245.RequestChannelCloseReject_cause.unspecified",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RequestChannelCloseReject_cause unspecified",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MultiplexElement_type_logicalChannelNumber,
    {
      "logicalChannelNumber",
      "h245.MultiplexElement_type.logicalChannelNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MultiplexElement_type logicalChannelNumber",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MultiplexElement_repeatCount_finite,
    {
      "finite",
      "h245.MultiplexElement_repeatCount.finite",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MultiplexElement_repeatCount finite",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MultiplexElement_repeatCount_untilClosingFlag,
    {
      "untilClosingFlag",
      "h245.MultiplexElement_repeatCount.untilClosingFlag",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MultiplexElement_repeatCount untilClosingFlag",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_ArrayOf_MultiplexTableEntryNumber_array,
    {
      "array",
      "h245.ArrayOf_MultiplexTableEntryNumber.array",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "ArrayOf_MultiplexTableEntryNumber array",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MultiplexEntryRejectionDescriptions_cause_unspecifiedCause,
    {
      "unspecifiedCause",
      "h245.MultiplexEntryRejectionDescriptions_cause.unspecifiedCause",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MultiplexEntryRejectionDescriptions_cause unspecifiedCause",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MultiplexEntryRejectionDescriptions_cause_descriptorTooComplex,
    {
      "descriptorTooComplex",
      "h245.MultiplexEntryRejectionDescriptions_cause.descriptorTooComplex",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MultiplexEntryRejectionDescriptions_cause descriptorTooComplex",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_RequestMultiplexEntryRejectionDescriptions_cause_unspecifiedCause,
    {
      "unspecifiedCause",
      "h245.RequestMultiplexEntryRejectionDescriptions_cause.unspecifiedCause",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RequestMultiplexEntryRejectionDescriptions_cause unspecifiedCause",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_RequestModeAck_response_willTransmitMostPreferredMode,
    {
      "willTransmitMostPreferredMode",
      "h245.RequestModeAck_response.willTransmitMostPreferredMode",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RequestModeAck_response willTransmitMostPreferredMode",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_RequestModeAck_response_willTransmitLessPreferredMode,
    {
      "willTransmitLessPreferredMode",
      "h245.RequestModeAck_response.willTransmitLessPreferredMode",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RequestModeAck_response willTransmitLessPreferredMode",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_RequestModeReject_cause_modeUnavailable,
    {
      "modeUnavailable",
      "h245.RequestModeReject_cause.modeUnavailable",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RequestModeReject_cause modeUnavailable",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_RequestModeReject_cause_multipointConstraint,
    {
      "multipointConstraint",
      "h245.RequestModeReject_cause.multipointConstraint",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RequestModeReject_cause multipointConstraint",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_RequestModeReject_cause_requestDenied,
    {
      "requestDenied",
      "h245.RequestModeReject_cause.requestDenied",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RequestModeReject_cause requestDenied",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223ModeParameters_adaptationLayerType_al1Framed,
    {
      "al1Framed",
      "h245.H223ModeParameters_adaptationLayerType.al1Framed",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223ModeParameters_adaptationLayerType al1Framed",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223ModeParameters_adaptationLayerType_al1NotFramed,
    {
      "al1NotFramed",
      "h245.H223ModeParameters_adaptationLayerType.al1NotFramed",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223ModeParameters_adaptationLayerType al1NotFramed",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223ModeParameters_adaptationLayerType_al2WithoutSequenceNumbers,
    {
      "al2WithoutSequenceNumbers",
      "h245.H223ModeParameters_adaptationLayerType.al2WithoutSequenceNumbers",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223ModeParameters_adaptationLayerType al2WithoutSequenceNumbers",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223ModeParameters_adaptationLayerType_al2WithSequenceNumbers,
    {
      "al2WithSequenceNumbers",
      "h245.H223ModeParameters_adaptationLayerType.al2WithSequenceNumbers",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223ModeParameters_adaptationLayerType al2WithSequenceNumbers",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H261VideoMode_resolution_qcif,
    {
      "qcif",
      "h245.H261VideoMode_resolution.qcif",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H261VideoMode_resolution qcif",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H261VideoMode_resolution_cif,
    {
      "cif",
      "h245.H261VideoMode_resolution.cif",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H261VideoMode_resolution cif",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H262VideoMode_profileAndLevel_profileAndLevel_SPatML,
    {
      "profileAndLevel_SPatML",
      "h245.H262VideoMode_profileAndLevel.profileAndLevel_SPatML",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H262VideoMode_profileAndLevel profileAndLevel_SPatML",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H262VideoMode_profileAndLevel_profileAndLevel_MPatLL,
    {
      "profileAndLevel_MPatLL",
      "h245.H262VideoMode_profileAndLevel.profileAndLevel_MPatLL",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H262VideoMode_profileAndLevel profileAndLevel_MPatLL",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H262VideoMode_profileAndLevel_profileAndLevel_MPatML,
    {
      "profileAndLevel_MPatML",
      "h245.H262VideoMode_profileAndLevel.profileAndLevel_MPatML",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H262VideoMode_profileAndLevel profileAndLevel_MPatML",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H262VideoMode_profileAndLevel_profileAndLevel_MPatH_14,
    {
      "profileAndLevel_MPatH_14",
      "h245.H262VideoMode_profileAndLevel.profileAndLevel_MPatH_14",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H262VideoMode_profileAndLevel profileAndLevel_MPatH_14",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H262VideoMode_profileAndLevel_profileAndLevel_MPatHL,
    {
      "profileAndLevel_MPatHL",
      "h245.H262VideoMode_profileAndLevel.profileAndLevel_MPatHL",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H262VideoMode_profileAndLevel profileAndLevel_MPatHL",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H262VideoMode_profileAndLevel_profileAndLevel_SNRatLL,
    {
      "profileAndLevel_SNRatLL",
      "h245.H262VideoMode_profileAndLevel.profileAndLevel_SNRatLL",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H262VideoMode_profileAndLevel profileAndLevel_SNRatLL",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H262VideoMode_profileAndLevel_profileAndLevel_SNRatML,
    {
      "profileAndLevel_SNRatML",
      "h245.H262VideoMode_profileAndLevel.profileAndLevel_SNRatML",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H262VideoMode_profileAndLevel profileAndLevel_SNRatML",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H262VideoMode_profileAndLevel_profileAndLevel_SpatialatH_14,
    {
      "profileAndLevel_SpatialatH_14",
      "h245.H262VideoMode_profileAndLevel.profileAndLevel_SpatialatH_14",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H262VideoMode_profileAndLevel profileAndLevel_SpatialatH_14",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H262VideoMode_profileAndLevel_profileAndLevel_HPatML,
    {
      "profileAndLevel_HPatML",
      "h245.H262VideoMode_profileAndLevel.profileAndLevel_HPatML",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H262VideoMode_profileAndLevel profileAndLevel_HPatML",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H262VideoMode_profileAndLevel_profileAndLevel_HPatH_14,
    {
      "profileAndLevel_HPatH_14",
      "h245.H262VideoMode_profileAndLevel.profileAndLevel_HPatH_14",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H262VideoMode_profileAndLevel profileAndLevel_HPatH_14",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H262VideoMode_profileAndLevel_profileAndLevel_HPatHL,
    {
      "profileAndLevel_HPatHL",
      "h245.H262VideoMode_profileAndLevel.profileAndLevel_HPatHL",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H262VideoMode_profileAndLevel profileAndLevel_HPatHL",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H263VideoMode_resolution_sqcif,
    {
      "sqcif",
      "h245.H263VideoMode_resolution.sqcif",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263VideoMode_resolution sqcif",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H263VideoMode_resolution_qcif,
    {
      "qcif",
      "h245.H263VideoMode_resolution.qcif",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263VideoMode_resolution qcif",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H263VideoMode_resolution_cif,
    {
      "cif",
      "h245.H263VideoMode_resolution.cif",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263VideoMode_resolution cif",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H263VideoMode_resolution_cif4,
    {
      "cif4",
      "h245.H263VideoMode_resolution.cif4",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263VideoMode_resolution cif4",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H263VideoMode_resolution_cif16,
    {
      "cif16",
      "h245.H263VideoMode_resolution.cif16",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263VideoMode_resolution cif16",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_AudioMode_g7231_noSilenceSuppressionLowRate,
    {
      "noSilenceSuppressionLowRate",
      "h245.AudioMode_g7231.noSilenceSuppressionLowRate",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "AudioMode_g7231 noSilenceSuppressionLowRate",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_AudioMode_g7231_noSilenceSuppressionHighRate,
    {
      "noSilenceSuppressionHighRate",
      "h245.AudioMode_g7231.noSilenceSuppressionHighRate",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "AudioMode_g7231 noSilenceSuppressionHighRate",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_AudioMode_g7231_silenceSuppressionLowRate,
    {
      "silenceSuppressionLowRate",
      "h245.AudioMode_g7231.silenceSuppressionLowRate",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "AudioMode_g7231 silenceSuppressionLowRate",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_AudioMode_g7231_silenceSuppressionHighRate,
    {
      "silenceSuppressionHighRate",
      "h245.AudioMode_g7231.silenceSuppressionHighRate",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "AudioMode_g7231 silenceSuppressionHighRate",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS11172AudioMode_audioLayer_audioLayer1,
    {
      "audioLayer1",
      "h245.IS11172AudioMode_audioLayer.audioLayer1",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS11172AudioMode_audioLayer audioLayer1",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS11172AudioMode_audioLayer_audioLayer2,
    {
      "audioLayer2",
      "h245.IS11172AudioMode_audioLayer.audioLayer2",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS11172AudioMode_audioLayer audioLayer2",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS11172AudioMode_audioLayer_audioLayer3,
    {
      "audioLayer3",
      "h245.IS11172AudioMode_audioLayer.audioLayer3",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS11172AudioMode_audioLayer audioLayer3",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS11172AudioMode_audioSampling_audioSampling32k,
    {
      "audioSampling32k",
      "h245.IS11172AudioMode_audioSampling.audioSampling32k",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS11172AudioMode_audioSampling audioSampling32k",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS11172AudioMode_audioSampling_audioSampling44k1,
    {
      "audioSampling44k1",
      "h245.IS11172AudioMode_audioSampling.audioSampling44k1",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS11172AudioMode_audioSampling audioSampling44k1",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS11172AudioMode_audioSampling_audioSampling48k,
    {
      "audioSampling48k",
      "h245.IS11172AudioMode_audioSampling.audioSampling48k",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS11172AudioMode_audioSampling audioSampling48k",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS11172AudioMode_multichannelType_singleChannel,
    {
      "singleChannel",
      "h245.IS11172AudioMode_multichannelType.singleChannel",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS11172AudioMode_multichannelType singleChannel",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS11172AudioMode_multichannelType_twoChannelStereo,
    {
      "twoChannelStereo",
      "h245.IS11172AudioMode_multichannelType.twoChannelStereo",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS11172AudioMode_multichannelType twoChannelStereo",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS11172AudioMode_multichannelType_twoChannelDual,
    {
      "twoChannelDual",
      "h245.IS11172AudioMode_multichannelType.twoChannelDual",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS11172AudioMode_multichannelType twoChannelDual",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS13818AudioMode_audioLayer_audioLayer1,
    {
      "audioLayer1",
      "h245.IS13818AudioMode_audioLayer.audioLayer1",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioMode_audioLayer audioLayer1",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS13818AudioMode_audioLayer_audioLayer2,
    {
      "audioLayer2",
      "h245.IS13818AudioMode_audioLayer.audioLayer2",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioMode_audioLayer audioLayer2",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS13818AudioMode_audioLayer_audioLayer3,
    {
      "audioLayer3",
      "h245.IS13818AudioMode_audioLayer.audioLayer3",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioMode_audioLayer audioLayer3",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS13818AudioMode_audioSampling_audioSampling16k,
    {
      "audioSampling16k",
      "h245.IS13818AudioMode_audioSampling.audioSampling16k",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioMode_audioSampling audioSampling16k",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS13818AudioMode_audioSampling_audioSampling22k05,
    {
      "audioSampling22k05",
      "h245.IS13818AudioMode_audioSampling.audioSampling22k05",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioMode_audioSampling audioSampling22k05",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS13818AudioMode_audioSampling_audioSampling24k,
    {
      "audioSampling24k",
      "h245.IS13818AudioMode_audioSampling.audioSampling24k",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioMode_audioSampling audioSampling24k",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS13818AudioMode_audioSampling_audioSampling32k,
    {
      "audioSampling32k",
      "h245.IS13818AudioMode_audioSampling.audioSampling32k",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioMode_audioSampling audioSampling32k",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS13818AudioMode_audioSampling_audioSampling44k1,
    {
      "audioSampling44k1",
      "h245.IS13818AudioMode_audioSampling.audioSampling44k1",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioMode_audioSampling audioSampling44k1",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS13818AudioMode_audioSampling_audioSampling48k,
    {
      "audioSampling48k",
      "h245.IS13818AudioMode_audioSampling.audioSampling48k",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioMode_audioSampling audioSampling48k",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS13818AudioMode_multichannelType_singleChannel,
    {
      "singleChannel",
      "h245.IS13818AudioMode_multichannelType.singleChannel",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioMode_multichannelType singleChannel",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS13818AudioMode_multichannelType_twoChannelStereo,
    {
      "twoChannelStereo",
      "h245.IS13818AudioMode_multichannelType.twoChannelStereo",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioMode_multichannelType twoChannelStereo",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS13818AudioMode_multichannelType_twoChannelDual,
    {
      "twoChannelDual",
      "h245.IS13818AudioMode_multichannelType.twoChannelDual",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioMode_multichannelType twoChannelDual",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS13818AudioMode_multichannelType_threeChannels2_1,
    {
      "threeChannels2_1",
      "h245.IS13818AudioMode_multichannelType.threeChannels2_1",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioMode_multichannelType threeChannels2_1",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS13818AudioMode_multichannelType_threeChannels3_0,
    {
      "threeChannels3_0",
      "h245.IS13818AudioMode_multichannelType.threeChannels3_0",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioMode_multichannelType threeChannels3_0",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS13818AudioMode_multichannelType_fourChannels2_0_2_0,
    {
      "fourChannels2_0_2_0",
      "h245.IS13818AudioMode_multichannelType.fourChannels2_0_2_0",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioMode_multichannelType fourChannels2_0_2_0",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS13818AudioMode_multichannelType_fourChannels2_2,
    {
      "fourChannels2_2",
      "h245.IS13818AudioMode_multichannelType.fourChannels2_2",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioMode_multichannelType fourChannels2_2",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS13818AudioMode_multichannelType_fourChannels3_1,
    {
      "fourChannels3_1",
      "h245.IS13818AudioMode_multichannelType.fourChannels3_1",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioMode_multichannelType fourChannels3_1",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS13818AudioMode_multichannelType_fiveChannels3_0_2_0,
    {
      "fiveChannels3_0_2_0",
      "h245.IS13818AudioMode_multichannelType.fiveChannels3_0_2_0",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioMode_multichannelType fiveChannels3_0_2_0",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_IS13818AudioMode_multichannelType_fiveChannels3_2,
    {
      "fiveChannels3_2",
      "h245.IS13818AudioMode_multichannelType.fiveChannels3_2",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioMode_multichannelType fiveChannels3_2",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_G7231AnnexCMode_g723AnnexCAudioMode_highRateMode0,
    {
      "highRateMode0",
      "h245.G7231AnnexCMode_g723AnnexCAudioMode.highRateMode0",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "G7231AnnexCMode_g723AnnexCAudioMode highRateMode0",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_G7231AnnexCMode_g723AnnexCAudioMode_highRateMode1,
    {
      "highRateMode1",
      "h245.G7231AnnexCMode_g723AnnexCAudioMode.highRateMode1",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "G7231AnnexCMode_g723AnnexCAudioMode highRateMode1",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_G7231AnnexCMode_g723AnnexCAudioMode_lowRateMode0,
    {
      "lowRateMode0",
      "h245.G7231AnnexCMode_g723AnnexCAudioMode.lowRateMode0",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "G7231AnnexCMode_g723AnnexCAudioMode lowRateMode0",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_G7231AnnexCMode_g723AnnexCAudioMode_lowRateMode1,
    {
      "lowRateMode1",
      "h245.G7231AnnexCMode_g723AnnexCAudioMode.lowRateMode1",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "G7231AnnexCMode_g723AnnexCAudioMode lowRateMode1",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_G7231AnnexCMode_g723AnnexCAudioMode_sidMode0,
    {
      "sidMode0",
      "h245.G7231AnnexCMode_g723AnnexCAudioMode.sidMode0",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "G7231AnnexCMode_g723AnnexCAudioMode sidMode0",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_G7231AnnexCMode_g723AnnexCAudioMode_sidMode1,
    {
      "sidMode1",
      "h245.G7231AnnexCMode_g723AnnexCAudioMode.sidMode1",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "G7231AnnexCMode_g723AnnexCAudioMode sidMode1",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_DataMode_application_dsvdControl,
    {
      "dsvdControl",
      "h245.DataMode_application.dsvdControl",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "DataMode_application dsvdControl",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MaintenanceLoopRequest_type_systemLoop,
    {
      "systemLoop",
      "h245.MaintenanceLoopRequest_type.systemLoop",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MaintenanceLoopRequest_type systemLoop",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MaintenanceLoopRequest_type_mediaLoop,
    {
      "mediaLoop",
      "h245.MaintenanceLoopRequest_type.mediaLoop",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MaintenanceLoopRequest_type mediaLoop",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MaintenanceLoopRequest_type_logicalChannelLoop,
    {
      "logicalChannelLoop",
      "h245.MaintenanceLoopRequest_type.logicalChannelLoop",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MaintenanceLoopRequest_type logicalChannelLoop",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MaintenanceLoopAck_type_systemLoop,
    {
      "systemLoop",
      "h245.MaintenanceLoopAck_type.systemLoop",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MaintenanceLoopAck_type systemLoop",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MaintenanceLoopAck_type_mediaLoop,
    {
      "mediaLoop",
      "h245.MaintenanceLoopAck_type.mediaLoop",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MaintenanceLoopAck_type mediaLoop",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MaintenanceLoopAck_type_logicalChannelLoop,
    {
      "logicalChannelLoop",
      "h245.MaintenanceLoopAck_type.logicalChannelLoop",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MaintenanceLoopAck_type logicalChannelLoop",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MaintenanceLoopReject_type_systemLoop,
    {
      "systemLoop",
      "h245.MaintenanceLoopReject_type.systemLoop",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MaintenanceLoopReject_type systemLoop",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MaintenanceLoopReject_type_mediaLoop,
    {
      "mediaLoop",
      "h245.MaintenanceLoopReject_type.mediaLoop",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MaintenanceLoopReject_type mediaLoop",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MaintenanceLoopReject_type_logicalChannelLoop,
    {
      "logicalChannelLoop",
      "h245.MaintenanceLoopReject_type.logicalChannelLoop",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MaintenanceLoopReject_type logicalChannelLoop",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MaintenanceLoopReject_cause_canNotPerformLoop,
    {
      "canNotPerformLoop",
      "h245.MaintenanceLoopReject_cause.canNotPerformLoop",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MaintenanceLoopReject_cause canNotPerformLoop",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_ConferenceResponse_makeMeChairResponse_grantedChairToken,
    {
      "grantedChairToken",
      "h245.ConferenceResponse_makeMeChairResponse.grantedChairToken",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceResponse_makeMeChairResponse grantedChairToken",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_ConferenceResponse_makeMeChairResponse_deniedChairToken,
    {
      "deniedChairToken",
      "h245.ConferenceResponse_makeMeChairResponse.deniedChairToken",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceResponse_makeMeChairResponse deniedChairToken",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_ConferenceResponse_extensionAddressResponse_extensionAddress,
    {
      "extensionAddress",
      "h245.ConferenceResponse_extensionAddressResponse.extensionAddress",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceResponse_extensionAddressResponse extensionAddress",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_ConferenceResponse_broadcastMyLogicalChannelResponse_grantedBroadcastMyLogicalChannel,
    {
      "grantedBroadcastMyLogicalChannel",
      "h245.ConferenceResponse_broadcastMyLogicalChannelResponse.grantedBroadcastMyLogicalChannel",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceResponse_broadcastMyLogicalChannelResponse grantedBroadcastMyLogicalChannel",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_ConferenceResponse_broadcastMyLogicalChannelResponse_deniedBroadcastMyLogicalChannel,
    {
      "deniedBroadcastMyLogicalChannel",
      "h245.ConferenceResponse_broadcastMyLogicalChannelResponse.deniedBroadcastMyLogicalChannel",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceResponse_broadcastMyLogicalChannelResponse deniedBroadcastMyLogicalChannel",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_ConferenceResponse_makeTerminalBroadcasterResponse_grantedMakeTerminalBroadcaster,
    {
      "grantedMakeTerminalBroadcaster",
      "h245.ConferenceResponse_makeTerminalBroadcasterResponse.grantedMakeTerminalBroadcaster",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceResponse_makeTerminalBroadcasterResponse grantedMakeTerminalBroadcaster",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_ConferenceResponse_makeTerminalBroadcasterResponse_deniedMakeTerminalBroadcaster,
    {
      "deniedMakeTerminalBroadcaster",
      "h245.ConferenceResponse_makeTerminalBroadcasterResponse.deniedMakeTerminalBroadcaster",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceResponse_makeTerminalBroadcasterResponse deniedMakeTerminalBroadcaster",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_ConferenceResponse_sendThisSourceResponse_grantedSendThisSource,
    {
      "grantedSendThisSource",
      "h245.ConferenceResponse_sendThisSourceResponse.grantedSendThisSource",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceResponse_sendThisSourceResponse grantedSendThisSource",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_ConferenceResponse_sendThisSourceResponse_deniedSendThisSource,
    {
      "deniedSendThisSource",
      "h245.ConferenceResponse_sendThisSourceResponse.deniedSendThisSource",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceResponse_sendThisSourceResponse deniedSendThisSource",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_RemoteMCResponse_reject_unspecified,
    {
      "unspecified",
      "h245.RemoteMCResponse_reject.unspecified",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RemoteMCResponse_reject unspecified",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_RemoteMCResponse_reject_functionNotSupported,
    {
      "functionNotSupported",
      "h245.RemoteMCResponse_reject.functionNotSupported",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "RemoteMCResponse_reject functionNotSupported",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MultilinkRequest_callInformation_maxNumberOfAdditionalConnections,
    {
      "maxNumberOfAdditionalConnections",
      "h245.MultilinkRequest_callInformation.maxNumberOfAdditionalConnections",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MultilinkRequest_callInformation maxNumberOfAdditionalConnections",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MultilinkRequest_addConnection_sequenceNumber,
    {
      "sequenceNumber",
      "h245.MultilinkRequest_addConnection.sequenceNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MultilinkRequest_addConnection sequenceNumber",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MultilinkResponse_callInformation_callAssociationNumber,
    {
      "callAssociationNumber",
      "h245.MultilinkResponse_callInformation.callAssociationNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MultilinkResponse_callInformation callAssociationNumber",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MultilinkResponse_maximumHeaderInterval_currentInterval,
    {
      "currentInterval",
      "h245.MultilinkResponse_maximumHeaderInterval.currentInterval",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MultilinkResponse_maximumHeaderInterval currentInterval",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_FlowControlCommand_scope_logicalChannelNumber,
    {
      "logicalChannelNumber",
      "h245.FlowControlCommand_scope.logicalChannelNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "FlowControlCommand_scope logicalChannelNumber",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_FlowControlCommand_scope_resourceID,
    {
      "resourceID",
      "h245.FlowControlCommand_scope.resourceID",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "FlowControlCommand_scope resourceID",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_FlowControlCommand_scope_wholeMultiplex,
    {
      "wholeMultiplex",
      "h245.FlowControlCommand_scope.wholeMultiplex",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "FlowControlCommand_scope wholeMultiplex",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_FlowControlCommand_restriction_maximumBitRate,
    {
      "maximumBitRate",
      "h245.FlowControlCommand_restriction.maximumBitRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "FlowControlCommand_restriction maximumBitRate",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_FlowControlCommand_restriction_noRestriction,
    {
      "noRestriction",
      "h245.FlowControlCommand_restriction.noRestriction",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "FlowControlCommand_restriction noRestriction",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_EndSessionCommand_gstnOptions_telephonyMode,
    {
      "telephonyMode",
      "h245.EndSessionCommand_gstnOptions.telephonyMode",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "EndSessionCommand_gstnOptions telephonyMode",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_EndSessionCommand_gstnOptions_v8bis,
    {
      "v8bis",
      "h245.EndSessionCommand_gstnOptions.v8bis",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "EndSessionCommand_gstnOptions v8bis",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_EndSessionCommand_gstnOptions_v34DSVD,
    {
      "v34DSVD",
      "h245.EndSessionCommand_gstnOptions.v34DSVD",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "EndSessionCommand_gstnOptions v34DSVD",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_EndSessionCommand_gstnOptions_v34DuplexFAX,
    {
      "v34DuplexFAX",
      "h245.EndSessionCommand_gstnOptions.v34DuplexFAX",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "EndSessionCommand_gstnOptions v34DuplexFAX",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_EndSessionCommand_gstnOptions_v34H324,
    {
      "v34H324",
      "h245.EndSessionCommand_gstnOptions.v34H324",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "EndSessionCommand_gstnOptions v34H324",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_EndSessionCommand_isdnOptions_telephonyMode,
    {
      "telephonyMode",
      "h245.EndSessionCommand_isdnOptions.telephonyMode",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "EndSessionCommand_isdnOptions telephonyMode",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_EndSessionCommand_isdnOptions_v140,
    {
      "v140",
      "h245.EndSessionCommand_isdnOptions.v140",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "EndSessionCommand_isdnOptions v140",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_EndSessionCommand_isdnOptions_terminalOnHold,
    {
      "terminalOnHold",
      "h245.EndSessionCommand_isdnOptions.terminalOnHold",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "EndSessionCommand_isdnOptions terminalOnHold",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousCommand_type_equalizeDelay,
    {
      "equalizeDelay",
      "h245.MiscellaneousCommand_type.equalizeDelay",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousCommand_type equalizeDelay",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousCommand_type_zeroDelay,
    {
      "zeroDelay",
      "h245.MiscellaneousCommand_type.zeroDelay",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousCommand_type zeroDelay",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousCommand_type_multipointModeCommand,
    {
      "multipointModeCommand",
      "h245.MiscellaneousCommand_type.multipointModeCommand",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousCommand_type multipointModeCommand",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousCommand_type_cancelMultipointModeCommand,
    {
      "cancelMultipointModeCommand",
      "h245.MiscellaneousCommand_type.cancelMultipointModeCommand",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousCommand_type cancelMultipointModeCommand",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousCommand_type_videoFreezePicture,
    {
      "videoFreezePicture",
      "h245.MiscellaneousCommand_type.videoFreezePicture",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousCommand_type videoFreezePicture",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousCommand_type_videoFastUpdatePicture,
    {
      "videoFastUpdatePicture",
      "h245.MiscellaneousCommand_type.videoFastUpdatePicture",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousCommand_type videoFastUpdatePicture",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousCommand_type_videoTemporalSpatialTradeOff,
    {
      "videoTemporalSpatialTradeOff",
      "h245.MiscellaneousCommand_type.videoTemporalSpatialTradeOff",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MiscellaneousCommand_type videoTemporalSpatialTradeOff",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousCommand_type_videoSendSyncEveryGOB,
    {
      "videoSendSyncEveryGOB",
      "h245.MiscellaneousCommand_type.videoSendSyncEveryGOB",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousCommand_type videoSendSyncEveryGOB",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousCommand_type_videoSendSyncEveryGOBCancel,
    {
      "videoSendSyncEveryGOBCancel",
      "h245.MiscellaneousCommand_type.videoSendSyncEveryGOBCancel",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousCommand_type videoSendSyncEveryGOBCancel",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousCommand_type_maxH223MUXPDUsize,
    {
      "maxH223MUXPDUsize",
      "h245.MiscellaneousCommand_type.maxH223MUXPDUsize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MiscellaneousCommand_type maxH223MUXPDUsize",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousCommand_type_switchReceiveMediaOff,
    {
      "switchReceiveMediaOff",
      "h245.MiscellaneousCommand_type.switchReceiveMediaOff",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousCommand_type switchReceiveMediaOff",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousCommand_type_switchReceiveMediaOn,
    {
      "switchReceiveMediaOn",
      "h245.MiscellaneousCommand_type.switchReceiveMediaOn",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousCommand_type switchReceiveMediaOn",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousCommand_type_progressiveRefinementAbortOne,
    {
      "progressiveRefinementAbortOne",
      "h245.MiscellaneousCommand_type.progressiveRefinementAbortOne",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousCommand_type progressiveRefinementAbortOne",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousCommand_type_progressiveRefinementAbortContinuous,
    {
      "progressiveRefinementAbortContinuous",
      "h245.MiscellaneousCommand_type.progressiveRefinementAbortContinuous",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousCommand_type progressiveRefinementAbortContinuous",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223MultiplexReconfiguration_h223ModeChange_toLevel0,
    {
      "toLevel0",
      "h245.H223MultiplexReconfiguration_h223ModeChange.toLevel0",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223MultiplexReconfiguration_h223ModeChange toLevel0",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223MultiplexReconfiguration_h223ModeChange_toLevel1,
    {
      "toLevel1",
      "h245.H223MultiplexReconfiguration_h223ModeChange.toLevel1",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223MultiplexReconfiguration_h223ModeChange toLevel1",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223MultiplexReconfiguration_h223ModeChange_toLevel2,
    {
      "toLevel2",
      "h245.H223MultiplexReconfiguration_h223ModeChange.toLevel2",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223MultiplexReconfiguration_h223ModeChange toLevel2",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223MultiplexReconfiguration_h223ModeChange_toLevel2withOptionalHeader,
    {
      "toLevel2withOptionalHeader",
      "h245.H223MultiplexReconfiguration_h223ModeChange.toLevel2withOptionalHeader",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223MultiplexReconfiguration_h223ModeChange toLevel2withOptionalHeader",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223MultiplexReconfiguration_h223AnnexADoubleFlag_start,
    {
      "start",
      "h245.H223MultiplexReconfiguration_h223AnnexADoubleFlag.start",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223MultiplexReconfiguration_h223AnnexADoubleFlag start",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223MultiplexReconfiguration_h223AnnexADoubleFlag_stop,
    {
      "stop",
      "h245.H223MultiplexReconfiguration_h223AnnexADoubleFlag.stop",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223MultiplexReconfiguration_h223AnnexADoubleFlag stop",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCCommand_multiplex_noMultiplex,
    {
      "noMultiplex",
      "h245.NewATMVCCommand_multiplex.noMultiplex",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCCommand_multiplex noMultiplex",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCCommand_multiplex_transportStream,
    {
      "transportStream",
      "h245.NewATMVCCommand_multiplex.transportStream",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCCommand_multiplex transportStream",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCCommand_multiplex_programStream,
    {
      "programStream",
      "h245.NewATMVCCommand_multiplex.programStream",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCCommand_multiplex programStream",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_FunctionNotSupported_cause_syntaxError,
    {
      "syntaxError",
      "h245.FunctionNotSupported_cause.syntaxError",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "FunctionNotSupported_cause syntaxError",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_FunctionNotSupported_cause_semanticError,
    {
      "semanticError",
      "h245.FunctionNotSupported_cause.semanticError",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "FunctionNotSupported_cause semanticError",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_FunctionNotSupported_cause_unknownFunction,
    {
      "unknownFunction",
      "h245.FunctionNotSupported_cause.unknownFunction",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "FunctionNotSupported_cause unknownFunction",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousIndication_type_logicalChannelActive,
    {
      "logicalChannelActive",
      "h245.MiscellaneousIndication_type.logicalChannelActive",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousIndication_type logicalChannelActive",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousIndication_type_logicalChannelInactive,
    {
      "logicalChannelInactive",
      "h245.MiscellaneousIndication_type.logicalChannelInactive",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousIndication_type logicalChannelInactive",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousIndication_type_multipointConference,
    {
      "multipointConference",
      "h245.MiscellaneousIndication_type.multipointConference",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousIndication_type multipointConference",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousIndication_type_cancelMultipointConference,
    {
      "cancelMultipointConference",
      "h245.MiscellaneousIndication_type.cancelMultipointConference",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousIndication_type cancelMultipointConference",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousIndication_type_multipointZeroComm,
    {
      "multipointZeroComm",
      "h245.MiscellaneousIndication_type.multipointZeroComm",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousIndication_type multipointZeroComm",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousIndication_type_cancelMultipointZeroComm,
    {
      "cancelMultipointZeroComm",
      "h245.MiscellaneousIndication_type.cancelMultipointZeroComm",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousIndication_type cancelMultipointZeroComm",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousIndication_type_multipointSecondaryStatus,
    {
      "multipointSecondaryStatus",
      "h245.MiscellaneousIndication_type.multipointSecondaryStatus",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousIndication_type multipointSecondaryStatus",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousIndication_type_cancelMultipointSecondaryStatus,
    {
      "cancelMultipointSecondaryStatus",
      "h245.MiscellaneousIndication_type.cancelMultipointSecondaryStatus",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousIndication_type cancelMultipointSecondaryStatus",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousIndication_type_videoIndicateReadyToActivate,
    {
      "videoIndicateReadyToActivate",
      "h245.MiscellaneousIndication_type.videoIndicateReadyToActivate",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousIndication_type videoIndicateReadyToActivate",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousIndication_type_videoTemporalSpatialTradeOff,
    {
      "videoTemporalSpatialTradeOff",
      "h245.MiscellaneousIndication_type.videoTemporalSpatialTradeOff",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MiscellaneousIndication_type videoTemporalSpatialTradeOff",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_JitterIndication_scope_logicalChannelNumber,
    {
      "logicalChannelNumber",
      "h245.JitterIndication_scope.logicalChannelNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "JitterIndication_scope logicalChannelNumber",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_JitterIndication_scope_resourceID,
    {
      "resourceID",
      "h245.JitterIndication_scope.resourceID",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "JitterIndication_scope resourceID",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_JitterIndication_scope_wholeMultiplex,
    {
      "wholeMultiplex",
      "h245.JitterIndication_scope.wholeMultiplex",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "JitterIndication_scope wholeMultiplex",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCIndication_multiplex_noMultiplex,
    {
      "noMultiplex",
      "h245.NewATMVCIndication_multiplex.noMultiplex",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCIndication_multiplex noMultiplex",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCIndication_multiplex_transportStream,
    {
      "transportStream",
      "h245.NewATMVCIndication_multiplex.transportStream",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCIndication_multiplex transportStream",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCIndication_multiplex_programStream,
    {
      "programStream",
      "h245.NewATMVCIndication_multiplex.programStream",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCIndication_multiplex programStream",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_UserInputIndication_userInputSupportIndication_basicString,
    {
      "basicString",
      "h245.UserInputIndication_userInputSupportIndication.basicString",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "UserInputIndication_userInputSupportIndication basicString",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_UserInputIndication_userInputSupportIndication_iA5String,
    {
      "iA5String",
      "h245.UserInputIndication_userInputSupportIndication.iA5String",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "UserInputIndication_userInputSupportIndication iA5String",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_UserInputIndication_userInputSupportIndication_generalString,
    {
      "generalString",
      "h245.UserInputIndication_userInputSupportIndication.generalString",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "UserInputIndication_userInputSupportIndication generalString",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_TerminalCapabilitySetReject_cause_tableEntryCapacityExceeded_highestEntryNumberProcessed,
    {
      "highestEntryNumberProcessed",
      "h245.TerminalCapabilitySetReject_cause_tableEntryCapacityExceeded.highestEntryNumberProcessed",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "TerminalCapabilitySetReject_cause_tableEntryCapacityExceeded highestEntryNumberProcessed",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_TerminalCapabilitySetReject_cause_tableEntryCapacityExceeded_noneProcessed,
    {
      "noneProcessed",
      "h245.TerminalCapabilitySetReject_cause_tableEntryCapacityExceeded.noneProcessed",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "TerminalCapabilitySetReject_cause_tableEntryCapacityExceeded noneProcessed",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_VCCapability_availableBitRates_type_singleBitRate,
    {
      "singleBitRate",
      "h245.VCCapability_availableBitRates_type.singleBitRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "VCCapability_availableBitRates_type singleBitRate",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223Capability_h223MultiplexTableCapability_enhanced_maximumNestingDepth,
    {
      "maximumNestingDepth",
      "h245.H223Capability_h223MultiplexTableCapability_enhanced.maximumNestingDepth",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H223Capability_h223MultiplexTableCapability_enhanced maximumNestingDepth",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223Capability_h223MultiplexTableCapability_enhanced_maximumElementListSize,
    {
      "maximumElementListSize",
      "h245.H223Capability_h223MultiplexTableCapability_enhanced.maximumElementListSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H223Capability_h223MultiplexTableCapability_enhanced maximumElementListSize",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223Capability_h223MultiplexTableCapability_enhanced_maximumSubElementListSize,
    {
      "maximumSubElementListSize",
      "h245.H223Capability_h223MultiplexTableCapability_enhanced.maximumSubElementListSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H223Capability_h223MultiplexTableCapability_enhanced maximumSubElementListSize",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_CustomPictureFormat_pixelAspectInformation_pixelAspectCode_array,
    {
      "array",
      "h245.CustomPictureFormat_pixelAspectInformation_pixelAspectCode.array",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CustomPictureFormat_pixelAspectInformation_pixelAspectCode array",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_DataApplicationCapability_application_nlpid_nlpidData,
    {
      "nlpidData",
      "h245.DataApplicationCapability_application_nlpid.nlpidData",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "DataApplicationCapability_application_nlpid nlpidData",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_OpenLogicalChannel_forwardLogicalChannelParameters_multiplexParameters_none,
    {
      "none",
      "h245.OpenLogicalChannel_forwardLogicalChannelParameters_multiplexParameters.none",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "OpenLogicalChannel_forwardLogicalChannelParameters_multiplexParameters none",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223LogicalChannelParameters_adaptationLayerType_al3_controlFieldOctets,
    {
      "controlFieldOctets",
      "h245.H223LogicalChannelParameters_adaptationLayerType_al3.controlFieldOctets",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H223LogicalChannelParameters_adaptationLayerType_al3 controlFieldOctets",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223LogicalChannelParameters_adaptationLayerType_al3_sendBufferSize,
    {
      "sendBufferSize",
      "h245.H223LogicalChannelParameters_adaptationLayerType_al3.sendBufferSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H223LogicalChannelParameters_adaptationLayerType_al3 sendBufferSize",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_UnicastAddress_iPSourceRouteAddress_routing_strict,
    {
      "strict",
      "h245.UnicastAddress_iPSourceRouteAddress_routing.strict",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "UnicastAddress_iPSourceRouteAddress_routing strict",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_UnicastAddress_iPSourceRouteAddress_routing_loose,
    {
      "loose",
      "h245.UnicastAddress_iPSourceRouteAddress_routing.loose",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "UnicastAddress_iPSourceRouteAddress_routing loose",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_UnicastAddress_iPSourceRouteAddress_route_array,
    {
      "array",
      "h245.UnicastAddress_iPSourceRouteAddress_route.array",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "UnicastAddress_iPSourceRouteAddress_route array",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223ModeParameters_adaptationLayerType_al3_controlFieldOctets,
    {
      "controlFieldOctets",
      "h245.H223ModeParameters_adaptationLayerType_al3.controlFieldOctets",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H223ModeParameters_adaptationLayerType_al3 controlFieldOctets",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223ModeParameters_adaptationLayerType_al3_sendBufferSize,
    {
      "sendBufferSize",
      "h245.H223ModeParameters_adaptationLayerType_al3.sendBufferSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H223ModeParameters_adaptationLayerType_al3 sendBufferSize",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_DataMode_application_nlpid_nlpidData,
    {
      "nlpidData",
      "h245.DataMode_application_nlpid.nlpidData",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "DataMode_application_nlpid nlpidData",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MultilinkRequest_maximumHeaderInterval_requestType_currentIntervalInformation,
    {
      "currentIntervalInformation",
      "h245.MultilinkRequest_maximumHeaderInterval_requestType.currentIntervalInformation",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MultilinkRequest_maximumHeaderInterval_requestType currentIntervalInformation",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MultilinkRequest_maximumHeaderInterval_requestType_requestedInterval,
    {
      "requestedInterval",
      "h245.MultilinkRequest_maximumHeaderInterval_requestType.requestedInterval",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MultilinkRequest_maximumHeaderInterval_requestType requestedInterval",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MultilinkResponse_addConnection_responseCode_accepted,
    {
      "accepted",
      "h245.MultilinkResponse_addConnection_responseCode.accepted",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MultilinkResponse_addConnection_responseCode accepted",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_ArrayOf_CapabilityDescriptorNumber_array,
    {
      "array",
      "h245.ArrayOf_CapabilityDescriptorNumber.array",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "ArrayOf_CapabilityDescriptorNumber array",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousCommand_type_videoFastUpdateGOB_firstGOB,
    {
      "firstGOB",
      "h245.MiscellaneousCommand_type_videoFastUpdateGOB.firstGOB",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MiscellaneousCommand_type_videoFastUpdateGOB firstGOB",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousCommand_type_videoFastUpdateGOB_numberOfGOBs,
    {
      "numberOfGOBs",
      "h245.MiscellaneousCommand_type_videoFastUpdateGOB.numberOfGOBs",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MiscellaneousCommand_type_videoFastUpdateGOB numberOfGOBs",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousCommand_type_videoFastUpdateMB_firstGOB,
    {
      "firstGOB",
      "h245.MiscellaneousCommand_type_videoFastUpdateMB.firstGOB",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MiscellaneousCommand_type_videoFastUpdateMB firstGOB",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousCommand_type_videoFastUpdateMB_firstMB,
    {
      "firstMB",
      "h245.MiscellaneousCommand_type_videoFastUpdateMB.firstMB",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MiscellaneousCommand_type_videoFastUpdateMB firstMB",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousCommand_type_videoFastUpdateMB_numberOfMBs,
    {
      "numberOfMBs",
      "h245.MiscellaneousCommand_type_videoFastUpdateMB.numberOfMBs",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MiscellaneousCommand_type_videoFastUpdateMB numberOfMBs",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCCommand_aal_aal5_forwardMaximumSDUSize,
    {
      "forwardMaximumSDUSize",
      "h245.NewATMVCCommand_aal_aal5.forwardMaximumSDUSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "NewATMVCCommand_aal_aal5 forwardMaximumSDUSize",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCCommand_aal_aal5_backwardMaximumSDUSize,
    {
      "backwardMaximumSDUSize",
      "h245.NewATMVCCommand_aal_aal5.backwardMaximumSDUSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "NewATMVCCommand_aal_aal5 backwardMaximumSDUSize",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCCommand_reverseParameters_multiplex_noMultiplex,
    {
      "noMultiplex",
      "h245.NewATMVCCommand_reverseParameters_multiplex.noMultiplex",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCCommand_reverseParameters_multiplex noMultiplex",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCCommand_reverseParameters_multiplex_transportStream,
    {
      "transportStream",
      "h245.NewATMVCCommand_reverseParameters_multiplex.transportStream",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCCommand_reverseParameters_multiplex transportStream",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCCommand_reverseParameters_multiplex_programStream,
    {
      "programStream",
      "h245.NewATMVCCommand_reverseParameters_multiplex.programStream",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCCommand_reverseParameters_multiplex programStream",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousIndication_type_videoNotDecodedMBs_firstMB,
    {
      "firstMB",
      "h245.MiscellaneousIndication_type_videoNotDecodedMBs.firstMB",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MiscellaneousIndication_type_videoNotDecodedMBs firstMB",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousIndication_type_videoNotDecodedMBs_numberOfMBs,
    {
      "numberOfMBs",
      "h245.MiscellaneousIndication_type_videoNotDecodedMBs.numberOfMBs",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MiscellaneousIndication_type_videoNotDecodedMBs numberOfMBs",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousIndication_type_videoNotDecodedMBs_temporalReference,
    {
      "temporalReference",
      "h245.MiscellaneousIndication_type_videoNotDecodedMBs.temporalReference",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MiscellaneousIndication_type_videoNotDecodedMBs temporalReference",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCIndication_aal_aal5_forwardMaximumSDUSize,
    {
      "forwardMaximumSDUSize",
      "h245.NewATMVCIndication_aal_aal5.forwardMaximumSDUSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "NewATMVCIndication_aal_aal5 forwardMaximumSDUSize",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCIndication_aal_aal5_backwardMaximumSDUSize,
    {
      "backwardMaximumSDUSize",
      "h245.NewATMVCIndication_aal_aal5.backwardMaximumSDUSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "NewATMVCIndication_aal_aal5 backwardMaximumSDUSize",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCIndication_reverseParameters_multiplex_noMultiplex,
    {
      "noMultiplex",
      "h245.NewATMVCIndication_reverseParameters_multiplex.noMultiplex",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCIndication_reverseParameters_multiplex noMultiplex",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCIndication_reverseParameters_multiplex_transportStream,
    {
      "transportStream",
      "h245.NewATMVCIndication_reverseParameters_multiplex.transportStream",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCIndication_reverseParameters_multiplex transportStream",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCIndication_reverseParameters_multiplex_programStream,
    {
      "programStream",
      "h245.NewATMVCIndication_reverseParameters_multiplex.programStream",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCIndication_reverseParameters_multiplex programStream",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_UserInputIndication_signal_rtp_timestamp,
    {
      "timestamp",
      "h245.UserInputIndication_signal_rtp.timestamp",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "UserInputIndication_signal_rtp timestamp",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_UserInputIndication_signal_rtp_expirationTime,
    {
      "expirationTime",
      "h245.UserInputIndication_signal_rtp.expirationTime",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "UserInputIndication_signal_rtp expirationTime",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_UserInputIndication_signal_rtp_logicalChannelNumber,
    {
      "logicalChannelNumber",
      "h245.UserInputIndication_signal_rtp.logicalChannelNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "UserInputIndication_signal_rtp logicalChannelNumber",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_UserInputIndication_signalUpdate_rtp_logicalChannelNumber,
    {
      "logicalChannelNumber",
      "h245.UserInputIndication_signalUpdate_rtp.logicalChannelNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "UserInputIndication_signalUpdate_rtp logicalChannelNumber",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_VCCapability_availableBitRates_type_rangeOfBitRates_lowerBitRate,
    {
      "lowerBitRate",
      "h245.VCCapability_availableBitRates_type_rangeOfBitRates.lowerBitRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "VCCapability_availableBitRates_type_rangeOfBitRates lowerBitRate",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_VCCapability_availableBitRates_type_rangeOfBitRates_higherBitRate,
    {
      "higherBitRate",
      "h245.VCCapability_availableBitRates_type_rangeOfBitRates.higherBitRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "VCCapability_availableBitRates_type_rangeOfBitRates higherBitRate",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_CustomPictureFormat_mPI_customPCF_subtype_clockConversionCode,
    {
      "clockConversionCode",
      "h245.CustomPictureFormat_mPI_customPCF_subtype.clockConversionCode",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CustomPictureFormat_mPI_customPCF_subtype clockConversionCode",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_CustomPictureFormat_mPI_customPCF_subtype_clockDivisor,
    {
      "clockDivisor",
      "h245.CustomPictureFormat_mPI_customPCF_subtype.clockDivisor",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CustomPictureFormat_mPI_customPCF_subtype clockDivisor",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_CustomPictureFormat_mPI_customPCF_subtype_customMPI,
    {
      "customMPI",
      "h245.CustomPictureFormat_mPI_customPCF_subtype.customMPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CustomPictureFormat_mPI_customPCF_subtype customMPI",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_CustomPictureFormat_pixelAspectInformation_extendedPAR_subtype_width,
    {
      "width",
      "h245.CustomPictureFormat_pixelAspectInformation_extendedPAR_subtype.width",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CustomPictureFormat_pixelAspectInformation_extendedPAR_subtype width",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_CustomPictureFormat_pixelAspectInformation_extendedPAR_subtype_height,
    {
      "height",
      "h245.CustomPictureFormat_pixelAspectInformation_extendedPAR_subtype.height",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CustomPictureFormat_pixelAspectInformation_extendedPAR_subtype height",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_V76LogicalChannelParameters_mode_eRM_recovery_rej,
    {
      "rej",
      "h245.V76LogicalChannelParameters_mode_eRM_recovery.rej",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "V76LogicalChannelParameters_mode_eRM_recovery rej",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_V76LogicalChannelParameters_mode_eRM_recovery_sREJ,
    {
      "sREJ",
      "h245.V76LogicalChannelParameters_mode_eRM_recovery.sREJ",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "V76LogicalChannelParameters_mode_eRM_recovery sREJ",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_V76LogicalChannelParameters_mode_eRM_recovery_mSREJ,
    {
      "mSREJ",
      "h245.V76LogicalChannelParameters_mode_eRM_recovery.mSREJ",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "V76LogicalChannelParameters_mode_eRM_recovery mSREJ",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MultilinkResponse_addConnection_responseCode_rejected_connectionsNotAvailable,
    {
      "connectionsNotAvailable",
      "h245.MultilinkResponse_addConnection_responseCode_rejected.connectionsNotAvailable",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MultilinkResponse_addConnection_responseCode_rejected connectionsNotAvailable",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MultilinkResponse_addConnection_responseCode_rejected_userRejected,
    {
      "userRejected",
      "h245.MultilinkResponse_addConnection_responseCode_rejected.userRejected",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MultilinkResponse_addConnection_responseCode_rejected userRejected",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousCommand_type_progressiveRefinementStart_repeatCount_doOneProgression,
    {
      "doOneProgression",
      "h245.MiscellaneousCommand_type_progressiveRefinementStart_repeatCount.doOneProgression",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousCommand_type_progressiveRefinementStart_repeatCount doOneProgression",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousCommand_type_progressiveRefinementStart_repeatCount_doContinuousProgressions,
    {
      "doContinuousProgressions",
      "h245.MiscellaneousCommand_type_progressiveRefinementStart_repeatCount.doContinuousProgressions",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousCommand_type_progressiveRefinementStart_repeatCount doContinuousProgressions",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousCommand_type_progressiveRefinementStart_repeatCount_doOneIndependentProgression,
    {
      "doOneIndependentProgression",
      "h245.MiscellaneousCommand_type_progressiveRefinementStart_repeatCount.doOneIndependentProgression",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousCommand_type_progressiveRefinementStart_repeatCount doOneIndependentProgression",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_MiscellaneousCommand_type_progressiveRefinementStart_repeatCount_doContinuousIndependentProgressions,
    {
      "doContinuousIndependentProgressions",
      "h245.MiscellaneousCommand_type_progressiveRefinementStart_repeatCount.doContinuousIndependentProgressions",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "MiscellaneousCommand_type_progressiveRefinementStart_repeatCount doContinuousIndependentProgressions",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCCommand_aal_aal1_clockRecovery_nullClockRecovery,
    {
      "nullClockRecovery",
      "h245.NewATMVCCommand_aal_aal1_clockRecovery.nullClockRecovery",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCCommand_aal_aal1_clockRecovery nullClockRecovery",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCCommand_aal_aal1_clockRecovery_srtsClockRecovery,
    {
      "srtsClockRecovery",
      "h245.NewATMVCCommand_aal_aal1_clockRecovery.srtsClockRecovery",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCCommand_aal_aal1_clockRecovery srtsClockRecovery",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCCommand_aal_aal1_clockRecovery_adaptiveClockRecovery,
    {
      "adaptiveClockRecovery",
      "h245.NewATMVCCommand_aal_aal1_clockRecovery.adaptiveClockRecovery",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCCommand_aal_aal1_clockRecovery adaptiveClockRecovery",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCCommand_aal_aal1_errorCorrection_nullErrorCorrection,
    {
      "nullErrorCorrection",
      "h245.NewATMVCCommand_aal_aal1_errorCorrection.nullErrorCorrection",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCCommand_aal_aal1_errorCorrection nullErrorCorrection",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCCommand_aal_aal1_errorCorrection_longInterleaver,
    {
      "longInterleaver",
      "h245.NewATMVCCommand_aal_aal1_errorCorrection.longInterleaver",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCCommand_aal_aal1_errorCorrection longInterleaver",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCCommand_aal_aal1_errorCorrection_shortInterleaver,
    {
      "shortInterleaver",
      "h245.NewATMVCCommand_aal_aal1_errorCorrection.shortInterleaver",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCCommand_aal_aal1_errorCorrection shortInterleaver",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCCommand_aal_aal1_errorCorrection_errorCorrectionOnly,
    {
      "errorCorrectionOnly",
      "h245.NewATMVCCommand_aal_aal1_errorCorrection.errorCorrectionOnly",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCCommand_aal_aal1_errorCorrection errorCorrectionOnly",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCIndication_aal_aal1_clockRecovery_nullClockRecovery,
    {
      "nullClockRecovery",
      "h245.NewATMVCIndication_aal_aal1_clockRecovery.nullClockRecovery",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCIndication_aal_aal1_clockRecovery nullClockRecovery",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCIndication_aal_aal1_clockRecovery_srtsClockRecovery,
    {
      "srtsClockRecovery",
      "h245.NewATMVCIndication_aal_aal1_clockRecovery.srtsClockRecovery",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCIndication_aal_aal1_clockRecovery srtsClockRecovery",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCIndication_aal_aal1_clockRecovery_adaptiveClockRecovery,
    {
      "adaptiveClockRecovery",
      "h245.NewATMVCIndication_aal_aal1_clockRecovery.adaptiveClockRecovery",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCIndication_aal_aal1_clockRecovery adaptiveClockRecovery",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCIndication_aal_aal1_errorCorrection_nullErrorCorrection,
    {
      "nullErrorCorrection",
      "h245.NewATMVCIndication_aal_aal1_errorCorrection.nullErrorCorrection",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCIndication_aal_aal1_errorCorrection nullErrorCorrection",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCIndication_aal_aal1_errorCorrection_longInterleaver,
    {
      "longInterleaver",
      "h245.NewATMVCIndication_aal_aal1_errorCorrection.longInterleaver",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCIndication_aal_aal1_errorCorrection longInterleaver",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCIndication_aal_aal1_errorCorrection_shortInterleaver,
    {
      "shortInterleaver",
      "h245.NewATMVCIndication_aal_aal1_errorCorrection.shortInterleaver",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCIndication_aal_aal1_errorCorrection shortInterleaver",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NewATMVCIndication_aal_aal1_errorCorrection_errorCorrectionOnly,
    {
      "errorCorrectionOnly",
      "h245.NewATMVCIndication_aal_aal1_errorCorrection.errorCorrectionOnly",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCIndication_aal_aal1_errorCorrection errorCorrectionOnly",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_NonStandardParameter_data,
    {
      "data",
      "h245.NonStandardParameter.data",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NonStandardParameter data",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_TerminalCapabilitySet_sequenceNumber,
    {
      "sequenceNumber",
      "h245.TerminalCapabilitySet.sequenceNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "TerminalCapabilitySet sequenceNumber",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_TerminalCapabilitySet_protocolIdentifier,
    {
      "protocolIdentifier",
      "h245.TerminalCapabilitySet.protocolIdentifier",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "TerminalCapabilitySet protocolIdentifier",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_CapabilityTableEntry_capabilityTableEntryNumber,
    {
      "capabilityTableEntryNumber",
      "h245.CapabilityTableEntry.capabilityTableEntryNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CapabilityTableEntry capabilityTableEntryNumber",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_CapabilityDescriptor_capabilityDescriptorNumber,
    {
      "capabilityDescriptorNumber",
      "h245.CapabilityDescriptor.capabilityDescriptorNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CapabilityDescriptor capabilityDescriptorNumber",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_TerminalCapabilitySetReject_sequenceNumber,
    {
      "sequenceNumber",
      "h245.TerminalCapabilitySetReject.sequenceNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "TerminalCapabilitySetReject sequenceNumber",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H222Capability_numberOfVCs,
    {
      "numberOfVCs",
      "h245.H222Capability.numberOfVCs",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H222Capability numberOfVCs",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223Capability_transportWithI_frames,
    {
      "transportWithI_frames",
      "h245.H223Capability.transportWithI_frames",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223Capability transportWithI_frames",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223Capability_videoWithAL1,
    {
      "videoWithAL1",
      "h245.H223Capability.videoWithAL1",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223Capability videoWithAL1",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223Capability_videoWithAL2,
    {
      "videoWithAL2",
      "h245.H223Capability.videoWithAL2",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223Capability videoWithAL2",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223Capability_videoWithAL3,
    {
      "videoWithAL3",
      "h245.H223Capability.videoWithAL3",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223Capability videoWithAL3",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223Capability_audioWithAL1,
    {
      "audioWithAL1",
      "h245.H223Capability.audioWithAL1",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223Capability audioWithAL1",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223Capability_audioWithAL2,
    {
      "audioWithAL2",
      "h245.H223Capability.audioWithAL2",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223Capability audioWithAL2",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223Capability_audioWithAL3,
    {
      "audioWithAL3",
      "h245.H223Capability.audioWithAL3",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223Capability audioWithAL3",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223Capability_dataWithAL1,
    {
      "dataWithAL1",
      "h245.H223Capability.dataWithAL1",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223Capability dataWithAL1",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223Capability_dataWithAL2,
    {
      "dataWithAL2",
      "h245.H223Capability.dataWithAL2",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223Capability dataWithAL2",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223Capability_dataWithAL3,
    {
      "dataWithAL3",
      "h245.H223Capability.dataWithAL3",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223Capability dataWithAL3",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223Capability_maximumAl2SDUSize,
    {
      "maximumAl2SDUSize",
      "h245.H223Capability.maximumAl2SDUSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H223Capability maximumAl2SDUSize",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223Capability_maximumAl3SDUSize,
    {
      "maximumAl3SDUSize",
      "h245.H223Capability.maximumAl3SDUSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H223Capability maximumAl3SDUSize",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223Capability_maximumDelayJitter,
    {
      "maximumDelayJitter",
      "h245.H223Capability.maximumDelayJitter",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H223Capability maximumDelayJitter",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223Capability_maxMUXPDUSizeCapability,
    {
      "maxMUXPDUSizeCapability",
      "h245.H223Capability.maxMUXPDUSizeCapability",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223Capability maxMUXPDUSizeCapability",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_H223Capability_nsrpSupport,
    {
      "nsrpSupport",
      "h245.H223Capability.nsrpSupport",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223Capability nsrpSupport",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_V76Capability_suspendResumeCapabilitywAddress,
    {
      "suspendResumeCapabilitywAddress",
      "h245.V76Capability.suspendResumeCapabilitywAddress",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "V76Capability suspendResumeCapabilitywAddress",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_V76Capability_suspendResumeCapabilitywoAddress,
    {
      "suspendResumeCapabilitywoAddress",
      "h245.V76Capability.suspendResumeCapabilitywoAddress",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "V76Capability suspendResumeCapabilitywoAddress",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_V76Capability_rejCapability,
    {
      "rejCapability",
      "h245.V76Capability.rejCapability",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "V76Capability rejCapability",
    }
  },
  {
  &h245Cont.h245_1.hf_h245_V76Capability_sREJCapability,
    {
      "sREJCapability",
      "h245.V76Capability.sREJCapability",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "V76Capability sREJCapability",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_V76Capability_mREJCapability,
    {
      "mREJCapability",
      "h245.V76Capability.mREJCapability",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "V76Capability mREJCapability",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_V76Capability_crc8bitCapability,
    {
      "crc8bitCapability",
      "h245.V76Capability.crc8bitCapability",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "V76Capability crc8bitCapability",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_V76Capability_crc16bitCapability,
    {
      "crc16bitCapability",
      "h245.V76Capability.crc16bitCapability",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "V76Capability crc16bitCapability",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_V76Capability_crc32bitCapability,
    {
      "crc32bitCapability",
      "h245.V76Capability.crc32bitCapability",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "V76Capability crc32bitCapability",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_V76Capability_uihCapability,
    {
      "uihCapability",
      "h245.V76Capability.uihCapability",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "V76Capability uihCapability",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_V76Capability_numOfDLCS,
    {
      "numOfDLCS",
      "h245.V76Capability.numOfDLCS",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "V76Capability numOfDLCS",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_V76Capability_twoOctetAddressFieldCapability,
    {
      "twoOctetAddressFieldCapability",
      "h245.V76Capability.twoOctetAddressFieldCapability",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "V76Capability twoOctetAddressFieldCapability",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_V76Capability_loopBackTestCapability,
    {
      "loopBackTestCapability",
      "h245.V76Capability.loopBackTestCapability",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "V76Capability loopBackTestCapability",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_V76Capability_n401Capability,
    {
      "n401Capability",
      "h245.V76Capability.n401Capability",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "V76Capability n401Capability",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_V76Capability_maxWindowSizeCapability,
    {
      "maxWindowSizeCapability",
      "h245.V76Capability.maxWindowSizeCapability",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "V76Capability maxWindowSizeCapability",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_MediaPacketizationCapability_h261aVideoPacketization,
    {
      "h261aVideoPacketization",
      "h245.MediaPacketizationCapability.h261aVideoPacketization",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "MediaPacketizationCapability h261aVideoPacketization",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_RSVPParameters_tokenRate,
    {
      "tokenRate",
      "h245.RSVPParameters.tokenRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RSVPParameters tokenRate",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_RSVPParameters_bucketSize,
    {
      "bucketSize",
      "h245.RSVPParameters.bucketSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RSVPParameters bucketSize",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_RSVPParameters_peakRate,
    {
      "peakRate",
      "h245.RSVPParameters.peakRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RSVPParameters peakRate",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_RSVPParameters_minPoliced,
    {
      "minPoliced",
      "h245.RSVPParameters.minPoliced",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RSVPParameters minPoliced",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_RSVPParameters_maxPktSize,
    {
      "maxPktSize",
      "h245.RSVPParameters.maxPktSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RSVPParameters maxPktSize",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_RedundancyEncodingCapability_primaryEncoding,
    {
      "primaryEncoding",
      "h245.RedundancyEncodingCapability.primaryEncoding",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RedundancyEncodingCapability primaryEncoding",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_RTPH263VideoRedundancyEncoding_numberOfThreads,
    {
      "numberOfThreads",
      "h245.RTPH263VideoRedundancyEncoding.numberOfThreads",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RTPH263VideoRedundancyEncoding numberOfThreads",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_RTPH263VideoRedundancyEncoding_framesBetweenSyncPoints,
    {
      "framesBetweenSyncPoints",
      "h245.RTPH263VideoRedundancyEncoding.framesBetweenSyncPoints",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RTPH263VideoRedundancyEncoding framesBetweenSyncPoints",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_RTPH263VideoRedundancyFrameMapping_threadNumber,
    {
      "threadNumber",
      "h245.RTPH263VideoRedundancyFrameMapping.threadNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RTPH263VideoRedundancyFrameMapping threadNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_MultipointCapability_multicastCapability,
    {
      "multicastCapability",
      "h245.MultipointCapability.multicastCapability",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "MultipointCapability multicastCapability",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_MultipointCapability_multiUniCastConference,
    {
      "multiUniCastConference",
      "h245.MultipointCapability.multiUniCastConference",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "MultipointCapability multiUniCastConference",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_MediaDistributionCapability_centralizedControl,
    {
      "centralizedControl",
      "h245.MediaDistributionCapability.centralizedControl",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "MediaDistributionCapability centralizedControl",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_MediaDistributionCapability_distributedControl,
    {
      "distributedControl",
      "h245.MediaDistributionCapability.distributedControl",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "MediaDistributionCapability distributedControl",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_MediaDistributionCapability_centralizedAudio,
    {
      "centralizedAudio",
      "h245.MediaDistributionCapability.centralizedAudio",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "MediaDistributionCapability centralizedAudio",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_MediaDistributionCapability_distributedAudio,
    {
      "distributedAudio",
      "h245.MediaDistributionCapability.distributedAudio",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "MediaDistributionCapability distributedAudio",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_MediaDistributionCapability_centralizedVideo,
    {
      "centralizedVideo",
      "h245.MediaDistributionCapability.centralizedVideo",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "MediaDistributionCapability centralizedVideo",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_MediaDistributionCapability_distributedVideo,
    {
      "distributedVideo",
      "h245.MediaDistributionCapability.distributedVideo",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "MediaDistributionCapability distributedVideo",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_EnhancementLayerInfo_baseBitRateConstrained,
    {
      "baseBitRateConstrained",
      "h245.EnhancementLayerInfo.baseBitRateConstrained",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "EnhancementLayerInfo baseBitRateConstrained",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_RefPictureSelection_videoMux,
    {
      "videoMux",
      "h245.RefPictureSelection.videoMux",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "RefPictureSelection videoMux",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_G7231AnnexCCapability_maxAl_sduAudioFrames,
    {
      "maxAl_sduAudioFrames",
      "h245.G7231AnnexCCapability.maxAl_sduAudioFrames",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "G7231AnnexCCapability maxAl_sduAudioFrames",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_G7231AnnexCCapability_silenceSuppression,
    {
      "silenceSuppression",
      "h245.G7231AnnexCCapability.silenceSuppression",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "G7231AnnexCCapability silenceSuppression",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_DataApplicationCapability_maxBitRate,
    {
      "maxBitRate",
      "h245.DataApplicationCapability.maxBitRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "DataApplicationCapability maxBitRate",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_ConferenceCapability_chairControlCapability,
    {
      "chairControlCapability",
      "h245.ConferenceCapability.chairControlCapability",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceCapability chairControlCapability",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_NetworkAccessParameters_associateConference,
    {
      "associateConference",
      "h245.NetworkAccessParameters.associateConference",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "NetworkAccessParameters associateConference",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_NetworkAccessParameters_externalReference,
    {
      "externalReference",
      "h245.NetworkAccessParameters.externalReference",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "NetworkAccessParameters externalReference",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_Q2931Address_subaddress,
    {
      "subaddress",
      "h245.Q2931Address.subaddress",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "Q2931Address subaddress",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H223LogicalChannelParameters_segmentableFlag,
    {
      "segmentableFlag",
      "h245.H223LogicalChannelParameters.segmentableFlag",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223LogicalChannelParameters segmentableFlag",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H223AL1MParameters_rcpcCodeRate,
    {
      "rcpcCodeRate",
      "h245.H223AL1MParameters.rcpcCodeRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H223AL1MParameters rcpcCodeRate",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H223AL1MParameters_alpduInterleaving,
    {
      "alpduInterleaving",
      "h245.H223AL1MParameters.alpduInterleaving",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AL1MParameters alpduInterleaving",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H223AL1MParameters_alsduSplitting,
    {
      "alsduSplitting",
      "h245.H223AL1MParameters.alsduSplitting",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AL1MParameters alsduSplitting",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H223AL2MParameters_alpduInterleaving,
    {
      "alpduInterleaving",
      "h245.H223AL2MParameters.alpduInterleaving",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AL2MParameters alpduInterleaving",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H223AL3MParameters_rcpcCodeRate,
    {
      "rcpcCodeRate",
      "h245.H223AL3MParameters.rcpcCodeRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H223AL3MParameters rcpcCodeRate",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H223AL3MParameters_alpduInterleaving,
    {
      "alpduInterleaving",
      "h245.H223AL3MParameters.alpduInterleaving",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223AL3MParameters alpduInterleaving",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H223AnnexCArqParameters_sendBufferSize,
    {
      "sendBufferSize",
      "h245.H223AnnexCArqParameters.sendBufferSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H223AnnexCArqParameters sendBufferSize",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_V76HDLCParameters_n401,
    {
      "n401",
      "h245.V76HDLCParameters.n401",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "V76HDLCParameters n401",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_V76HDLCParameters_loopbackTestProcedure,
    {
      "loopbackTestProcedure",
      "h245.V76HDLCParameters.loopbackTestProcedure",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "V76HDLCParameters loopbackTestProcedure",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_RTPPayloadType_payloadType,
    {
      "payloadType",
      "h245.RTPPayloadType.payloadType",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RTPPayloadType payloadType",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_EncryptionSync_synchFlag,
    {
      "synchFlag",
      "h245.EncryptionSync.synchFlag",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "EncryptionSync synchFlag",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_EncryptionSync_h235Key,
    {
      "h235Key",
      "h245.EncryptionSync.h235Key",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "EncryptionSync h235Key",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_OpenLogicalChannelReject_forwardLogicalChannelNumber,
    {
      "forwardLogicalChannelNumber",
      "h245.OpenLogicalChannelReject.forwardLogicalChannelNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "OpenLogicalChannelReject forwardLogicalChannelNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H2250LogicalChannelAckParameters_sessionID,
    {
      "sessionID",
      "h245.H2250LogicalChannelAckParameters.sessionID",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H2250LogicalChannelAckParameters sessionID",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H2250LogicalChannelAckParameters_dynamicRTPPayloadType,
    {
      "dynamicRTPPayloadType",
      "h245.H2250LogicalChannelAckParameters.dynamicRTPPayloadType",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H2250LogicalChannelAckParameters dynamicRTPPayloadType",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H2250LogicalChannelAckParameters_flowControlToZero,
    {
      "flowControlToZero",
      "h245.H2250LogicalChannelAckParameters.flowControlToZero",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H2250LogicalChannelAckParameters flowControlToZero",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H2250LogicalChannelAckParameters_portNumber,
    {
      "portNumber",
      "h245.H2250LogicalChannelAckParameters.portNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H2250LogicalChannelAckParameters portNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_CloseLogicalChannel_forwardLogicalChannelNumber,
    {
      "forwardLogicalChannelNumber",
      "h245.CloseLogicalChannel.forwardLogicalChannelNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CloseLogicalChannel forwardLogicalChannelNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_RequestChannelClose_forwardLogicalChannelNumber,
    {
      "forwardLogicalChannelNumber",
      "h245.RequestChannelClose.forwardLogicalChannelNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RequestChannelClose forwardLogicalChannelNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_RequestChannelCloseReject_forwardLogicalChannelNumber,
    {
      "forwardLogicalChannelNumber",
      "h245.RequestChannelCloseReject.forwardLogicalChannelNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RequestChannelCloseReject forwardLogicalChannelNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_MultiplexEntrySend_sequenceNumber,
    {
      "sequenceNumber",
      "h245.MultiplexEntrySend.sequenceNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MultiplexEntrySend sequenceNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_MultiplexEntryDescriptor_multiplexTableEntryNumber,
    {
      "multiplexTableEntryNumber",
      "h245.MultiplexEntryDescriptor.multiplexTableEntryNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MultiplexEntryDescriptor multiplexTableEntryNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_MultiplexEntrySendAck_sequenceNumber,
    {
      "sequenceNumber",
      "h245.MultiplexEntrySendAck.sequenceNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MultiplexEntrySendAck sequenceNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_MultiplexEntrySendReject_sequenceNumber,
    {
      "sequenceNumber",
      "h245.MultiplexEntrySendReject.sequenceNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MultiplexEntrySendReject sequenceNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_MultiplexEntryRejectionDescriptions_multiplexTableEntryNumber,
    {
      "multiplexTableEntryNumber",
      "h245.MultiplexEntryRejectionDescriptions.multiplexTableEntryNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MultiplexEntryRejectionDescriptions multiplexTableEntryNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_RequestMultiplexEntryRejectionDescriptions_multiplexTableEntryNumber,
    {
      "multiplexTableEntryNumber",
      "h245.RequestMultiplexEntryRejectionDescriptions.multiplexTableEntryNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RequestMultiplexEntryRejectionDescriptions multiplexTableEntryNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_RequestMode_sequenceNumber,
    {
      "sequenceNumber",
      "h245.RequestMode.sequenceNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RequestMode sequenceNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_RequestModeAck_sequenceNumber,
    {
      "sequenceNumber",
      "h245.RequestModeAck.sequenceNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RequestModeAck sequenceNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_RequestModeReject_sequenceNumber,
    {
      "sequenceNumber",
      "h245.RequestModeReject.sequenceNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "RequestModeReject sequenceNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H223ModeParameters_segmentableFlag,
    {
      "segmentableFlag",
      "h245.H223ModeParameters.segmentableFlag",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H223ModeParameters segmentableFlag",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H261VideoMode_bitRate,
    {
      "bitRate",
      "h245.H261VideoMode.bitRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H261VideoMode bitRate",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H261VideoMode_stillImageTransmission,
    {
      "stillImageTransmission",
      "h245.H261VideoMode.stillImageTransmission",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H261VideoMode stillImageTransmission",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H262VideoMode_videoBitRate,
    {
      "videoBitRate",
      "h245.H262VideoMode.videoBitRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H262VideoMode videoBitRate",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H262VideoMode_vbvBufferSize,
    {
      "vbvBufferSize",
      "h245.H262VideoMode.vbvBufferSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H262VideoMode vbvBufferSize",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H262VideoMode_samplesPerLine,
    {
      "samplesPerLine",
      "h245.H262VideoMode.samplesPerLine",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H262VideoMode samplesPerLine",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H262VideoMode_linesPerFrame,
    {
      "linesPerFrame",
      "h245.H262VideoMode.linesPerFrame",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H262VideoMode linesPerFrame",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H262VideoMode_framesPerSecond,
    {
      "framesPerSecond",
      "h245.H262VideoMode.framesPerSecond",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H262VideoMode framesPerSecond",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H262VideoMode_luminanceSampleRate,
    {
      "luminanceSampleRate",
      "h245.H262VideoMode.luminanceSampleRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H262VideoMode luminanceSampleRate",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_IS11172AudioMode_bitRate,
    {
      "bitRate",
      "h245.IS11172AudioMode.bitRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "IS11172AudioMode bitRate",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_IS13818AudioMode_lowFrequencyEnhancement,
    {
      "lowFrequencyEnhancement",
      "h245.IS13818AudioMode.lowFrequencyEnhancement",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioMode lowFrequencyEnhancement",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_IS13818AudioMode_multilingual,
    {
      "multilingual",
      "h245.IS13818AudioMode.multilingual",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "IS13818AudioMode multilingual",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_IS13818AudioMode_bitRate,
    {
      "bitRate",
      "h245.IS13818AudioMode.bitRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "IS13818AudioMode bitRate",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_G7231AnnexCMode_maxAl_sduAudioFrames,
    {
      "maxAl_sduAudioFrames",
      "h245.G7231AnnexCMode.maxAl_sduAudioFrames",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "G7231AnnexCMode maxAl_sduAudioFrames",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_G7231AnnexCMode_silenceSuppression,
    {
      "silenceSuppression",
      "h245.G7231AnnexCMode.silenceSuppression",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "G7231AnnexCMode silenceSuppression",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_DataMode_bitRate,
    {
      "bitRate",
      "h245.DataMode.bitRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "DataMode bitRate",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_TerminalLabel_mcuNumber,
    {
      "mcuNumber",
      "h245.TerminalLabel.mcuNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "TerminalLabel mcuNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_TerminalLabel_terminalNumber,
    {
      "terminalNumber",
      "h245.TerminalLabel.terminalNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "TerminalLabel terminalNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_TerminalInformation_terminalID,
    {
      "terminalID",
      "h245.TerminalInformation.terminalID",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "TerminalInformation terminalID",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_DiallingInformationNumber_networkAddress,
    {
      "networkAddress",
      "h245.DiallingInformationNumber.networkAddress",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "DiallingInformationNumber networkAddress",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_DiallingInformationNumber_subAddress,
    {
      "subAddress",
      "h245.DiallingInformationNumber.subAddress",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "DiallingInformationNumber subAddress",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_MiscellaneousCommand_logicalChannelNumber,
    {
      "logicalChannelNumber",
      "h245.MiscellaneousCommand.logicalChannelNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MiscellaneousCommand logicalChannelNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_FunctionNotSupported_returnedFunction,
    {
      "returnedFunction",
      "h245.FunctionNotSupported.returnedFunction",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "FunctionNotSupported returnedFunction",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_MiscellaneousIndication_logicalChannelNumber,
    {
      "logicalChannelNumber",
      "h245.MiscellaneousIndication.logicalChannelNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MiscellaneousIndication logicalChannelNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_JitterIndication_estimatedReceivedJitterMantissa,
    {
      "estimatedReceivedJitterMantissa",
      "h245.JitterIndication.estimatedReceivedJitterMantissa",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "JitterIndication estimatedReceivedJitterMantissa",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_JitterIndication_estimatedReceivedJitterExponent,
    {
      "estimatedReceivedJitterExponent",
      "h245.JitterIndication.estimatedReceivedJitterExponent",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "JitterIndication estimatedReceivedJitterExponent",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_JitterIndication_skippedFrameCount,
    {
      "skippedFrameCount",
      "h245.JitterIndication.skippedFrameCount",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "JitterIndication skippedFrameCount",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_JitterIndication_additionalDecoderBuffer,
    {
      "additionalDecoderBuffer",
      "h245.JitterIndication.additionalDecoderBuffer",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "JitterIndication additionalDecoderBuffer",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_VCCapability_aal1ViaGateway_nullClockRecovery,
    {
      "nullClockRecovery",
      "h245.VCCapability_aal1ViaGateway.nullClockRecovery",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "VCCapability_aal1ViaGateway nullClockRecovery",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_VCCapability_aal1ViaGateway_srtsClockRecovery,
    {
      "srtsClockRecovery",
      "h245.VCCapability_aal1ViaGateway.srtsClockRecovery",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "VCCapability_aal1ViaGateway srtsClockRecovery",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_VCCapability_aal1ViaGateway_adaptiveClockRecovery,
    {
      "adaptiveClockRecovery",
      "h245.VCCapability_aal1ViaGateway.adaptiveClockRecovery",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "VCCapability_aal1ViaGateway adaptiveClockRecovery",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_VCCapability_aal1ViaGateway_nullErrorCorrection,
    {
      "nullErrorCorrection",
      "h245.VCCapability_aal1ViaGateway.nullErrorCorrection",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "VCCapability_aal1ViaGateway nullErrorCorrection",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_VCCapability_aal1ViaGateway_longInterleaver,
    {
      "longInterleaver",
      "h245.VCCapability_aal1ViaGateway.longInterleaver",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "VCCapability_aal1ViaGateway longInterleaver",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_VCCapability_aal1ViaGateway_shortInterleaver,
    {
      "shortInterleaver",
      "h245.VCCapability_aal1ViaGateway.shortInterleaver",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "VCCapability_aal1ViaGateway shortInterleaver",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_VCCapability_aal1ViaGateway_errorCorrectionOnly,
    {
      "errorCorrectionOnly",
      "h245.VCCapability_aal1ViaGateway.errorCorrectionOnly",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "VCCapability_aal1ViaGateway errorCorrectionOnly",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_VCCapability_aal1ViaGateway_structuredDataTransfer,
    {
      "structuredDataTransfer",
      "h245.VCCapability_aal1ViaGateway.structuredDataTransfer",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "VCCapability_aal1ViaGateway structuredDataTransfer",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_VCCapability_aal1ViaGateway_partiallyFilledCells,
    {
      "partiallyFilledCells",
      "h245.VCCapability_aal1ViaGateway.partiallyFilledCells",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "VCCapability_aal1ViaGateway partiallyFilledCells",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_CustomPictureFormat_mPI_standardMPI,
    {
      "standardMPI",
      "h245.CustomPictureFormat_mPI.standardMPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CustomPictureFormat_mPI standardMPI",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_OpenLogicalChannel_forwardLogicalChannelParameters_portNumber,
    {
      "portNumber",
      "h245.OpenLogicalChannel_forwardLogicalChannelParameters.portNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "OpenLogicalChannel_forwardLogicalChannelParameters portNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_OpenLogicalChannel_forwardLogicalChannelParameters_forwardLogicalChannelDependency,
    {
      "forwardLogicalChannelDependency",
      "h245.OpenLogicalChannel_forwardLogicalChannelParameters.forwardLogicalChannelDependency",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "OpenLogicalChannel_forwardLogicalChannelParameters forwardLogicalChannelDependency",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_OpenLogicalChannel_forwardLogicalChannelParameters_replacementFor,
    {
      "replacementFor",
      "h245.OpenLogicalChannel_forwardLogicalChannelParameters.replacementFor",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "OpenLogicalChannel_forwardLogicalChannelParameters replacementFor",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_OpenLogicalChannel_reverseLogicalChannelParameters_reverseLogicalChannelDependency,
    {
      "reverseLogicalChannelDependency",
      "h245.OpenLogicalChannel_reverseLogicalChannelParameters.reverseLogicalChannelDependency",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "OpenLogicalChannel_reverseLogicalChannelParameters reverseLogicalChannelDependency",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_OpenLogicalChannel_reverseLogicalChannelParameters_replacementFor,
    {
      "replacementFor",
      "h245.OpenLogicalChannel_reverseLogicalChannelParameters.replacementFor",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "OpenLogicalChannel_reverseLogicalChannelParameters replacementFor",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_UnicastAddress_iPSourceRouteAddress_network,
    {
      "network",
      "h245.UnicastAddress_iPSourceRouteAddress.network",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "UnicastAddress_iPSourceRouteAddress network",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_UnicastAddress_iPSourceRouteAddress_tsapIdentifier,
    {
      "tsapIdentifier",
      "h245.UnicastAddress_iPSourceRouteAddress.tsapIdentifier",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "UnicastAddress_iPSourceRouteAddress tsapIdentifier",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_OpenLogicalChannelAck_reverseLogicalChannelParameters_reverseLogicalChannelNumber,
    {
      "reverseLogicalChannelNumber",
      "h245.OpenLogicalChannelAck_reverseLogicalChannelParameters.reverseLogicalChannelNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "OpenLogicalChannelAck_reverseLogicalChannelParameters reverseLogicalChannelNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_OpenLogicalChannelAck_reverseLogicalChannelParameters_portNumber,
    {
      "portNumber",
      "h245.OpenLogicalChannelAck_reverseLogicalChannelParameters.portNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "OpenLogicalChannelAck_reverseLogicalChannelParameters portNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_OpenLogicalChannelAck_reverseLogicalChannelParameters_replacementFor,
    {
      "replacementFor",
      "h245.OpenLogicalChannelAck_reverseLogicalChannelParameters.replacementFor",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "OpenLogicalChannelAck_reverseLogicalChannelParameters replacementFor",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_ConferenceRequest_requestTerminalCertificate_sRandom,
    {
      "sRandom",
      "h245.ConferenceRequest_requestTerminalCertificate.sRandom",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "ConferenceRequest_requestTerminalCertificate sRandom",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_ConferenceResponse_mCTerminalIDResponse_terminalID,
    {
      "terminalID",
      "h245.ConferenceResponse_mCTerminalIDResponse.terminalID",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceResponse_mCTerminalIDResponse terminalID",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_ConferenceResponse_terminalIDResponse_terminalID,
    {
      "terminalID",
      "h245.ConferenceResponse_terminalIDResponse.terminalID",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceResponse_terminalIDResponse terminalID",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_ConferenceResponse_conferenceIDResponse_conferenceID,
    {
      "conferenceID",
      "h245.ConferenceResponse_conferenceIDResponse.conferenceID",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceResponse_conferenceIDResponse conferenceID",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_ConferenceResponse_passwordResponse_password,
    {
      "password",
      "h245.ConferenceResponse_passwordResponse.password",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceResponse_passwordResponse password",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_ConferenceResponse_chairTokenOwnerResponse_terminalID,
    {
      "terminalID",
      "h245.ConferenceResponse_chairTokenOwnerResponse.terminalID",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceResponse_chairTokenOwnerResponse terminalID",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_ConferenceResponse_terminalCertificateResponse_certificateResponse,
    {
      "certificateResponse",
      "h245.ConferenceResponse_terminalCertificateResponse.certificateResponse",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "ConferenceResponse_terminalCertificateResponse certificateResponse",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_MultilinkResponse_addConnection_sequenceNumber,
    {
      "sequenceNumber",
      "h245.MultilinkResponse_addConnection.sequenceNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "MultilinkResponse_addConnection sequenceNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_SendTerminalCapabilitySet_specificRequest_multiplexCapability,
    {
      "multiplexCapability",
      "h245.SendTerminalCapabilitySet_specificRequest.multiplexCapability",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "SendTerminalCapabilitySet_specificRequest multiplexCapability",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_EncryptionCommand_encryptionAlgorithmID_h233AlgorithmIdentifier,
    {
      "h233AlgorithmIdentifier",
      "h245.EncryptionCommand_encryptionAlgorithmID.h233AlgorithmIdentifier",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "EncryptionCommand_encryptionAlgorithmID h233AlgorithmIdentifier",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_NewATMVCCommand_reverseParameters_bitRate,
    {
      "bitRate",
      "h245.NewATMVCCommand_reverseParameters.bitRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "NewATMVCCommand_reverseParameters bitRate",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_NewATMVCCommand_reverseParameters_bitRateLockedToPCRClock,
    {
      "bitRateLockedToPCRClock",
      "h245.NewATMVCCommand_reverseParameters.bitRateLockedToPCRClock",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCCommand_reverseParameters bitRateLockedToPCRClock",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_NewATMVCCommand_reverseParameters_bitRateLockedToNetworkClock,
    {
      "bitRateLockedToNetworkClock",
      "h245.NewATMVCCommand_reverseParameters.bitRateLockedToNetworkClock",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCCommand_reverseParameters bitRateLockedToNetworkClock",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_NewATMVCIndication_reverseParameters_bitRate,
    {
      "bitRate",
      "h245.NewATMVCIndication_reverseParameters.bitRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "NewATMVCIndication_reverseParameters bitRate",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_NewATMVCIndication_reverseParameters_bitRateLockedToPCRClock,
    {
      "bitRateLockedToPCRClock",
      "h245.NewATMVCIndication_reverseParameters.bitRateLockedToPCRClock",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCIndication_reverseParameters bitRateLockedToPCRClock",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_NewATMVCIndication_reverseParameters_bitRateLockedToNetworkClock,
    {
      "bitRateLockedToNetworkClock",
      "h245.NewATMVCIndication_reverseParameters.bitRateLockedToNetworkClock",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCIndication_reverseParameters bitRateLockedToNetworkClock",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_UserInputIndication_signal_signalType,
    {
      "signalType",
      "h245.UserInputIndication_signal.signalType",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "UserInputIndication_signal signalType",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_UserInputIndication_signal_duration,
    {
      "duration",
      "h245.UserInputIndication_signal.duration",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "UserInputIndication_signal duration",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_UserInputIndication_signalUpdate_duration,
    {
      "duration",
      "h245.UserInputIndication_signalUpdate.duration",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "UserInputIndication_signalUpdate duration",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_V76LogicalChannelParameters_mode_eRM_windowSize,
    {
      "windowSize",
      "h245.V76LogicalChannelParameters_mode_eRM.windowSize",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "V76LogicalChannelParameters_mode_eRM windowSize",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_NewATMVCCommand_aal_aal1_structuredDataTransfer,
    {
      "structuredDataTransfer",
      "h245.NewATMVCCommand_aal_aal1.structuredDataTransfer",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCCommand_aal_aal1 structuredDataTransfer",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_NewATMVCCommand_aal_aal1_partiallyFilledCells,
    {
      "partiallyFilledCells",
      "h245.NewATMVCCommand_aal_aal1.partiallyFilledCells",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCCommand_aal_aal1 partiallyFilledCells",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_NewATMVCIndication_aal_aal1_structuredDataTransfer,
    {
      "structuredDataTransfer",
      "h245.NewATMVCIndication_aal_aal1.structuredDataTransfer",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCIndication_aal_aal1 structuredDataTransfer",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_NewATMVCIndication_aal_aal1_partiallyFilledCells,
    {
      "partiallyFilledCells",
      "h245.NewATMVCIndication_aal_aal1.partiallyFilledCells",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCIndication_aal_aal1 partiallyFilledCells",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_VCCapability_transportStream,
    {
      "transportStream",
      "h245.VCCapability.transportStream",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "VCCapability transportStream",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_VCCapability_programStream,
    {
      "programStream",
      "h245.VCCapability.programStream",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "VCCapability programStream",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H2250Capability_maximumAudioDelayJitter,
    {
      "maximumAudioDelayJitter",
      "h245.H2250Capability.maximumAudioDelayJitter",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H2250Capability maximumAudioDelayJitter",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H2250Capability_rtcpVideoControlCapability,
    {
      "rtcpVideoControlCapability",
      "h245.H2250Capability.rtcpVideoControlCapability",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H2250Capability rtcpVideoControlCapability",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H2250Capability_logicalChannelSwitchingCapability,
    {
      "logicalChannelSwitchingCapability",
      "h245.H2250Capability.logicalChannelSwitchingCapability",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H2250Capability logicalChannelSwitchingCapability",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H2250Capability_t120DynamicPortCapability,
    {
      "t120DynamicPortCapability",
      "h245.H2250Capability.t120DynamicPortCapability",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H2250Capability t120DynamicPortCapability",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_advancedIntraCodingMode,
    {
      "advancedIntraCodingMode",
      "h245.H263Options.advancedIntraCodingMode",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options advancedIntraCodingMode",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_deblockingFilterMode,
    {
      "deblockingFilterMode",
      "h245.H263Options.deblockingFilterMode",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options deblockingFilterMode",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_improvedPBFramesMode,
    {
      "improvedPBFramesMode",
      "h245.H263Options.improvedPBFramesMode",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options improvedPBFramesMode",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_unlimitedMotionVectors,
    {
      "unlimitedMotionVectors",
      "h245.H263Options.unlimitedMotionVectors",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options unlimitedMotionVectors",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_fullPictureFreeze,
    {
      "fullPictureFreeze",
      "h245.H263Options.fullPictureFreeze",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options fullPictureFreeze",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_partialPictureFreezeAndRelease,
    {
      "partialPictureFreezeAndRelease",
      "h245.H263Options.partialPictureFreezeAndRelease",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options partialPictureFreezeAndRelease",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_resizingPartPicFreezeAndRelease,
    {
      "resizingPartPicFreezeAndRelease",
      "h245.H263Options.resizingPartPicFreezeAndRelease",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options resizingPartPicFreezeAndRelease",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_fullPictureSnapshot,
    {
      "fullPictureSnapshot",
      "h245.H263Options.fullPictureSnapshot",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options fullPictureSnapshot",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_partialPictureSnapshot,
    {
      "partialPictureSnapshot",
      "h245.H263Options.partialPictureSnapshot",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options partialPictureSnapshot",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_videoSegmentTagging,
    {
      "videoSegmentTagging",
      "h245.H263Options.videoSegmentTagging",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options videoSegmentTagging",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_progressiveRefinement,
    {
      "progressiveRefinement",
      "h245.H263Options.progressiveRefinement",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options progressiveRefinement",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_dynamicPictureResizingByFour,
    {
      "dynamicPictureResizingByFour",
      "h245.H263Options.dynamicPictureResizingByFour",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options dynamicPictureResizingByFour",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_dynamicPictureResizingSixteenthPel,
    {
      "dynamicPictureResizingSixteenthPel",
      "h245.H263Options.dynamicPictureResizingSixteenthPel",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options dynamicPictureResizingSixteenthPel",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_dynamicWarpingHalfPel,
    {
      "dynamicWarpingHalfPel",
      "h245.H263Options.dynamicWarpingHalfPel",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options dynamicWarpingHalfPel",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_dynamicWarpingSixteenthPel,
    {
      "dynamicWarpingSixteenthPel",
      "h245.H263Options.dynamicWarpingSixteenthPel",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options dynamicWarpingSixteenthPel",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_independentSegmentDecoding,
    {
      "independentSegmentDecoding",
      "h245.H263Options.independentSegmentDecoding",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options independentSegmentDecoding",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_slicesInOrder_NonRect,
    {
      "slicesInOrder_NonRect",
      "h245.H263Options.slicesInOrder_NonRect",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options slicesInOrder_NonRect",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_slicesInOrder_Rect,
    {
      "slicesInOrder_Rect",
      "h245.H263Options.slicesInOrder_Rect",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options slicesInOrder_Rect",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_slicesNoOrder_NonRect,
    {
      "slicesNoOrder_NonRect",
      "h245.H263Options.slicesNoOrder_NonRect",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options slicesNoOrder_NonRect",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_slicesNoOrder_Rect,
    {
      "slicesNoOrder_Rect",
      "h245.H263Options.slicesNoOrder_Rect",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options slicesNoOrder_Rect",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_alternateInterVLCMode,
    {
      "alternateInterVLCMode",
      "h245.H263Options.alternateInterVLCMode",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options alternateInterVLCMode",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_modifiedQuantizationMode,
    {
      "modifiedQuantizationMode",
      "h245.H263Options.modifiedQuantizationMode",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options modifiedQuantizationMode",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_reducedResolutionUpdate,
    {
      "reducedResolutionUpdate",
      "h245.H263Options.reducedResolutionUpdate",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options reducedResolutionUpdate",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263Options_separateVideoBackChannel,
    {
      "separateVideoBackChannel",
      "h245.H263Options.separateVideoBackChannel",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263Options separateVideoBackChannel",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_CustomPictureFormat_maxCustomPictureWidth,
    {
      "maxCustomPictureWidth",
      "h245.CustomPictureFormat.maxCustomPictureWidth",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CustomPictureFormat maxCustomPictureWidth",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_CustomPictureFormat_maxCustomPictureHeight,
    {
      "maxCustomPictureHeight",
      "h245.CustomPictureFormat.maxCustomPictureHeight",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CustomPictureFormat maxCustomPictureHeight",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_CustomPictureFormat_minCustomPictureWidth,
    {
      "minCustomPictureWidth",
      "h245.CustomPictureFormat.minCustomPictureWidth",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CustomPictureFormat minCustomPictureWidth",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_CustomPictureFormat_minCustomPictureHeight,
    {
      "minCustomPictureHeight",
      "h245.CustomPictureFormat.minCustomPictureHeight",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CustomPictureFormat minCustomPictureHeight",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_OpenLogicalChannel_forwardLogicalChannelNumber,
    {
      "forwardLogicalChannelNumber",
      "h245.OpenLogicalChannel.forwardLogicalChannelNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "OpenLogicalChannel forwardLogicalChannelNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_V76LogicalChannelParameters_uIH,
    {
      "uIH",
      "h245.V76LogicalChannelParameters.uIH",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "V76LogicalChannelParameters uIH",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H2250LogicalChannelParameters_sessionID,
    {
      "sessionID",
      "h245.H2250LogicalChannelParameters.sessionID",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H2250LogicalChannelParameters sessionID",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H2250LogicalChannelParameters_associatedSessionID,
    {
      "associatedSessionID",
      "h245.H2250LogicalChannelParameters.associatedSessionID",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H2250LogicalChannelParameters associatedSessionID",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H2250LogicalChannelParameters_mediaGuaranteedDelivery,
    {
      "mediaGuaranteedDelivery",
      "h245.H2250LogicalChannelParameters.mediaGuaranteedDelivery",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H2250LogicalChannelParameters mediaGuaranteedDelivery",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H2250LogicalChannelParameters_mediaControlGuaranteedDelivery,
    {
      "mediaControlGuaranteedDelivery",
      "h245.H2250LogicalChannelParameters.mediaControlGuaranteedDelivery",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H2250LogicalChannelParameters mediaControlGuaranteedDelivery",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H2250LogicalChannelParameters_silenceSuppression,
    {
      "silenceSuppression",
      "h245.H2250LogicalChannelParameters.silenceSuppression",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H2250LogicalChannelParameters silenceSuppression",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H2250LogicalChannelParameters_dynamicRTPPayloadType,
    {
      "dynamicRTPPayloadType",
      "h245.H2250LogicalChannelParameters.dynamicRTPPayloadType",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H2250LogicalChannelParameters dynamicRTPPayloadType",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_OpenLogicalChannelAck_forwardLogicalChannelNumber,
    {
      "forwardLogicalChannelNumber",
      "h245.OpenLogicalChannelAck.forwardLogicalChannelNumber",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "OpenLogicalChannelAck forwardLogicalChannelNumber",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263VideoMode_bitRate,
    {
      "bitRate",
      "h245.H263VideoMode.bitRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H263VideoMode bitRate",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263VideoMode_unrestrictedVector,
    {
      "unrestrictedVector",
      "h245.H263VideoMode.unrestrictedVector",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263VideoMode unrestrictedVector",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263VideoMode_arithmeticCoding,
    {
      "arithmeticCoding",
      "h245.H263VideoMode.arithmeticCoding",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263VideoMode arithmeticCoding",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263VideoMode_advancedPrediction,
    {
      "advancedPrediction",
      "h245.H263VideoMode.advancedPrediction",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263VideoMode advancedPrediction",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263VideoMode_pbFrames,
    {
      "pbFrames",
      "h245.H263VideoMode.pbFrames",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263VideoMode pbFrames",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263VideoMode_errorCompensation,
    {
      "errorCompensation",
      "h245.H263VideoMode.errorCompensation",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263VideoMode errorCompensation",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_CommunicationModeTableEntry_sessionID,
    {
      "sessionID",
      "h245.CommunicationModeTableEntry.sessionID",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CommunicationModeTableEntry sessionID",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_CommunicationModeTableEntry_associatedSessionID,
    {
      "associatedSessionID",
      "h245.CommunicationModeTableEntry.associatedSessionID",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CommunicationModeTableEntry associatedSessionID",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_CommunicationModeTableEntry_sessionDescription,
    {
      "sessionDescription",
      "h245.CommunicationModeTableEntry.sessionDescription",
      FT_STRING, 
      BASE_NONE, 
      NULL,
      0x0,
      "CommunicationModeTableEntry sessionDescription",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_CommunicationModeTableEntry_mediaGuaranteedDelivery,
    {
      "mediaGuaranteedDelivery",
      "h245.CommunicationModeTableEntry.mediaGuaranteedDelivery",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "CommunicationModeTableEntry mediaGuaranteedDelivery",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_CommunicationModeTableEntry_mediaControlGuaranteedDelivery,
    {
      "mediaControlGuaranteedDelivery",
      "h245.CommunicationModeTableEntry.mediaControlGuaranteedDelivery",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "CommunicationModeTableEntry mediaControlGuaranteedDelivery",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_CommunicationModeTableEntry_sessionDependency,
    {
      "sessionDependency",
      "h245.CommunicationModeTableEntry.sessionDependency",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "CommunicationModeTableEntry sessionDependency",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_NewATMVCCommand_resourceID,
    {
      "resourceID",
      "h245.NewATMVCCommand.resourceID",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "NewATMVCCommand resourceID",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_NewATMVCCommand_bitRate,
    {
      "bitRate",
      "h245.NewATMVCCommand.bitRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "NewATMVCCommand bitRate",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_NewATMVCCommand_bitRateLockedToPCRClock,
    {
      "bitRateLockedToPCRClock",
      "h245.NewATMVCCommand.bitRateLockedToPCRClock",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCCommand bitRateLockedToPCRClock",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_NewATMVCCommand_bitRateLockedToNetworkClock,
    {
      "bitRateLockedToNetworkClock",
      "h245.NewATMVCCommand.bitRateLockedToNetworkClock",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCCommand bitRateLockedToNetworkClock",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_NewATMVCIndication_resourceID,
    {
      "resourceID",
      "h245.NewATMVCIndication.resourceID",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "NewATMVCIndication resourceID",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_NewATMVCIndication_bitRate,
    {
      "bitRate",
      "h245.NewATMVCIndication.bitRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "NewATMVCIndication bitRate",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_NewATMVCIndication_bitRateLockedToPCRClock,
    {
      "bitRateLockedToPCRClock",
      "h245.NewATMVCIndication.bitRateLockedToPCRClock",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCIndication bitRateLockedToPCRClock",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_NewATMVCIndication_bitRateLockedToNetworkClock,
    {
      "bitRateLockedToNetworkClock",
      "h245.NewATMVCIndication.bitRateLockedToNetworkClock",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "NewATMVCIndication bitRateLockedToNetworkClock",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H235SecurityCapability_mediaCapability,
    {
      "mediaCapability",
      "h245.H235SecurityCapability.mediaCapability",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H235SecurityCapability mediaCapability",
    }
  },
  {
  &h245Cont.h245_2.hf_h245_H263VideoCapability_sqcifMPI,
    {
      "sqcifMPI",
      "h245.H263VideoCapability.sqcifMPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H263VideoCapability sqcifMPI",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_H263VideoCapability_qcifMPI,
    {
      "qcifMPI",
      "h245.H263VideoCapability.qcifMPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H263VideoCapability qcifMPI",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_H263VideoCapability_cifMPI,
    {
      "cifMPI",
      "h245.H263VideoCapability.cifMPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H263VideoCapability cifMPI",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_H263VideoCapability_cif4MPI,
    {
      "cif4MPI",
      "h245.H263VideoCapability.cif4MPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H263VideoCapability cif4MPI",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_H263VideoCapability_cif16MPI,
    {
      "cif16MPI",
      "h245.H263VideoCapability.cif16MPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H263VideoCapability cif16MPI",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_H263VideoCapability_maxBitRate,
    {
      "maxBitRate",
      "h245.H263VideoCapability.maxBitRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H263VideoCapability maxBitRate",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_H263VideoCapability_unrestrictedVector,
    {
      "unrestrictedVector",
      "h245.H263VideoCapability.unrestrictedVector",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263VideoCapability unrestrictedVector",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_H263VideoCapability_arithmeticCoding,
    {
      "arithmeticCoding",
      "h245.H263VideoCapability.arithmeticCoding",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263VideoCapability arithmeticCoding",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_H263VideoCapability_advancedPrediction,
    {
      "advancedPrediction",
      "h245.H263VideoCapability.advancedPrediction",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263VideoCapability advancedPrediction",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_H263VideoCapability_pbFrames,
    {
      "pbFrames",
      "h245.H263VideoCapability.pbFrames",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263VideoCapability pbFrames",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_H263VideoCapability_temporalSpatialTradeOffCapability,
    {
      "temporalSpatialTradeOffCapability",
      "h245.H263VideoCapability.temporalSpatialTradeOffCapability",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263VideoCapability temporalSpatialTradeOffCapability",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_H263VideoCapability_hrd_B,
    {
      "hrd_B",
      "h245.H263VideoCapability.hrd_B",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H263VideoCapability hrd_B",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_H263VideoCapability_bppMaxKb,
    {
      "bppMaxKb",
      "h245.H263VideoCapability.bppMaxKb",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H263VideoCapability bppMaxKb",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_H263VideoCapability_slowSqcifMPI,
    {
      "slowSqcifMPI",
      "h245.H263VideoCapability.slowSqcifMPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H263VideoCapability slowSqcifMPI",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_H263VideoCapability_slowQcifMPI,
    {
      "slowQcifMPI",
      "h245.H263VideoCapability.slowQcifMPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H263VideoCapability slowQcifMPI",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_H263VideoCapability_slowCifMPI,
    {
      "slowCifMPI",
      "h245.H263VideoCapability.slowCifMPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H263VideoCapability slowCifMPI",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_H263VideoCapability_slowCif4MPI,
    {
      "slowCif4MPI",
      "h245.H263VideoCapability.slowCif4MPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H263VideoCapability slowCif4MPI",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_H263VideoCapability_slowCif16MPI,
    {
      "slowCif16MPI",
      "h245.H263VideoCapability.slowCif16MPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "H263VideoCapability slowCif16MPI",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_H263VideoCapability_errorCompensation,
    {
      "errorCompensation",
      "h245.H263VideoCapability.errorCompensation",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "H263VideoCapability errorCompensation",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_EnhancementOptions_sqcifMPI,
    {
      "sqcifMPI",
      "h245.EnhancementOptions.sqcifMPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "EnhancementOptions sqcifMPI",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_EnhancementOptions_qcifMPI,
    {
      "qcifMPI",
      "h245.EnhancementOptions.qcifMPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "EnhancementOptions qcifMPI",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_EnhancementOptions_cifMPI,
    {
      "cifMPI",
      "h245.EnhancementOptions.cifMPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "EnhancementOptions cifMPI",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_EnhancementOptions_cif4MPI,
    {
      "cif4MPI",
      "h245.EnhancementOptions.cif4MPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "EnhancementOptions cif4MPI",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_EnhancementOptions_cif16MPI,
    {
      "cif16MPI",
      "h245.EnhancementOptions.cif16MPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "EnhancementOptions cif16MPI",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_EnhancementOptions_maxBitRate,
    {
      "maxBitRate",
      "h245.EnhancementOptions.maxBitRate",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "EnhancementOptions maxBitRate",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_EnhancementOptions_unrestrictedVector,
    {
      "unrestrictedVector",
      "h245.EnhancementOptions.unrestrictedVector",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "EnhancementOptions unrestrictedVector",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_EnhancementOptions_arithmeticCoding,
    {
      "arithmeticCoding",
      "h245.EnhancementOptions.arithmeticCoding",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "EnhancementOptions arithmeticCoding",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_EnhancementOptions_temporalSpatialTradeOffCapability,
    {
      "temporalSpatialTradeOffCapability",
      "h245.EnhancementOptions.temporalSpatialTradeOffCapability",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "EnhancementOptions temporalSpatialTradeOffCapability",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_EnhancementOptions_slowSqcifMPI,
    {
      "slowSqcifMPI",
      "h245.EnhancementOptions.slowSqcifMPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "EnhancementOptions slowSqcifMPI",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_EnhancementOptions_slowQcifMPI,
    {
      "slowQcifMPI",
      "h245.EnhancementOptions.slowQcifMPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "EnhancementOptions slowQcifMPI",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_EnhancementOptions_slowCifMPI,
    {
      "slowCifMPI",
      "h245.EnhancementOptions.slowCifMPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "EnhancementOptions slowCifMPI",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_EnhancementOptions_slowCif4MPI,
    {
      "slowCif4MPI",
      "h245.EnhancementOptions.slowCif4MPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "EnhancementOptions slowCif4MPI",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_EnhancementOptions_slowCif16MPI,
    {
      "slowCif16MPI",
      "h245.EnhancementOptions.slowCif16MPI",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "EnhancementOptions slowCif16MPI",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_EnhancementOptions_errorCompensation,
    {
      "errorCompensation",
      "h245.EnhancementOptions.errorCompensation",
      FT_BOOLEAN, 
      BASE_NONE, 
      NULL,
      0x0,
      "EnhancementOptions errorCompensation",
    }
  },
  {
  &h245Cont.h245_3.hf_h245_BEnhancementParameters_numberOfBPictures,
    {
      "numberOfBPictures",
      "h245.BEnhancementParameters.numberOfBPictures",
      FT_UINT32, 
      BASE_DEC, 
      NULL,
      0x0,
      "BEnhancementParameters numberOfBPictures",
    }
  },
};

static gint *etth245[] = 
{
  &h245Cont.h245_0.ett_proto_H245, // Protocol itself 
  &h245Cont.h245_0.ett_h245_MultimediaSystemControlMessage_choice,
  &h245Cont.h245_0.ett_h245_RequestMessage_choice,
  &h245Cont.h245_0.ett_h245_ResponseMessage_choice,
  &h245Cont.h245_0.ett_h245_CommandMessage_choice,
  &h245Cont.h245_0.ett_h245_IndicationMessage_choice,
  &h245Cont.h245_0.ett_h245_NonStandardIdentifier_choice,
  &h245Cont.h245_0.ett_h245_Capability_choice,
  &h245Cont.h245_0.ett_h245_MultiplexCapability_choice,
  &h245Cont.h245_0.ett_h245_MediaChannelCapability_mediaTransport,
  &h245Cont.h245_0.ett_h245_RedundancyEncodingMethod_choice,
  &h245Cont.h245_0.ett_h245_VideoCapability_choice,
  &h245Cont.h245_0.ett_h245_AudioCapability_choice,
  &h245Cont.h245_0.ett_h245_DataProtocolCapability_choice,
  &h245Cont.h245_0.ett_h245_CompressionType_choice,
  &h245Cont.h245_0.ett_h245_T84Profile_choice,
  &h245Cont.h245_0.ett_h245_EncryptionCapability,
  &h245Cont.h245_0.ett_h245_MediaEncryptionAlgorithm_choice,
  &h245Cont.h245_0.ett_h245_UserInputCapability_choice,
  &h245Cont.h245_0.ett_h245_DataType_choice,
  &h245Cont.h245_0.ett_h245_RedundancyEncoding_redundancyEncodingMethod,
  &h245Cont.h245_0.ett_h245_RedundancyEncoding_secondaryEncoding,
  &h245Cont.h245_0.ett_h245_TransportAddress_choice,
  &h245Cont.h245_0.ett_h245_UnicastAddress_choice,
  &h245Cont.h245_0.ett_h245_MulticastAddress_choice,
  &h245Cont.h245_0.ett_h245_ModeDescription,
  &h245Cont.h245_0.ett_h245_VideoMode_choice,
  &h245Cont.h245_0.ett_h245_AudioMode_choice,
  &h245Cont.h245_0.ett_h245_EncryptionMode_choice,
  &h245Cont.h245_0.ett_h245_CommunicationModeResponse_choice,
  &h245Cont.h245_0.ett_h245_ConferenceRequest_choice,
  &h245Cont.h245_0.ett_h245_CertSelectionCriteria,
  &h245Cont.h245_0.ett_h245_ConferenceResponse_choice,
  &h245Cont.h245_0.ett_h245_RemoteMCResponse_choice,
  &h245Cont.h245_0.ett_h245_MultilinkRequest_choice,
  &h245Cont.h245_0.ett_h245_MultilinkResponse_choice,
  &h245Cont.h245_0.ett_h245_MultilinkIndication_choice,
  &h245Cont.h245_0.ett_h245_DiallingInformation_choice,
  &h245Cont.h245_0.ett_h245_DiallingInformationNetworkType_choice,
  &h245Cont.h245_0.ett_h245_SendTerminalCapabilitySet_choice,
  &h245Cont.h245_0.ett_h245_EncryptionCommand_choice,
  &h245Cont.h245_0.ett_h245_EndSessionCommand_choice,
  &h245Cont.h245_0.ett_h245_ConferenceCommand_choice,
  &h245Cont.h245_0.ett_h245_EncryptionUpdateRequest_keyProtectionMethod,
  &h245Cont.h245_0.ett_h245_H223MultiplexReconfiguration_choice,
  &h245Cont.h245_0.ett_h245_FunctionNotUnderstood_choice,
  &h245Cont.h245_0.ett_h245_ConferenceIndication_choice,
  &h245Cont.h245_0.ett_h245_MCLocationIndication_signalAddress,
  &h245Cont.h245_0.ett_h245_VendorIdentification_vendor,
  &h245Cont.h245_0.ett_h245_UserInputIndication_choice,
  &h245Cont.h245_0.ett_h245_ArrayOf_CapabilityTableEntry,
  &h245Cont.h245_0.ett_h245_ArrayOf_CapabilityDescriptor,
  &h245Cont.h245_0.ett_h245_ArrayOf_AlternativeCapabilitySet,
  &h245Cont.h245_0.ett_h245_TerminalCapabilitySetReject_cause_choice,
  &h245Cont.h245_0.ett_h245_ArrayOf_VCCapability,
  &h245Cont.h245_0.ett_h245_H223Capability_h223MultiplexTableCapability_choice,
  &h245Cont.h245_0.ett_h245_ArrayOf_RedundancyEncodingCapability,
  &h245Cont.h245_0.ett_h245_ArrayOf_RTPPayloadType,
  &h245Cont.h245_0.ett_h245_ArrayOf_QOSCapability,
  &h245Cont.h245_0.ett_h245_ArrayOf_MediaChannelCapability,
  &h245Cont.h245_0.ett_h245_RTPH263VideoRedundancyEncoding_frameToThreadMapping_choice,
  &h245Cont.h245_0.ett_h245_ArrayOf_MediaDistributionCapability,
  &h245Cont.h245_0.ett_h245_ArrayOf_DataApplicationCapability,
  &h245Cont.h245_0.ett_h245_ArrayOf_EnhancementOptions,
  &h245Cont.h245_0.ett_h245_ArrayOf_BEnhancementParameters,
  &h245Cont.h245_0.ett_h245_ArrayOf_CustomPictureClockFrequency,
  &h245Cont.h245_0.ett_h245_ArrayOf_CustomPictureFormat,
  &h245Cont.h245_0.ett_h245_ArrayOf_H263VideoModeCombos,
  &h245Cont.h245_0.ett_h245_CustomPictureFormat_pixelAspectInformation_choice,
  &h245Cont.h245_0.ett_h245_ArrayOf_H263ModeComboFlags,
  &h245Cont.h245_0.ett_h245_DataApplicationCapability_application_choice,
  &h245Cont.h245_0.ett_h245_DataProtocolCapability_v76wCompression_choice,
  &h245Cont.h245_1.ett_h245_ArrayOf_NonStandardParameter,
  &h245Cont.h245_1.ett_h245_NetworkAccessParameters_networkAddress_choice,
  &h245Cont.h245_1.ett_h245_H235Media_mediaType_choice,
  &h245Cont.h245_1.ett_h245_H223LogicalChannelParameters_adaptationLayerType_choice,
  &h245Cont.h245_1.ett_h245_H223AL1MParameters_arqType_choice,
  &h245Cont.h245_1.ett_h245_H223AL3MParameters_arqType_choice,
  &h245Cont.h245_1.ett_h245_V76LogicalChannelParameters_mode_choice,
  &h245Cont.h245_1.ett_h245_H2250LogicalChannelParameters_mediaPacketization_choice,
  &h245Cont.h245_1.ett_h245_RTPPayloadType_payloadDescriptor_choice,
  &h245Cont.h245_1.ett_h245_ArrayOf_EscrowData,
  &h245Cont.h245_1.ett_h245_OpenLogicalChannelAck_forwardMultiplexAckParameters_choice,
  &h245Cont.h245_1.ett_h245_ArrayOf_MultiplexEntryDescriptor,
  &h245Cont.h245_1.ett_h245_ArrayOf_MultiplexElement,
  &h245Cont.h245_1.ett_h245_MultiplexElement_type_choice,
  &h245Cont.h245_1.ett_h245_ArrayOf_MultiplexEntryRejectionDescriptions,
  &h245Cont.h245_1.ett_h245_ArrayOf_RequestMultiplexEntryRejectionDescriptions,
  &h245Cont.h245_1.ett_h245_ArrayOf_ModeDescription,
  &h245Cont.h245_1.ett_h245_ModeElement_type_choice,
  &h245Cont.h245_1.ett_h245_H235Mode_mediaMode_choice,
  &h245Cont.h245_1.ett_h245_H223ModeParameters_adaptationLayerType_choice,
  &h245Cont.h245_1.ett_h245_RedundancyEncodingMode_secondaryEncoding_choice,
  &h245Cont.h245_1.ett_h245_DataMode_application_choice,
  &h245Cont.h245_1.ett_h245_ArrayOf_CommunicationModeTableEntry,
  &h245Cont.h245_1.ett_h245_CommunicationModeTableEntry_dataType_choice,
  &h245Cont.h245_1.ett_h245_ArrayOf_TerminalLabel,
  &h245Cont.h245_1.ett_h245_ArrayOf_TerminalInformation,
  &h245Cont.h245_1.ett_h245_MultilinkRequest_addConnection_diallingInformation,
  &h245Cont.h245_1.ett_h245_MultilinkRequest_removeConnection_connectionIdentifier,
  &h245Cont.h245_1.ett_h245_MultilinkResponse_callInformation_diallingInformation,
  &h245Cont.h245_1.ett_h245_MultilinkResponse_removeConnection_connectionIdentifier,
  &h245Cont.h245_1.ett_h245_MultilinkIndication_excessiveError_connectionIdentifier,
  &h245Cont.h245_1.ett_h245_ArrayOf_DiallingInformationNumber,
  &h245Cont.h245_1.ett_h245_ArrayOf_DiallingInformationNetworkType,
  &h245Cont.h245_1.ett_h245_MiscellaneousCommand_type_choice,
  &h245Cont.h245_1.ett_h245_NewATMVCCommand_aal_choice,
  &h245Cont.h245_1.ett_h245_MiscellaneousIndication_type_choice,
  &h245Cont.h245_1.ett_h245_NewATMVCIndication_aal_choice,
  &h245Cont.h245_1.ett_h245_UserInputIndication_userInputSupportIndication_choice,
  &h245Cont.h245_1.ett_h245_VCCapability_availableBitRates_type_choice,
  &h245Cont.h245_1.ett_h245_ArrayOf_Q2931Address,
  &h245Cont.h245_1.ett_h245_ArrayOf_RTPH263VideoRedundancyFrameMapping,
  &h245Cont.h245_1.ett_h245_CustomPictureFormat_mPI_customPCF,
  &h245Cont.h245_1.ett_h245_CustomPictureFormat_pixelAspectInformation_extendedPAR,
  &h245Cont.h245_1.ett_h245_DataApplicationCapability_application_t84_t84Protocol,
  &h245Cont.h245_1.ett_h245_DataApplicationCapability_application_t84_t84Profile,
  &h245Cont.h245_1.ett_h245_DataApplicationCapability_application_nlpid_nlpidProtocol,
  &h245Cont.h245_1.ett_h245_DataApplicationCapability_application_t38fax_t38FaxProtocol,
  &h245Cont.h245_1.ett_h245_DataApplicationCapability_application_t38fax_t38FaxProfile,
  &h245Cont.h245_1.ett_h245_OpenLogicalChannel_forwardLogicalChannelParameters_multiplexParameters_choice,
  &h245Cont.h245_1.ett_h245_OpenLogicalChannel_reverseLogicalChannelParameters_multiplexParameters_choice,
  &h245Cont.h245_1.ett_h245_OpenLogicalChannelAck_reverseLogicalChannelParameters_multiplexParameters_choice,
  &h245Cont.h245_1.ett_h245_DataMode_application_nlpid_nlpidProtocol,
  &h245Cont.h245_1.ett_h245_DataMode_application_t38fax_t38FaxProtocol,
  &h245Cont.h245_1.ett_h245_DataMode_application_t38fax_t38FaxProfile,
  &h245Cont.h245_1.ett_h245_MultilinkResponse_addConnection_responseCode_choice,
  &h245Cont.h245_1.ett_h245_NonStandardParameter_nonStandardIdentifier,
  &h245Cont.h245_1.ett_h245_MasterSlaveDeterminationAck_decision,
  &h245Cont.h245_1.ett_h245_MasterSlaveDeterminationReject_cause,
  &h245Cont.h245_1.ett_h245_TerminalCapabilitySet_multiplexCapability,
  &h245Cont.h245_1.ett_h245_TerminalCapabilitySet_capabilityTable,
  &h245Cont.h245_1.ett_h245_TerminalCapabilitySet_capabilityDescriptors,
  &h245Cont.h245_1.ett_h245_CapabilityTableEntry_capability,
  &h245Cont.h245_1.ett_h245_CapabilityDescriptor_simultaneousCapabilities,
  &h245Cont.h245_1.ett_h245_TerminalCapabilitySetReject_cause,
  &h245Cont.h245_1.ett_h245_H222Capability_vcCapability,
  &h245Cont.h245_1.ett_h245_H223Capability_h223MultiplexTableCapability,
  &h245Cont.h245_1.ett_h245_H223Capability_mobileOperationTransmitCapability,
  &h245Cont.h245_1.ett_h245_H223Capability_h223AnnexCCapability,
  &h245Cont.h245_2.ett_h245_V76Capability_v75Capability,
  &h245Cont.h245_2.ett_h245_MediaPacketizationCapability_rtpPayloadType,
  &h245Cont.h245_2.ett_h245_RSVPParameters_qosMode,
  &h245Cont.h245_2.ett_h245_QOSCapability_nonStandardData,
  &h245Cont.h245_2.ett_h245_QOSCapability_rsvpParameters,
  &h245Cont.h245_2.ett_h245_QOSCapability_atmParameters,
  &h245Cont.h245_2.ett_h245_TransportCapability_nonStandard,
  &h245Cont.h245_2.ett_h245_TransportCapability_qOSCapabilities,
  &h245Cont.h245_2.ett_h245_TransportCapability_mediaChannelCapabilities,
  &h245Cont.h245_2.ett_h245_RedundancyEncodingCapability_redundancyEncodingMethod,
  &h245Cont.h245_2.ett_h245_RedundancyEncodingCapability_secondaryEncoding,
  &h245Cont.h245_2.ett_h245_RTPH263VideoRedundancyEncoding_frameToThreadMapping,
  &h245Cont.h245_2.ett_h245_RTPH263VideoRedundancyEncoding_containedThreads,
  &h245Cont.h245_2.ett_h245_RTPH263VideoRedundancyFrameMapping_frameSequence,
  &h245Cont.h245_2.ett_h245_MultipointCapability_mediaDistributionCapability,
  &h245Cont.h245_2.ett_h245_MediaDistributionCapability_centralizedData,
  &h245Cont.h245_2.ett_h245_MediaDistributionCapability_distributedData,
  &h245Cont.h245_2.ett_h245_EnhancementLayerInfo_snrEnhancement,
  &h245Cont.h245_2.ett_h245_EnhancementLayerInfo_spatialEnhancement,
  &h245Cont.h245_2.ett_h245_EnhancementLayerInfo_bPictureEnhancement,
  &h245Cont.h245_2.ett_h245_RefPictureSelection_additionalPictureMemory,
  &h245Cont.h245_2.ett_h245_RefPictureSelection_videoBackChannelSend,
  &h245Cont.h245_2.ett_h245_H263VideoModeCombos_h263VideoUncoupledModes,
  &h245Cont.h245_2.ett_h245_H263VideoModeCombos_h263VideoCoupledModes,
  &h245Cont.h245_2.ett_h245_G7231AnnexCCapability_g723AnnexCAudioMode,
  &h245Cont.h245_2.ett_h245_DataApplicationCapability_application,
  &h245Cont.h245_2.ett_h245_AuthenticationCapability_nonStandard,
  &h245Cont.h245_2.ett_h245_IntegrityCapability_nonStandard,
  &h245Cont.h245_2.ett_h245_ConferenceCapability_nonStandardData,
  &h245Cont.h245_2.ett_h245_NetworkAccessParameters_distribution,
  &h245Cont.h245_2.ett_h245_NetworkAccessParameters_networkAddress,
  &h245Cont.h245_2.ett_h245_NetworkAccessParameters_t120SetupProcedure,
  &h245Cont.h245_2.ett_h245_Q2931Address_address,
  &h245Cont.h245_2.ett_h245_H223LogicalChannelParameters_adaptationLayerType,
  &h245Cont.h245_2.ett_h245_H223AL1MParameters_transferMode,
  &h245Cont.h245_2.ett_h245_H223AL1MParameters_headerFEC,
  &h245Cont.h245_2.ett_h245_H223AL1MParameters_crcLength,
  &h245Cont.h245_2.ett_h245_H223AL1MParameters_arqType,
  &h245Cont.h245_2.ett_h245_H223AL2MParameters_headerFEC,
  &h245Cont.h245_2.ett_h245_H223AL3MParameters_headerFormat,
  &h245Cont.h245_2.ett_h245_H223AL3MParameters_crcLength,
  &h245Cont.h245_2.ett_h245_H223AL3MParameters_arqType,
  &h245Cont.h245_2.ett_h245_H223AnnexCArqParameters_numberOfRetransmissions,
  &h245Cont.h245_2.ett_h245_V76HDLCParameters_crcLength,
  &h245Cont.h245_2.ett_h245_RTPPayloadType_payloadDescriptor,
  &h245Cont.h245_2.ett_h245_EncryptionSync_nonStandard,
  &h245Cont.h245_2.ett_h245_EncryptionSync_escrowentry,
  &h245Cont.h245_2.ett_h245_OpenLogicalChannelReject_cause,
  &h245Cont.h245_2.ett_h245_H2250LogicalChannelAckParameters_nonStandard,
  &h245Cont.h245_2.ett_h245_H2250LogicalChannelAckParameters_mediaChannel,
  &h245Cont.h245_2.ett_h245_H2250LogicalChannelAckParameters_mediaControlChannel,
  &h245Cont.h245_2.ett_h245_CloseLogicalChannel_source,
  &h245Cont.h245_2.ett_h245_CloseLogicalChannel_reason,
  &h245Cont.h245_2.ett_h245_RequestChannelClose_qosCapability,
  &h245Cont.h245_2.ett_h245_RequestChannelClose_reason,
  &h245Cont.h245_2.ett_h245_RequestChannelCloseReject_cause,
  &h245Cont.h245_2.ett_h245_MultiplexEntrySend_multiplexEntryDescriptors,
  &h245Cont.h245_2.ett_h245_MultiplexEntryDescriptor_elementList,
  &h245Cont.h245_2.ett_h245_MultiplexElement_type,
  &h245Cont.h245_2.ett_h245_MultiplexElement_repeatCount,
  &h245Cont.h245_2.ett_h245_MultiplexEntrySendAck_multiplexTableEntryNumber,
  &h245Cont.h245_2.ett_h245_MultiplexEntrySendReject_rejectionDescriptions,
  &h245Cont.h245_2.ett_h245_MultiplexEntryRejectionDescriptions_cause,
  &h245Cont.h245_2.ett_h245_MultiplexEntrySendRelease_multiplexTableEntryNumber,
  &h245Cont.h245_2.ett_h245_RequestMultiplexEntry_entryNumbers,
  &h245Cont.h245_2.ett_h245_RequestMultiplexEntryAck_entryNumbers,
  &h245Cont.h245_2.ett_h245_RequestMultiplexEntryReject_entryNumbers,
  &h245Cont.h245_2.ett_h245_RequestMultiplexEntryReject_rejectionDescriptions,
  &h245Cont.h245_2.ett_h245_RequestMultiplexEntryRejectionDescriptions_cause,
  &h245Cont.h245_2.ett_h245_RequestMultiplexEntryRelease_entryNumbers,
  &h245Cont.h245_2.ett_h245_RequestMode_requestedModes,
  &h245Cont.h245_2.ett_h245_RequestModeAck_response,
  &h245Cont.h245_2.ett_h245_RequestModeReject_cause,
  &h245Cont.h245_2.ett_h245_H223ModeParameters_adaptationLayerType,
  &h245Cont.h245_2.ett_h245_RedundancyEncodingMode_redundancyEncodingMethod,
  &h245Cont.h245_2.ett_h245_RedundancyEncodingMode_secondaryEncoding,
  &h245Cont.h245_2.ett_h245_H261VideoMode_resolution,
  &h245Cont.h245_2.ett_h245_H262VideoMode_profileAndLevel,
  &h245Cont.h245_2.ett_h245_IS11172AudioMode_audioLayer,
  &h245Cont.h245_2.ett_h245_IS11172AudioMode_audioSampling,
  &h245Cont.h245_2.ett_h245_IS11172AudioMode_multichannelType,
  &h245Cont.h245_2.ett_h245_IS13818AudioMode_audioLayer,
  &h245Cont.h245_2.ett_h245_IS13818AudioMode_audioSampling,
  &h245Cont.h245_2.ett_h245_IS13818AudioMode_multichannelType,
  &h245Cont.h245_2.ett_h245_G7231AnnexCMode_g723AnnexCAudioMode,
  &h245Cont.h245_2.ett_h245_DataMode_application,
  &h245Cont.h245_2.ett_h245_MaintenanceLoopRequest_type,
  &h245Cont.h245_2.ett_h245_MaintenanceLoopAck_type,
  &h245Cont.h245_2.ett_h245_MaintenanceLoopReject_type,
  &h245Cont.h245_2.ett_h245_MaintenanceLoopReject_cause,
  &h245Cont.h245_2.ett_h245_CommunicationModeCommand_communicationModeTable,
  &h245Cont.h245_2.ett_h245_RequestAllTerminalIDsResponse_terminalInformation,
  &h245Cont.h245_2.ett_h245_TerminalInformation_terminalLabel,
  &h245Cont.h245_2.ett_h245_DiallingInformationNumber_networkType,
  &h245Cont.h245_2.ett_h245_FlowControlCommand_scope,
  &h245Cont.h245_2.ett_h245_FlowControlCommand_restriction,
  &h245Cont.h245_2.ett_h245_MiscellaneousCommand_type,
  &h245Cont.h245_2.ett_h245_FunctionNotSupported_cause,
  &h245Cont.h245_2.ett_h245_MiscellaneousIndication_type,
  &h245Cont.h245_2.ett_h245_JitterIndication_scope,
  &h245Cont.h245_2.ett_h245_VCCapability_availableBitRates_type,
  &h245Cont.h245_2.ett_h245_VCCapability_aal1ViaGateway_gatewayAddress,
  &h245Cont.h245_2.ett_h245_CustomPictureFormat_mPI_customPCF,
  &h245Cont.h245_2.ett_h245_OpenLogicalChannel_forwardLogicalChannelParameters_dataType,
  &h245Cont.h245_2.ett_h245_OpenLogicalChannel_forwardLogicalChannelParameters_multiplexParameters,
  &h245Cont.h245_2.ett_h245_OpenLogicalChannel_reverseLogicalChannelParameters_dataType,
  &h245Cont.h245_2.ett_h245_OpenLogicalChannel_reverseLogicalChannelParameters_multiplexParameters,
  &h245Cont.h245_2.ett_h245_UnicastAddress_iPSourceRouteAddress_routing,
  &h245Cont.h245_2.ett_h245_UnicastAddress_iPSourceRouteAddress_route,
  &h245Cont.h245_2.ett_h245_OpenLogicalChannelAck_reverseLogicalChannelParameters_multiplexParameters,
  &h245Cont.h245_2.ett_h245_ConferenceRequest_requestTerminalCertificate_terminalLabel,
  &h245Cont.h245_2.ett_h245_ConferenceRequest_requestTerminalCertificate_certSelectionCriteria,
  &h245Cont.h245_2.ett_h245_ConferenceResponse_mCTerminalIDResponse_terminalLabel,
  &h245Cont.h245_2.ett_h245_ConferenceResponse_terminalIDResponse_terminalLabel,
  &h245Cont.h245_2.ett_h245_ConferenceResponse_conferenceIDResponse_terminalLabel,
  &h245Cont.h245_2.ett_h245_ConferenceResponse_passwordResponse_terminalLabel,
  &h245Cont.h245_2.ett_h245_ConferenceResponse_chairTokenOwnerResponse_terminalLabel,
  &h245Cont.h245_2.ett_h245_ConferenceResponse_terminalCertificateResponse_terminalLabel,
  &h245Cont.h245_2.ett_h245_MultilinkRequest_maximumHeaderInterval_requestType,
  &h245Cont.h245_2.ett_h245_MultilinkResponse_addConnection_responseCode,
  &h245Cont.h245_2.ett_h245_SendTerminalCapabilitySet_specificRequest_capabilityTableEntryNumbers,
  &h245Cont.h245_2.ett_h245_SendTerminalCapabilitySet_specificRequest_capabilityDescriptorNumbers,
  &h245Cont.h245_2.ett_h245_EncryptionCommand_encryptionAlgorithmID_associatedAlgorithm,
  &h245Cont.h245_2.ett_h245_NewATMVCCommand_reverseParameters_multiplex,
  &h245Cont.h245_2.ett_h245_NewATMVCIndication_reverseParameters_multiplex,
  &h245Cont.h245_2.ett_h245_UserInputIndication_signal_rtp,
  &h245Cont.h245_2.ett_h245_UserInputIndication_signalUpdate_rtp,
  &h245Cont.h245_2.ett_h245_V76LogicalChannelParameters_mode_eRM_recovery,
  &h245Cont.h245_2.ett_h245_MiscellaneousCommand_type_progressiveRefinementStart_repeatCount,
  &h245Cont.h245_2.ett_h245_NewATMVCCommand_aal_aal1_clockRecovery,
  &h245Cont.h245_2.ett_h245_NewATMVCCommand_aal_aal1_errorCorrection,
  &h245Cont.h245_2.ett_h245_NewATMVCIndication_aal_aal1_clockRecovery,
  &h245Cont.h245_2.ett_h245_NewATMVCIndication_aal_aal1_errorCorrection,
  &h245Cont.h245_2.ett_h245_NonStandardMessage_nonStandardData,
  &h245Cont.h245_2.ett_h245_VCCapability_aal1,
  &h245Cont.h245_2.ett_h245_VCCapability_aal5,
  &h245Cont.h245_2.ett_h245_VCCapability_availableBitRates,
  &h245Cont.h245_2.ett_h245_VCCapability_aal1ViaGateway,
  &h245Cont.h245_2.ett_h245_H2250Capability_receiveMultipointCapability,
  &h245Cont.h245_2.ett_h245_H2250Capability_transmitMultipointCapability,
  &h245Cont.h245_2.ett_h245_H2250Capability_receiveAndTransmitMultipointCapability,
  &h245Cont.h245_2.ett_h245_H2250Capability_mcCapability,
  &h245Cont.h245_2.ett_h245_H2250Capability_mediaPacketizationCapability,
  &h245Cont.h245_2.ett_h245_H2250Capability_transportCapability,
  &h245Cont.h245_2.ett_h245_H2250Capability_redundancyEncodingCapability,
  &h245Cont.h245_2.ett_h245_H263Options_transparencyParameters,
  &h245Cont.h245_2.ett_h245_H263Options_refPictureSelection,
  &h245Cont.h245_2.ett_h245_H263Options_customPictureClockFrequency,
  &h245Cont.h245_2.ett_h245_H263Options_customPictureFormat,
  &h245Cont.h245_2.ett_h245_H263Options_modeCombos,
  &h245Cont.h245_2.ett_h245_CustomPictureFormat_mPI,
  &h245Cont.h245_2.ett_h245_CustomPictureFormat_pixelAspectInformation,
  &h245Cont.h245_2.ett_h245_EncryptionAuthenticationAndIntegrity_encryptionCapability,
  &h245Cont.h245_2.ett_h245_EncryptionAuthenticationAndIntegrity_authenticationCapability,
  &h245Cont.h245_2.ett_h245_EncryptionAuthenticationAndIntegrity_integrityCapability,
  &h245Cont.h245_2.ett_h245_OpenLogicalChannel_forwardLogicalChannelParameters,
  &h245Cont.h245_2.ett_h245_OpenLogicalChannel_reverseLogicalChannelParameters,
  &h245Cont.h245_2.ett_h245_OpenLogicalChannel_separateStack,
  &h245Cont.h245_2.ett_h245_OpenLogicalChannel_encryptionSync,
  &h245Cont.h245_2.ett_h245_H235Media_encryptionAuthenticationAndIntegrity,
  &h245Cont.h245_2.ett_h245_H235Media_mediaType,
  &h245Cont.h245_2.ett_h245_V76LogicalChannelParameters_hdlcParameters,
  &h245Cont.h245_2.ett_h245_V76LogicalChannelParameters_suspendResume,
  &h245Cont.h245_2.ett_h245_V76LogicalChannelParameters_mode,
  &h245Cont.h245_2.ett_h245_V76LogicalChannelParameters_v75Parameters,
  &h245Cont.h245_2.ett_h245_H2250LogicalChannelParameters_nonStandard,
  &h245Cont.h245_2.ett_h245_H2250LogicalChannelParameters_mediaChannel,
  &h245Cont.h245_2.ett_h245_H2250LogicalChannelParameters_mediaControlChannel,
  &h245Cont.h245_2.ett_h245_H2250LogicalChannelParameters_destination,
  &h245Cont.h245_2.ett_h245_H2250LogicalChannelParameters_mediaPacketization,
  &h245Cont.h245_2.ett_h245_H2250LogicalChannelParameters_transportCapability,
  &h245Cont.h245_2.ett_h245_H2250LogicalChannelParameters_redundancyEncoding,
  &h245Cont.h245_2.ett_h245_H2250LogicalChannelParameters_source,
  &h245Cont.h245_2.ett_h245_OpenLogicalChannelAck_reverseLogicalChannelParameters,
  &h245Cont.h245_2.ett_h245_OpenLogicalChannelAck_separateStack,
  &h245Cont.h245_2.ett_h245_OpenLogicalChannelAck_forwardMultiplexAckParameters,
  &h245Cont.h245_2.ett_h245_OpenLogicalChannelAck_encryptionSync,
  &h245Cont.h245_2.ett_h245_H235Mode_encryptionAuthenticationAndIntegrity,
  &h245Cont.h245_2.ett_h245_H235Mode_mediaMode,
  &h245Cont.h245_2.ett_h245_H2250ModeParameters_redundancyEncodingMode,
  &h245Cont.h245_2.ett_h245_H263VideoMode_resolution,
  &h245Cont.h245_2.ett_h245_H263VideoMode_enhancementLayerInfo,
  &h245Cont.h245_2.ett_h245_H263VideoMode_h263Options,
  &h245Cont.h245_2.ett_h245_CommunicationModeTableEntry_nonStandard,
  &h245Cont.h245_2.ett_h245_CommunicationModeTableEntry_terminalLabel,
  &h245Cont.h245_2.ett_h245_CommunicationModeTableEntry_dataType,
  &h245Cont.h245_2.ett_h245_CommunicationModeTableEntry_mediaChannel,
  &h245Cont.h245_2.ett_h245_CommunicationModeTableEntry_mediaControlChannel,
  &h245Cont.h245_2.ett_h245_CommunicationModeTableEntry_redundancyEncoding,
  &h245Cont.h245_2.ett_h245_CommunicationModeTableEntry_destination,
  &h245Cont.h245_2.ett_h245_NewATMVCCommand_aal,
  &h245Cont.h245_2.ett_h245_NewATMVCCommand_multiplex,
  &h245Cont.h245_2.ett_h245_NewATMVCCommand_reverseParameters,
  &h245Cont.h245_2.ett_h245_NewATMVCIndication_aal,
  &h245Cont.h245_2.ett_h245_NewATMVCIndication_multiplex,
  &h245Cont.h245_2.ett_h245_NewATMVCIndication_reverseParameters,
  &h245Cont.h245_2.ett_h245_H235SecurityCapability_encryptionAuthenticationAndIntegrity,
  &h245Cont.h245_3.ett_h245_H263VideoCapability_enhancementLayerInfo,
  &h245Cont.h245_3.ett_h245_H263VideoCapability_h263Options,
  &h245Cont.h245_3.ett_h245_EnhancementOptions_h263Options,
  &h245Cont.h245_3.ett_h245_ModeElement_type,
  &h245Cont.h245_3.ett_h245_ModeElement_h223ModeParameters,
  &h245Cont.h245_3.ett_h245_ModeElement_v76ModeParameters,
  &h245Cont.h245_3.ett_h245_ModeElement_h2250ModeParameters,
  &h245Cont.h245_3.ett_h245_BEnhancementParameters_enhancementOptions,
};


	h245Cont.h245_0.hf_proto_H245 = proto_register_protocol( "ITU-T Recommendation H.245", "H245.0", "h245" );
	proto_register_field_array( h245Cont.h245_0.hf_proto_H245, hfh245, array_length( hfh245 ) );
	proto_register_subtree_array( etth245, array_length( etth245 ) );

	setH245Container( &h245Cont );

  register_dissector( "h245", dissect_h245, h245Cont.h245_0.hf_proto_H245 );

	h245_tpkt_pdu_handle = create_dissector_handle(dissect_h245_tpkt_pdu, h245Cont.h245_0.hf_proto_H245);


	//register_init_routine( &h245_init );
}

} // extern "C"